function [residual, g1, g2, g3] = BBCDLmodelcomp_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           columns: equations in order of declaration
%                                                           rows: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(36, 1);
T14 = exp(y(15))^(1-params(1))/(1-params(1));
T21 = params(27)*exp(y(44))^(-params(22));
T23 = exp(y(18));
T25 = T23^(1+params(22));
T30 = T21*T25/(1+params(22))*exp(y(25));
T46 = params(33)*exp(y(47))^(-params(21));
T48 = exp(y(32));
T50 = T48^(1+params(21));
T55 = T46*T50/(1+params(21))*exp(y(39));
T65 = ((1+y(3))/(1+params(38)))^params(40);
T68 = y(21)/params(31);
T70 = T68^params(41);
T73 = (T68*T70)^(1-params(40));
T88 = ((1+y(6))/(1+params(39)))^params(42);
T91 = y(35)/params(36);
T93 = T91^params(43);
T96 = (T91*T93)^(1-params(42));
T118 = exp(y(49))^(-params(1))/exp(y(50));
T120 = exp(y(15))^(-params(1));
T123 = T120/exp(y(20));
T132 = exp(y(15))*params(28)/exp(y(16));
T135 = params(3)/(1+params(3));
T137 = exp(y(20))*T132^T135;
T143 = exp(y(27))/exp(y(34));
T148 = exp(y(15))*params(29)/exp(y(17));
T152 = 1/(1+params(3));
T158 = params(28)^T135*exp(y(16))^T152+params(29)^T135*exp(y(17))^T152;
T167 = 1+params(22)*(1+params(24))/params(24);
T175 = params(27)*(1+params(24))/params(24);
T176 = T23/exp(y(44));
T178 = T175*T176^params(22);
T184 = T118*params(2)*params(26)/T123;
T185 = params(31)/y(51);
T188 = (1+params(22))*(-(1+params(24)))/params(24);
T189 = T185^T188;
T204 = T185^(1-(1+params(24))/params(24));
T212 = (-1)/params(24);
T215 = params(31)/y(21);
T260 = exp(y(54))^(-params(9))/exp(y(55));
T262 = exp(y(29))^(-params(9));
T263 = T262/exp(y(34));
T272 = exp(y(29))*params(34)/exp(y(30));
T275 = params(11)/(1+params(11));
T277 = exp(y(34))*T272^T275;
T283 = exp(y(29))*params(35)/exp(y(31));
T287 = 1/(1+params(11));
T293 = params(34)^T275*exp(y(30))^T287+params(35)^T275*exp(y(31))^T287;
T302 = 1+params(21)*(1+params(23))/params(23);
T310 = params(33)*(1+params(23))/params(23);
T311 = T48/exp(y(47));
T313 = T310*T311^params(21);
T319 = T260*params(10)*params(25)/T263;
T320 = params(36)/y(56);
T323 = (1+params(21))*(-(1+params(23)))/params(23);
T324 = T320^T323;
T339 = T320^(1-(1+params(23))/params(23));
T347 = (-1)/params(23);
T350 = params(36)/y(35);
T389 = params(46)/exp(y(27))*params(47);
T445 = (-(exp(y(15))*getPowerDeriv(exp(y(15)),1-params(1),1)/(1-params(1))));
T447 = exp(y(15))*getPowerDeriv(exp(y(15)),(-params(1)),1);
T448 = T447/exp(y(20));
T467 = (-(T118*params(2)*params(26)*T448))/(T123*T123);
T482 = exp(y(49))*getPowerDeriv(exp(y(49)),(-params(1)),1);
T483 = T482/exp(y(50));
T489 = params(2)*params(26)*T483/T123;
T499 = (-(exp(y(15))*params(28)*exp(y(16))))/(exp(y(16))*exp(y(16)));
T500 = getPowerDeriv(T132,T135,1)*T499;
T504 = params(28)^T135*exp(y(16))*getPowerDeriv(exp(y(16)),T152,1);
T505 = getPowerDeriv(T158,1+params(3),1);
T512 = (-(exp(y(15))*params(29)*exp(y(17))))/(exp(y(17))*exp(y(17)));
T513 = getPowerDeriv(T148,T135,1)*T512;
T517 = params(29)^T135*exp(y(17))*getPowerDeriv(exp(y(17)),T152,1);
T522 = T23*getPowerDeriv(T23,1+params(22),1);
T525 = exp(y(25))*T21*T522/(1+params(22));
T529 = T175*T176*getPowerDeriv(T176,params(22),1);
T532 = T23*T178/T123+T23*T529/T123;
T540 = (-(exp(y(20))*exp(y(1))))/(exp(y(1))*exp(y(1)));
T542 = (-(y(21)*T540));
T545 = exp(y(20))*exp(y(20));
T546 = (-(T120*exp(y(20))))/T545;
T558 = (-(T118*params(2)*params(26)*T546))/(T123*T123);
T568 = (-(exp(y(20))*1/exp(y(27))));
T571 = (-(exp(y(49))^(-params(1))*exp(y(50))));
T573 = T571/(exp(y(50))*exp(y(50)));
T579 = params(2)*params(26)*T573/T123;
T586 = 1/params(31);
T588 = T586*getPowerDeriv(T68,params(41),1);
T595 = (1+params(38))*T65*(T70*T586+T68*T588)*getPowerDeriv(T68*T70,1-params(40),1);
T600 = (-params(31))/(y(21)*y(21));
T614 = (-params(31))/(y(51)*y(51));
T616 = T614*getPowerDeriv(T185,T188,1);
T620 = getPowerDeriv(T185,1-(1+params(24))/params(24),1);
T621 = T614*T620;
T631 = (-((-(exp(y(22))*exp(y(23))))/(exp(y(23))*exp(y(23)))));
T634 = exp(y(24))*getPowerDeriv(exp(y(24)),T167,1);
T646 = 1/(1+params(38))*getPowerDeriv((1+y(3))/(1+params(38)),params(40),1);
T660 = params(47)*(-(exp(y(27))*params(46)))/(exp(y(27))*exp(y(27)));
T669 = exp(y(29))*getPowerDeriv(exp(y(29)),(-params(9)),1);
T670 = T669/exp(y(34));
T689 = (-(T260*params(10)*params(25)*T670))/(T263*T263);
T703 = exp(y(54))*getPowerDeriv(exp(y(54)),(-params(9)),1);
T704 = T703/exp(y(55));
T710 = params(10)*params(25)*T704/T263;
T720 = (-(exp(y(29))*params(34)*exp(y(30))))/(exp(y(30))*exp(y(30)));
T721 = getPowerDeriv(T272,T275,1)*T720;
T725 = params(34)^T275*exp(y(30))*getPowerDeriv(exp(y(30)),T287,1);
T726 = getPowerDeriv(T293,1+params(11),1);
T734 = (-(exp(y(31))*exp(y(29))*params(35)))/(exp(y(31))*exp(y(31)));
T735 = getPowerDeriv(T283,T275,1)*T734;
T739 = params(35)^T275*exp(y(31))*getPowerDeriv(exp(y(31)),T287,1);
T743 = T48*getPowerDeriv(T48,1+params(21),1);
T746 = exp(y(39))*T46*T743/(1+params(21));
T750 = T310*T311*getPowerDeriv(T311,params(21),1);
T753 = T48*T313/T263+T48*T750/T263;
T761 = (-(exp(y(34))*exp(y(4))))/(exp(y(4))*exp(y(4)));
T763 = (-(y(35)*T761));
T766 = exp(y(34))*exp(y(34));
T767 = (-(exp(y(27))*exp(y(34))))/T766;
T770 = (-(exp(y(34))*T262))/T766;
T782 = (-(T260*params(10)*params(25)*T770))/(T263*T263);
T792 = (-(exp(y(54))^(-params(9))*exp(y(55))));
T794 = T792/(exp(y(55))*exp(y(55)));
T800 = params(10)*params(25)*T794/T263;
T807 = 1/params(36);
T809 = T807*getPowerDeriv(T91,params(43),1);
T816 = (1+params(39))*T88*(T93*T807+T91*T809)*getPowerDeriv(T91*T93,1-params(42),1);
T821 = (-params(36))/(y(35)*y(35));
T835 = (-params(36))/(y(56)*y(56));
T837 = T835*getPowerDeriv(T320,T323,1);
T841 = getPowerDeriv(T320,1-(1+params(23))/params(23),1);
T842 = T835*T841;
T852 = (-((-(exp(y(36))*exp(y(37))))/(exp(y(37))*exp(y(37)))));
T855 = exp(y(38))*getPowerDeriv(exp(y(38)),T302,1);
T867 = 1/(1+params(39))*getPowerDeriv((1+y(6))/(1+params(39)),params(42),1);
T882 = exp(y(25))*T25*params(27)*exp(y(44))*getPowerDeriv(exp(y(44)),(-params(22)),1)/(1+params(22));
T887 = (-(exp(y(44))*T23))/(exp(y(44))*exp(y(44)));
T888 = getPowerDeriv(T176,params(22),1)*T887;
T889 = T175*T888;
T896 = (-(T23*params(32)*exp(y(45))/params(24)));
T904 = exp(y(39))*T50*params(33)*exp(y(47))*getPowerDeriv(exp(y(47)),(-params(21)),1)/(1+params(21));
T909 = (-(exp(y(47))*T48))/(exp(y(47))*exp(y(47)));
T910 = getPowerDeriv(T311,params(21),1)*T909;
T911 = T310*T910;
T918 = (-(T48*params(37)*exp(y(48))/params(23)));
T932 = (-((exp(y(15))*getPowerDeriv(exp(y(15)),1-params(1),1)+exp(y(15))*exp(y(15))*getPowerDeriv(exp(y(15)),1-params(1),2))/(1-params(1))));
T1036 = T447+exp(y(15))*exp(y(15))*getPowerDeriv(exp(y(15)),(-params(1)),2);
T1037 = T1036/exp(y(20));
T1058 = (T482+exp(y(49))*exp(y(49))*getPowerDeriv(exp(y(49)),(-params(1)),2))/exp(y(50));
T1065 = (-(exp(y(20))*T447))/T545;
T1084 = ((-(T120*exp(y(20))))*T545-(-(T120*exp(y(20))))*(T545+T545))/(T545*T545);
T1117 = (T571*exp(y(50))*exp(y(50))-T571*(exp(y(50))*exp(y(50))+exp(y(50))*exp(y(50))))/(exp(y(50))*exp(y(50))*exp(y(50))*exp(y(50)));
T1234 = (T123*T123*(-(T118*params(2)*params(26)*T1037))-(-(T118*params(2)*params(26)*T448))*(T123*T448+T123*T448))/(T123*T123*T123*T123);
T1278 = (T123*T123*(-(T118*params(2)*params(26)*T1065))-(-(T118*params(2)*params(26)*T546))*(T123*T448+T123*T448))/(T123*T123*T123*T123);
T1307 = (T123*T123*(-(T118*params(2)*params(26)*T1084))-(-(T118*params(2)*params(26)*T546))*(T123*T546+T123*T546))/(T123*T123*T123*T123);
T1319 = params(2)*params(26)*(-(exp(y(50))*T482))/(exp(y(50))*exp(y(50)))/T123;
T1482 = T669+exp(y(29))*exp(y(29))*getPowerDeriv(exp(y(29)),(-params(9)),2);
T1483 = T1482/exp(y(34));
T1504 = (T703+exp(y(54))*exp(y(54))*getPowerDeriv(exp(y(54)),(-params(9)),2))/exp(y(55));
T1511 = (-(exp(y(34))*T669))/T766;
T1528 = (T766*(-(exp(y(34))*T262))-(-(exp(y(34))*T262))*(T766+T766))/(T766*T766);
T1561 = (T792*exp(y(55))*exp(y(55))-T792*(exp(y(55))*exp(y(55))+exp(y(55))*exp(y(55))))/(exp(y(55))*exp(y(55))*exp(y(55))*exp(y(55)));
T1686 = (T263*T263*(-(T260*params(10)*params(25)*T1483))-(-(T260*params(10)*params(25)*T670))*(T263*T670+T263*T670))/(T263*T263*T263*T263);
T1730 = (T263*T263*(-(T260*params(10)*params(25)*T1511))-(-(T260*params(10)*params(25)*T770))*(T263*T670+T263*T670))/(T263*T263*T263*T263);
T1759 = (T263*T263*(-(T260*params(10)*params(25)*T1528))-(-(T260*params(10)*params(25)*T770))*(T263*T770+T263*T770))/(T263*T263*T263*T263);
T1771 = params(10)*params(25)*(-(exp(y(55))*T703))/(exp(y(55))*exp(y(55)))/T263;
lhs =y(13);
rhs =T14-T30;
residual(1)= lhs-rhs;
lhs =y(14);
rhs =exp(y(29))^(1-params(9))/(1-params(9))-T55;
residual(2)= lhs-rhs;
lhs =y(26);
rhs =(1+params(38))*T65*T73*(1+x(it_, 7))-1;
residual(3)= lhs-rhs;
lhs =y(40);
rhs =(1+params(39))*T88*T96*(1+x(it_, 8))-1;
residual(4)= lhs-rhs;
lhs =y(42);
rhs =T14+params(2)*y(59);
residual(5)= lhs-rhs;
lhs =1/(1+y(26));
rhs =params(2)*T118/T123/y(51);
residual(6)= lhs-rhs;
lhs =T137;
rhs =1;
residual(7)= lhs-rhs;
lhs =T143;
rhs =T148^T135;
residual(8)= lhs-rhs;
lhs =exp(y(15));
rhs =T158^(1+params(3));
residual(9)= lhs-rhs;
lhs =exp(y(24))^T167;
rhs =exp(y(22))/exp(y(23));
residual(10)= lhs-rhs;
lhs =exp(y(22));
rhs =T23*T178/T123+T184*T189*exp(y(52));
residual(11)= lhs-rhs;
lhs =exp(y(23));
rhs =T23*(1+params(32)*exp(y(45)))/params(24)+T184*T204*exp(y(53));
residual(12)= lhs-rhs;
lhs =(1-params(26))*exp(y(24))^T212+params(26)*T215^T212;
rhs =1;
residual(13)= lhs-rhs;
lhs =exp(y(25));
rhs =(1-params(26))*exp(y(24))^T188+params(26)*T215^T188*exp(y(2));
residual(14)= lhs-rhs;
lhs =T23;
rhs =exp(y(16))+exp(y(19))+1/params(30)*exp(y(31));
residual(15)= lhs-rhs;
lhs =exp(y(19));
rhs =T23*params(4)*exp(y(43));
residual(16)= lhs-rhs;
lhs =y(28);
rhs =y(21)*exp(y(20))/exp(y(1));
residual(17)= lhs-rhs;
lhs =1/(1+y(40));
rhs =params(10)*T260/T263/y(56);
residual(18)= lhs-rhs;
lhs =T277;
rhs =1;
residual(19)= lhs-rhs;
lhs =1/exp(y(27))/exp(y(20));
rhs =T283^T275;
residual(20)= lhs-rhs;
lhs =exp(y(29));
rhs =T293^(1+params(11));
residual(21)= lhs-rhs;
lhs =exp(y(38))^T302;
rhs =exp(y(36))/exp(y(37));
residual(22)= lhs-rhs;
lhs =exp(y(36));
rhs =T48*T313/T263+T319*T324*exp(y(57));
residual(23)= lhs-rhs;
lhs =exp(y(37));
rhs =T48*(1+params(37)*exp(y(48)))/params(23)+T319*T339*exp(y(58));
residual(24)= lhs-rhs;
lhs =(1-params(25))*exp(y(38))^T347+params(25)*T350^T347;
rhs =1;
residual(25)= lhs-rhs;
lhs =exp(y(39));
rhs =(1-params(25))*exp(y(38))^T323+params(25)*T350^T323*exp(y(5));
residual(26)= lhs-rhs;
lhs =T48;
rhs =exp(y(30))+exp(y(33))+exp(y(17))*params(30);
residual(27)= lhs-rhs;
lhs =exp(y(33));
rhs =T48*params(12)*exp(y(46));
residual(28)= lhs-rhs;
lhs =y(41);
rhs =y(35)*exp(y(34))/exp(y(4));
residual(29)= lhs-rhs;
lhs =params(44)/T262*params(45);
rhs =T389/T120*params(48);
residual(30)= lhs-rhs;
lhs =y(43);
rhs =params(5)*y(7)+params(6)*x(it_, 1);
residual(31)= lhs-rhs;
lhs =y(44);
rhs =params(7)*y(8)+params(8)*x(it_, 2);
residual(32)= lhs-rhs;
lhs =y(45);
rhs =params(19)*y(9)+params(20)*x(it_, 6);
residual(33)= lhs-rhs;
lhs =y(46);
rhs =params(13)*y(10)+params(14)*x(it_, 3);
residual(34)= lhs-rhs;
lhs =y(47);
rhs =params(15)*y(11)+params(16)*x(it_, 4);
residual(35)= lhs-rhs;
lhs =y(48);
rhs =params(17)*y(12)+params(18)*x(it_, 5);
residual(36)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(36, 67);

  %
  % Jacobian matrix
  %

  g1(1,13)=1;
  g1(1,15)=T445;
  g1(1,18)=T525;
  g1(1,25)=T30;
  g1(1,44)=T882;
  g1(2,14)=1;
  g1(2,29)=(-(exp(y(29))*getPowerDeriv(exp(y(29)),1-params(9),1)/(1-params(9))));
  g1(2,32)=T746;
  g1(2,39)=T55;
  g1(2,47)=T904;
  g1(3,21)=(-((1+x(it_, 7))*T595));
  g1(3,3)=(-((1+x(it_, 7))*(1+params(38))*T73*T646));
  g1(3,26)=1;
  g1(3,66)=(-((1+params(38))*T65*T73));
  g1(4,35)=(-((1+x(it_, 8))*T816));
  g1(4,6)=(-((1+x(it_, 8))*(1+params(39))*T96*T867));
  g1(4,40)=1;
  g1(4,67)=(-((1+params(39))*T88*T96));
  g1(5,15)=T445;
  g1(5,42)=1;
  g1(5,59)=(-params(2));
  g1(6,15)=(-((-(params(2)*T118*T448))/(T123*T123)/y(51)));
  g1(6,49)=(-(params(2)*T483/T123/y(51)));
  g1(6,20)=(-((-(params(2)*T118*T546))/(T123*T123)/y(51)));
  g1(6,50)=(-(params(2)*T573/T123/y(51)));
  g1(6,51)=(-((-(params(2)*T118/T123))/(y(51)*y(51))));
  g1(6,26)=(-1)/((1+y(26))*(1+y(26)));
  g1(7,15)=exp(y(20))*T132*getPowerDeriv(T132,T135,1);
  g1(7,16)=exp(y(20))*T500;
  g1(7,20)=T137;
  g1(8,15)=(-(T148*getPowerDeriv(T148,T135,1)));
  g1(8,17)=(-T513);
  g1(8,27)=T143;
  g1(8,34)=T767;
  g1(9,15)=exp(y(15));
  g1(9,16)=(-(T504*T505));
  g1(9,17)=(-(T505*T517));
  g1(10,22)=(-(exp(y(22))/exp(y(23))));
  g1(10,23)=T631;
  g1(10,24)=T634;
  g1(11,15)=(-(T23*(-(T178*T448))/(T123*T123)+exp(y(52))*T189*T467));
  g1(11,49)=(-(exp(y(52))*T189*T489));
  g1(11,18)=(-T532);
  g1(11,20)=(-(T23*(-(T178*T546))/(T123*T123)+exp(y(52))*T189*T558));
  g1(11,50)=(-(exp(y(52))*T189*T579));
  g1(11,51)=(-(exp(y(52))*T184*T616));
  g1(11,22)=exp(y(22));
  g1(11,52)=(-(T184*T189*exp(y(52))));
  g1(11,44)=(-(T23*T889/T123));
  g1(12,15)=(-(exp(y(53))*T204*T467));
  g1(12,49)=(-(exp(y(53))*T204*T489));
  g1(12,18)=(-(T23*(1+params(32)*exp(y(45)))/params(24)));
  g1(12,20)=(-(exp(y(53))*T204*T558));
  g1(12,50)=(-(exp(y(53))*T204*T579));
  g1(12,51)=(-(exp(y(53))*T184*T621));
  g1(12,23)=exp(y(23));
  g1(12,53)=(-(T184*T204*exp(y(53))));
  g1(12,45)=T896;
  g1(13,21)=params(26)*T600*getPowerDeriv(T215,T212,1);
  g1(13,24)=(1-params(26))*exp(y(24))*getPowerDeriv(exp(y(24)),T212,1);
  g1(14,21)=(-(exp(y(2))*params(26)*T600*getPowerDeriv(T215,T188,1)));
  g1(14,24)=(-((1-params(26))*exp(y(24))*getPowerDeriv(exp(y(24)),T188,1)));
  g1(14,2)=(-(params(26)*T215^T188*exp(y(2))));
  g1(14,25)=exp(y(25));
  g1(15,16)=(-exp(y(16)));
  g1(15,18)=T23;
  g1(15,19)=(-exp(y(19)));
  g1(15,31)=(-(1/params(30)*exp(y(31))));
  g1(16,18)=(-(T23*params(4)*exp(y(43))));
  g1(16,19)=exp(y(19));
  g1(16,43)=(-(T23*params(4)*exp(y(43))));
  g1(17,1)=T542;
  g1(17,20)=(-(y(21)*exp(y(20))/exp(y(1))));
  g1(17,21)=(-(exp(y(20))/exp(y(1))));
  g1(17,28)=1;
  g1(18,29)=(-((-(params(10)*T260*T670))/(T263*T263)/y(56)));
  g1(18,54)=(-(params(10)*T704/T263/y(56)));
  g1(18,34)=(-((-(params(10)*T260*T770))/(T263*T263)/y(56)));
  g1(18,55)=(-(params(10)*T794/T263/y(56)));
  g1(18,56)=(-((-(params(10)*T260/T263))/(y(56)*y(56))));
  g1(18,40)=(-1)/((1+y(40))*(1+y(40)));
  g1(19,29)=exp(y(34))*T272*getPowerDeriv(T272,T275,1);
  g1(19,30)=exp(y(34))*T721;
  g1(19,34)=T277;
  g1(20,20)=T568/T545;
  g1(20,27)=(-exp(y(27)))/(exp(y(27))*exp(y(27)))/exp(y(20));
  g1(20,29)=(-(T283*getPowerDeriv(T283,T275,1)));
  g1(20,31)=(-T735);
  g1(21,29)=exp(y(29));
  g1(21,30)=(-(T725*T726));
  g1(21,31)=(-(T726*T739));
  g1(22,36)=(-(exp(y(36))/exp(y(37))));
  g1(22,37)=T852;
  g1(22,38)=T855;
  g1(23,29)=(-(T48*(-(T313*T670))/(T263*T263)+exp(y(57))*T324*T689));
  g1(23,54)=(-(exp(y(57))*T324*T710));
  g1(23,32)=(-T753);
  g1(23,34)=(-(T48*(-(T313*T770))/(T263*T263)+exp(y(57))*T324*T782));
  g1(23,55)=(-(exp(y(57))*T324*T800));
  g1(23,56)=(-(exp(y(57))*T319*T837));
  g1(23,36)=exp(y(36));
  g1(23,57)=(-(T319*T324*exp(y(57))));
  g1(23,47)=(-(T48*T911/T263));
  g1(24,29)=(-(exp(y(58))*T339*T689));
  g1(24,54)=(-(exp(y(58))*T339*T710));
  g1(24,32)=(-(T48*(1+params(37)*exp(y(48)))/params(23)));
  g1(24,34)=(-(exp(y(58))*T339*T782));
  g1(24,55)=(-(exp(y(58))*T339*T800));
  g1(24,56)=(-(exp(y(58))*T319*T842));
  g1(24,37)=exp(y(37));
  g1(24,58)=(-(T319*T339*exp(y(58))));
  g1(24,48)=T918;
  g1(25,35)=params(25)*T821*getPowerDeriv(T350,T347,1);
  g1(25,38)=(1-params(25))*exp(y(38))*getPowerDeriv(exp(y(38)),T347,1);
  g1(26,35)=(-(exp(y(5))*params(25)*T821*getPowerDeriv(T350,T323,1)));
  g1(26,38)=(-((1-params(25))*exp(y(38))*getPowerDeriv(exp(y(38)),T323,1)));
  g1(26,5)=(-(params(25)*T350^T323*exp(y(5))));
  g1(26,39)=exp(y(39));
  g1(27,17)=(-(exp(y(17))*params(30)));
  g1(27,30)=(-exp(y(30)));
  g1(27,32)=T48;
  g1(27,33)=(-exp(y(33)));
  g1(28,32)=(-(T48*params(12)*exp(y(46))));
  g1(28,33)=exp(y(33));
  g1(28,46)=(-(T48*params(12)*exp(y(46))));
  g1(29,4)=T763;
  g1(29,34)=(-(y(35)*exp(y(34))/exp(y(4))));
  g1(29,35)=(-(exp(y(34))/exp(y(4))));
  g1(29,41)=1;
  g1(30,15)=(-(params(48)*(-(T389*T447))/(T120*T120)));
  g1(30,27)=(-(params(48)*T660/T120));
  g1(30,29)=params(45)*(-(params(44)*T669))/(T262*T262);
  g1(31,7)=(-params(5));
  g1(31,43)=1;
  g1(31,60)=(-params(6));
  g1(32,8)=(-params(7));
  g1(32,44)=1;
  g1(32,61)=(-params(8));
  g1(33,9)=(-params(19));
  g1(33,45)=1;
  g1(33,65)=(-params(20));
  g1(34,10)=(-params(13));
  g1(34,46)=1;
  g1(34,62)=(-params(14));
  g1(35,11)=(-params(15));
  g1(35,47)=1;
  g1(35,63)=(-params(16));
  g1(36,12)=(-params(17));
  g1(36,48)=1;
  g1(36,64)=(-params(18));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(378,3);
  v2(1,1)=1;
  v2(1,2)=953;
  v2(1,3)=T932;
  v2(2,1)=1;
  v2(2,2)=1157;
  v2(2,3)=exp(y(25))*T21*(T522+T23*T23*getPowerDeriv(T23,1+params(22),2))/(1+params(22));
  v2(3,1)=1;
  v2(3,2)=1626;
  v2(3,3)=T525;
  v2(4,1)=1;
  v2(4,2)=1164;
  v2(4,3)=  v2(3,3);
  v2(5,1)=1;
  v2(5,2)=1633;
  v2(5,3)=T30;
  v2(6,1)=1;
  v2(6,2)=2899;
  v2(6,3)=exp(y(25))*T522*params(27)*exp(y(44))*getPowerDeriv(exp(y(44)),(-params(22)),1)/(1+params(22));
  v2(7,1)=1;
  v2(7,2)=1183;
  v2(7,3)=  v2(6,3);
  v2(8,1)=1;
  v2(8,2)=2906;
  v2(8,3)=T882;
  v2(9,1)=1;
  v2(9,2)=1652;
  v2(9,3)=  v2(8,3);
  v2(10,1)=1;
  v2(10,2)=2925;
  v2(10,3)=exp(y(25))*T25*params(27)*(exp(y(44))*getPowerDeriv(exp(y(44)),(-params(22)),1)+exp(y(44))*exp(y(44))*getPowerDeriv(exp(y(44)),(-params(22)),2))/(1+params(22));
  v2(11,1)=2;
  v2(11,2)=1905;
  v2(11,3)=(-((exp(y(29))*getPowerDeriv(exp(y(29)),1-params(9),1)+exp(y(29))*exp(y(29))*getPowerDeriv(exp(y(29)),1-params(9),2))/(1-params(9))));
  v2(12,1)=2;
  v2(12,2)=2109;
  v2(12,3)=exp(y(39))*T46*(T743+T48*T48*getPowerDeriv(T48,1+params(21),2))/(1+params(21));
  v2(13,1)=2;
  v2(13,2)=2578;
  v2(13,3)=T746;
  v2(14,1)=2;
  v2(14,2)=2116;
  v2(14,3)=  v2(13,3);
  v2(15,1)=2;
  v2(15,2)=2585;
  v2(15,3)=T55;
  v2(16,1)=2;
  v2(16,2)=3114;
  v2(16,3)=exp(y(39))*T743*params(33)*exp(y(47))*getPowerDeriv(exp(y(47)),(-params(21)),1)/(1+params(21));
  v2(17,1)=2;
  v2(17,2)=2124;
  v2(17,3)=  v2(16,3);
  v2(18,1)=2;
  v2(18,2)=3121;
  v2(18,3)=T904;
  v2(19,1)=2;
  v2(19,2)=2593;
  v2(19,3)=  v2(18,3);
  v2(20,1)=2;
  v2(20,2)=3129;
  v2(20,3)=exp(y(39))*T50*params(33)*(exp(y(47))*getPowerDeriv(exp(y(47)),(-params(21)),1)+exp(y(47))*exp(y(47))*getPowerDeriv(exp(y(47)),(-params(21)),2))/(1+params(21));
  v2(21,1)=3;
  v2(21,2)=1361;
  v2(21,3)=(-((1+x(it_, 7))*(1+params(38))*T65*(getPowerDeriv(T68*T70,1-params(40),1)*(T586*T588+T586*T588+T68*T586*T586*getPowerDeriv(T68,params(41),2))+(T70*T586+T68*T588)*(T70*T586+T68*T588)*getPowerDeriv(T68*T70,1-params(40),2))));
  v2(22,1)=3;
  v2(22,2)=155;
  v2(22,3)=(-((1+x(it_, 7))*(1+params(38))*(T70*T586+T68*T588)*getPowerDeriv(T68*T70,1-params(40),1)*T646));
  v2(23,1)=3;
  v2(23,2)=1343;
  v2(23,3)=  v2(22,3);
  v2(24,1)=3;
  v2(24,2)=137;
  v2(24,3)=(-((1+x(it_, 7))*(1+params(38))*T73*1/(1+params(38))*1/(1+params(38))*getPowerDeriv((1+y(3))/(1+params(38)),params(40),2)));
  v2(25,1)=3;
  v2(25,2)=4376;
  v2(25,3)=(-T595);
  v2(26,1)=3;
  v2(26,2)=1406;
  v2(26,3)=  v2(25,3);
  v2(27,1)=3;
  v2(27,2)=4358;
  v2(27,3)=(-((1+params(38))*T73*T646));
  v2(28,1)=3;
  v2(28,2)=200;
  v2(28,3)=  v2(27,3);
  v2(29,1)=4;
  v2(29,2)=2313;
  v2(29,3)=(-((1+x(it_, 8))*(1+params(39))*T88*(getPowerDeriv(T91*T93,1-params(42),1)*(T807*T809+T807*T809+T91*T807*T807*getPowerDeriv(T91,params(43),2))+(T93*T807+T91*T809)*(T93*T807+T91*T809)*getPowerDeriv(T91*T93,1-params(42),2))));
  v2(30,1)=4;
  v2(30,2)=370;
  v2(30,3)=(-((1+x(it_, 8))*(1+params(39))*(T93*T807+T91*T809)*getPowerDeriv(T91*T93,1-params(42),1)*T867));
  v2(31,1)=4;
  v2(31,2)=2284;
  v2(31,3)=  v2(30,3);
  v2(32,1)=4;
  v2(32,2)=341;
  v2(32,3)=(-((1+x(it_, 8))*(1+params(39))*T96*1/(1+params(39))*1/(1+params(39))*getPowerDeriv((1+y(6))/(1+params(39)),params(42),2)));
  v2(33,1)=4;
  v2(33,2)=4457;
  v2(33,3)=(-T816);
  v2(34,1)=4;
  v2(34,2)=2345;
  v2(34,3)=  v2(33,3);
  v2(35,1)=4;
  v2(35,2)=4428;
  v2(35,3)=(-((1+params(39))*T96*T867));
  v2(36,1)=4;
  v2(36,2)=402;
  v2(36,3)=  v2(35,3);
  v2(37,1)=5;
  v2(37,2)=953;
  v2(37,3)=T932;
  v2(38,1)=6;
  v2(38,2)=953;
  v2(38,3)=(-((T123*T123*(-(params(2)*T118*T1037))-(-(params(2)*T118*T448))*(T123*T448+T123*T448))/(T123*T123*T123*T123)/y(51)));
  v2(39,1)=6;
  v2(39,2)=3231;
  v2(39,3)=(-((-(T448*params(2)*T483))/(T123*T123)/y(51)));
  v2(40,1)=6;
  v2(40,2)=987;
  v2(40,3)=  v2(39,3);
  v2(41,1)=6;
  v2(41,2)=3265;
  v2(41,3)=(-(params(2)*T1058/T123/y(51)));
  v2(42,1)=6;
  v2(42,2)=1288;
  v2(42,3)=(-((T123*T123*(-(params(2)*T118*T1065))-(-(params(2)*T118*T546))*(T123*T448+T123*T448))/(T123*T123*T123*T123)/y(51)));
  v2(43,1)=6;
  v2(43,2)=958;
  v2(43,3)=  v2(42,3);
  v2(44,1)=6;
  v2(44,2)=1322;
  v2(44,3)=(-((-(params(2)*T483*T546))/(T123*T123)/y(51)));
  v2(45,1)=6;
  v2(45,2)=3236;
  v2(45,3)=  v2(44,3);
  v2(46,1)=6;
  v2(46,2)=1293;
  v2(46,3)=(-((T123*T123*(-(params(2)*T118*T1084))-(-(params(2)*T118*T546))*(T123*T546+T123*T546))/(T123*T123*T123*T123)/y(51)));
  v2(47,1)=6;
  v2(47,2)=3298;
  v2(47,3)=(-((-(T448*params(2)*T573))/(T123*T123)/y(51)));
  v2(48,1)=6;
  v2(48,2)=988;
  v2(48,3)=  v2(47,3);
  v2(49,1)=6;
  v2(49,2)=3332;
  v2(49,3)=(-(params(2)*(-(exp(y(50))*T482))/(exp(y(50))*exp(y(50)))/T123/y(51)));
  v2(50,1)=6;
  v2(50,2)=3266;
  v2(50,3)=  v2(49,3);
  v2(51,1)=6;
  v2(51,2)=3303;
  v2(51,3)=(-((-(T546*params(2)*T573))/(T123*T123)/y(51)));
  v2(52,1)=6;
  v2(52,2)=1323;
  v2(52,3)=  v2(51,3);
  v2(53,1)=6;
  v2(53,2)=3333;
  v2(53,3)=(-(params(2)*T1117/T123/y(51)));
  v2(54,1)=6;
  v2(54,2)=3365;
  v2(54,3)=(-((-((-(params(2)*T118*T448))/(T123*T123)))/(y(51)*y(51))));
  v2(55,1)=6;
  v2(55,2)=989;
  v2(55,3)=  v2(54,3);
  v2(56,1)=6;
  v2(56,2)=3399;
  v2(56,3)=(-((-(params(2)*T483/T123))/(y(51)*y(51))));
  v2(57,1)=6;
  v2(57,2)=3267;
  v2(57,3)=  v2(56,3);
  v2(58,1)=6;
  v2(58,2)=3370;
  v2(58,3)=(-((-((-(params(2)*T118*T546))/(T123*T123)))/(y(51)*y(51))));
  v2(59,1)=6;
  v2(59,2)=1324;
  v2(59,3)=  v2(58,3);
  v2(60,1)=6;
  v2(60,2)=3400;
  v2(60,3)=(-((-(params(2)*T573/T123))/(y(51)*y(51))));
  v2(61,1)=6;
  v2(61,2)=3334;
  v2(61,3)=  v2(60,3);
  v2(62,1)=6;
  v2(62,2)=3401;
  v2(62,3)=(-((-((-(params(2)*T118/T123))*(y(51)+y(51))))/(y(51)*y(51)*y(51)*y(51))));
  v2(63,1)=6;
  v2(63,2)=1701;
  v2(63,3)=(1+y(26)+1+y(26))/((1+y(26))*(1+y(26))*(1+y(26))*(1+y(26)));
  v2(64,1)=7;
  v2(64,2)=953;
  v2(64,3)=exp(y(20))*(T132*getPowerDeriv(T132,T135,1)+T132*T132*getPowerDeriv(T132,T135,2));
  v2(65,1)=7;
  v2(65,2)=1020;
  v2(65,3)=exp(y(20))*(T500+T499*T132*getPowerDeriv(T132,T135,2));
  v2(66,1)=7;
  v2(66,2)=954;
  v2(66,3)=  v2(65,3);
  v2(67,1)=7;
  v2(67,2)=1021;
  v2(67,3)=exp(y(20))*(T499*T499*getPowerDeriv(T132,T135,2)+getPowerDeriv(T132,T135,1)*((-(exp(y(15))*params(28)*exp(y(16))))*exp(y(16))*exp(y(16))-(-(exp(y(15))*params(28)*exp(y(16))))*(exp(y(16))*exp(y(16))+exp(y(16))*exp(y(16))))/(exp(y(16))*exp(y(16))*exp(y(16))*exp(y(16))));
  v2(68,1)=7;
  v2(68,2)=1288;
  v2(68,3)=exp(y(20))*T132*getPowerDeriv(T132,T135,1);
  v2(69,1)=7;
  v2(69,2)=958;
  v2(69,3)=  v2(68,3);
  v2(70,1)=7;
  v2(70,2)=1289;
  v2(70,3)=exp(y(20))*T500;
  v2(71,1)=7;
  v2(71,2)=1025;
  v2(71,3)=  v2(70,3);
  v2(72,1)=7;
  v2(72,2)=1293;
  v2(72,3)=T137;
  v2(73,1)=8;
  v2(73,2)=953;
  v2(73,3)=(-(T148*getPowerDeriv(T148,T135,1)+T148*T148*getPowerDeriv(T148,T135,2)));
  v2(74,1)=8;
  v2(74,2)=1087;
  v2(74,3)=(-(T513+T512*T148*getPowerDeriv(T148,T135,2)));
  v2(75,1)=8;
  v2(75,2)=955;
  v2(75,3)=  v2(74,3);
  v2(76,1)=8;
  v2(76,2)=1089;
  v2(76,3)=(-(T512*T512*getPowerDeriv(T148,T135,2)+getPowerDeriv(T148,T135,1)*((-(exp(y(15))*params(29)*exp(y(17))))*exp(y(17))*exp(y(17))-(-(exp(y(15))*params(29)*exp(y(17))))*(exp(y(17))*exp(y(17))+exp(y(17))*exp(y(17))))/(exp(y(17))*exp(y(17))*exp(y(17))*exp(y(17)))));
  v2(77,1)=8;
  v2(77,2)=1769;
  v2(77,3)=T143;
  v2(78,1)=8;
  v2(78,2)=2238;
  v2(78,3)=T767;
  v2(79,1)=8;
  v2(79,2)=1776;
  v2(79,3)=  v2(78,3);
  v2(80,1)=8;
  v2(80,2)=2245;
  v2(80,3)=((-(exp(y(27))*exp(y(34))))*T766-(-(exp(y(27))*exp(y(34))))*(T766+T766))/(T766*T766);
  v2(81,1)=9;
  v2(81,2)=953;
  v2(81,3)=exp(y(15));
  v2(82,1)=9;
  v2(82,2)=1021;
  v2(82,3)=(-(T505*params(28)^T135*(exp(y(16))*getPowerDeriv(exp(y(16)),T152,1)+exp(y(16))*exp(y(16))*getPowerDeriv(exp(y(16)),T152,2))+T504*T504*getPowerDeriv(T158,1+params(3),2)));
  v2(83,1)=9;
  v2(83,2)=1088;
  v2(83,3)=(-(T517*T504*getPowerDeriv(T158,1+params(3),2)));
  v2(84,1)=9;
  v2(84,2)=1022;
  v2(84,3)=  v2(83,3);
  v2(85,1)=9;
  v2(85,2)=1089;
  v2(85,3)=(-(T517*T517*getPowerDeriv(T158,1+params(3),2)+T505*params(29)^T135*(exp(y(17))*getPowerDeriv(exp(y(17)),T152,1)+exp(y(17))*exp(y(17))*getPowerDeriv(exp(y(17)),T152,2))));
  v2(86,1)=10;
  v2(86,2)=1429;
  v2(86,3)=(-(exp(y(22))/exp(y(23))));
  v2(87,1)=10;
  v2(87,2)=1496;
  v2(87,3)=T631;
  v2(88,1)=10;
  v2(88,2)=1430;
  v2(88,3)=  v2(87,3);
  v2(89,1)=10;
  v2(89,2)=1497;
  v2(89,3)=(-(((-(exp(y(22))*exp(y(23))))*exp(y(23))*exp(y(23))-(-(exp(y(22))*exp(y(23))))*(exp(y(23))*exp(y(23))+exp(y(23))*exp(y(23))))/(exp(y(23))*exp(y(23))*exp(y(23))*exp(y(23)))));
  v2(90,1)=10;
  v2(90,2)=1565;
  v2(90,3)=T634+exp(y(24))*exp(y(24))*getPowerDeriv(exp(y(24)),T167,2);
  v2(91,1)=11;
  v2(91,2)=953;
  v2(91,3)=(-(T23*(T123*T123*(-(T178*T1037))-(-(T178*T448))*(T123*T448+T123*T448))/(T123*T123*T123*T123)+exp(y(52))*T189*T1234));
  v2(92,1)=11;
  v2(92,2)=3231;
  v2(92,3)=(-(exp(y(52))*T189*(-(T448*params(2)*params(26)*T483))/(T123*T123)));
  v2(93,1)=11;
  v2(93,2)=987;
  v2(93,3)=  v2(92,3);
  v2(94,1)=11;
  v2(94,2)=3265;
  v2(94,3)=(-(exp(y(52))*T189*params(2)*params(26)*T1058/T123));
  v2(95,1)=11;
  v2(95,2)=1154;
  v2(95,3)=(-(T23*(-(T178*T448))/(T123*T123)+T23*(-(T448*T529))/(T123*T123)));
  v2(96,1)=11;
  v2(96,2)=956;
  v2(96,3)=  v2(95,3);
  v2(97,1)=11;
  v2(97,2)=1157;
  v2(97,3)=(-(T532+T23*T529/T123+T23*T175*(T176*getPowerDeriv(T176,params(22),1)+T176*T176*getPowerDeriv(T176,params(22),2))/T123));
  v2(98,1)=11;
  v2(98,2)=1288;
  v2(98,3)=(-(T23*(T123*T123*(-(T178*T1065))-(-(T178*T546))*(T123*T448+T123*T448))/(T123*T123*T123*T123)+exp(y(52))*T189*T1278));
  v2(99,1)=11;
  v2(99,2)=958;
  v2(99,3)=  v2(98,3);
  v2(100,1)=11;
  v2(100,2)=1322;
  v2(100,3)=(-(exp(y(52))*T189*(-(params(2)*params(26)*T483*T546))/(T123*T123)));
  v2(101,1)=11;
  v2(101,2)=3236;
  v2(101,3)=  v2(100,3);
  v2(102,1)=11;
  v2(102,2)=1291;
  v2(102,3)=(-(T23*(-(T178*T546))/(T123*T123)+T23*(-(T529*T546))/(T123*T123)));
  v2(103,1)=11;
  v2(103,2)=1159;
  v2(103,3)=  v2(102,3);
  v2(104,1)=11;
  v2(104,2)=1293;
  v2(104,3)=(-(T23*(T123*T123*(-(T178*T1084))-(-(T178*T546))*(T123*T546+T123*T546))/(T123*T123*T123*T123)+exp(y(52))*T189*T1307));
  v2(105,1)=11;
  v2(105,2)=3298;
  v2(105,3)=(-(exp(y(52))*T189*(-(T448*params(2)*params(26)*T573))/(T123*T123)));
  v2(106,1)=11;
  v2(106,2)=988;
  v2(106,3)=  v2(105,3);
  v2(107,1)=11;
  v2(107,2)=3332;
  v2(107,3)=(-(exp(y(52))*T189*T1319));
  v2(108,1)=11;
  v2(108,2)=3266;
  v2(108,3)=  v2(107,3);
  v2(109,1)=11;
  v2(109,2)=3303;
  v2(109,3)=(-(exp(y(52))*T189*(-(T546*params(2)*params(26)*T573))/(T123*T123)));
  v2(110,1)=11;
  v2(110,2)=1323;
  v2(110,3)=  v2(109,3);
  v2(111,1)=11;
  v2(111,2)=3333;
  v2(111,3)=(-(exp(y(52))*T189*params(2)*params(26)*T1117/T123));
  v2(112,1)=11;
  v2(112,2)=3365;
  v2(112,3)=(-(exp(y(52))*T467*T616));
  v2(113,1)=11;
  v2(113,2)=989;
  v2(113,3)=  v2(112,3);
  v2(114,1)=11;
  v2(114,2)=3399;
  v2(114,3)=(-(exp(y(52))*T489*T616));
  v2(115,1)=11;
  v2(115,2)=3267;
  v2(115,3)=  v2(114,3);
  v2(116,1)=11;
  v2(116,2)=3370;
  v2(116,3)=(-(exp(y(52))*T558*T616));
  v2(117,1)=11;
  v2(117,2)=1324;
  v2(117,3)=  v2(116,3);
  v2(118,1)=11;
  v2(118,2)=3400;
  v2(118,3)=(-(exp(y(52))*T579*T616));
  v2(119,1)=11;
  v2(119,2)=3334;
  v2(119,3)=  v2(118,3);
  v2(120,1)=11;
  v2(120,2)=3401;
  v2(120,3)=(-(exp(y(52))*T184*(getPowerDeriv(T185,T188,1)*(-((-params(31))*(y(51)+y(51))))/(y(51)*y(51)*y(51)*y(51))+T614*T614*getPowerDeriv(T185,T188,2))));
  v2(121,1)=11;
  v2(121,2)=1429;
  v2(121,3)=exp(y(22));
  v2(122,1)=11;
  v2(122,2)=3432;
  v2(122,3)=(-(exp(y(52))*T189*T467));
  v2(123,1)=11;
  v2(123,2)=990;
  v2(123,3)=  v2(122,3);
  v2(124,1)=11;
  v2(124,2)=3466;
  v2(124,3)=(-(exp(y(52))*T189*T489));
  v2(125,1)=11;
  v2(125,2)=3268;
  v2(125,3)=  v2(124,3);
  v2(126,1)=11;
  v2(126,2)=3437;
  v2(126,3)=(-(exp(y(52))*T189*T558));
  v2(127,1)=11;
  v2(127,2)=1325;
  v2(127,3)=  v2(126,3);
  v2(128,1)=11;
  v2(128,2)=3467;
  v2(128,3)=(-(exp(y(52))*T189*T579));
  v2(129,1)=11;
  v2(129,2)=3335;
  v2(129,3)=  v2(128,3);
  v2(130,1)=11;
  v2(130,2)=3468;
  v2(130,3)=(-(exp(y(52))*T184*T616));
  v2(131,1)=11;
  v2(131,2)=3402;
  v2(131,3)=  v2(130,3);
  v2(132,1)=11;
  v2(132,2)=3469;
  v2(132,3)=(-(T184*T189*exp(y(52))));
  v2(133,1)=11;
  v2(133,2)=2896;
  v2(133,3)=(-(T23*(-(T448*T889))/(T123*T123)));
  v2(134,1)=11;
  v2(134,2)=982;
  v2(134,3)=  v2(133,3);
  v2(135,1)=11;
  v2(135,2)=2899;
  v2(135,3)=(-(T23*T889/T123+T23*T175*(T888+T887*T176*getPowerDeriv(T176,params(22),2))/T123));
  v2(136,1)=11;
  v2(136,2)=1183;
  v2(136,3)=  v2(135,3);
  v2(137,1)=11;
  v2(137,2)=2901;
  v2(137,3)=(-(T23*(-(T546*T889))/(T123*T123)));
  v2(138,1)=11;
  v2(138,2)=1317;
  v2(138,3)=  v2(137,3);
  v2(139,1)=11;
  v2(139,2)=2925;
  v2(139,3)=(-(T23*T175*(T887*T887*getPowerDeriv(T176,params(22),2)+getPowerDeriv(T176,params(22),1)*((-(exp(y(44))*T23))*exp(y(44))*exp(y(44))-(-(exp(y(44))*T23))*(exp(y(44))*exp(y(44))+exp(y(44))*exp(y(44))))/(exp(y(44))*exp(y(44))*exp(y(44))*exp(y(44))))/T123));
  v2(140,1)=12;
  v2(140,2)=953;
  v2(140,3)=(-(exp(y(53))*T204*T1234));
  v2(141,1)=12;
  v2(141,2)=3231;
  v2(141,3)=(-(exp(y(53))*T204*(-(T448*params(2)*params(26)*T483))/(T123*T123)));
  v2(142,1)=12;
  v2(142,2)=987;
  v2(142,3)=  v2(141,3);
  v2(143,1)=12;
  v2(143,2)=3265;
  v2(143,3)=(-(exp(y(53))*T204*params(2)*params(26)*T1058/T123));
  v2(144,1)=12;
  v2(144,2)=1157;
  v2(144,3)=(-(T23*(1+params(32)*exp(y(45)))/params(24)));
  v2(145,1)=12;
  v2(145,2)=1288;
  v2(145,3)=(-(exp(y(53))*T204*T1278));
  v2(146,1)=12;
  v2(146,2)=958;
  v2(146,3)=  v2(145,3);
  v2(147,1)=12;
  v2(147,2)=1322;
  v2(147,3)=(-(exp(y(53))*T204*(-(params(2)*params(26)*T483*T546))/(T123*T123)));
  v2(148,1)=12;
  v2(148,2)=3236;
  v2(148,3)=  v2(147,3);
  v2(149,1)=12;
  v2(149,2)=1293;
  v2(149,3)=(-(exp(y(53))*T204*T1307));
  v2(150,1)=12;
  v2(150,2)=3298;
  v2(150,3)=(-(exp(y(53))*T204*(-(T448*params(2)*params(26)*T573))/(T123*T123)));
  v2(151,1)=12;
  v2(151,2)=988;
  v2(151,3)=  v2(150,3);
  v2(152,1)=12;
  v2(152,2)=3332;
  v2(152,3)=(-(exp(y(53))*T204*T1319));
  v2(153,1)=12;
  v2(153,2)=3266;
  v2(153,3)=  v2(152,3);
  v2(154,1)=12;
  v2(154,2)=3303;
  v2(154,3)=(-(exp(y(53))*T204*(-(T546*params(2)*params(26)*T573))/(T123*T123)));
  v2(155,1)=12;
  v2(155,2)=1323;
  v2(155,3)=  v2(154,3);
  v2(156,1)=12;
  v2(156,2)=3333;
  v2(156,3)=(-(exp(y(53))*T204*params(2)*params(26)*T1117/T123));
  v2(157,1)=12;
  v2(157,2)=3365;
  v2(157,3)=(-(exp(y(53))*T467*T621));
  v2(158,1)=12;
  v2(158,2)=989;
  v2(158,3)=  v2(157,3);
  v2(159,1)=12;
  v2(159,2)=3399;
  v2(159,3)=(-(exp(y(53))*T489*T621));
  v2(160,1)=12;
  v2(160,2)=3267;
  v2(160,3)=  v2(159,3);
  v2(161,1)=12;
  v2(161,2)=3370;
  v2(161,3)=(-(exp(y(53))*T558*T621));
  v2(162,1)=12;
  v2(162,2)=1324;
  v2(162,3)=  v2(161,3);
  v2(163,1)=12;
  v2(163,2)=3400;
  v2(163,3)=(-(exp(y(53))*T579*T621));
  v2(164,1)=12;
  v2(164,2)=3334;
  v2(164,3)=  v2(163,3);
  v2(165,1)=12;
  v2(165,2)=3401;
  v2(165,3)=(-(exp(y(53))*T184*(T620*(-((-params(31))*(y(51)+y(51))))/(y(51)*y(51)*y(51)*y(51))+T614*T614*getPowerDeriv(T185,1-(1+params(24))/params(24),2))));
  v2(166,1)=12;
  v2(166,2)=1497;
  v2(166,3)=exp(y(23));
  v2(167,1)=12;
  v2(167,2)=3499;
  v2(167,3)=(-(exp(y(53))*T204*T467));
  v2(168,1)=12;
  v2(168,2)=991;
  v2(168,3)=  v2(167,3);
  v2(169,1)=12;
  v2(169,2)=3533;
  v2(169,3)=(-(exp(y(53))*T204*T489));
  v2(170,1)=12;
  v2(170,2)=3269;
  v2(170,3)=  v2(169,3);
  v2(171,1)=12;
  v2(171,2)=3504;
  v2(171,3)=(-(exp(y(53))*T204*T558));
  v2(172,1)=12;
  v2(172,2)=1326;
  v2(172,3)=  v2(171,3);
  v2(173,1)=12;
  v2(173,2)=3534;
  v2(173,3)=(-(exp(y(53))*T204*T579));
  v2(174,1)=12;
  v2(174,2)=3336;
  v2(174,3)=  v2(173,3);
  v2(175,1)=12;
  v2(175,2)=3535;
  v2(175,3)=(-(exp(y(53))*T184*T621));
  v2(176,1)=12;
  v2(176,2)=3403;
  v2(176,3)=  v2(175,3);
  v2(177,1)=12;
  v2(177,2)=3537;
  v2(177,3)=(-(T184*T204*exp(y(53))));
  v2(178,1)=12;
  v2(178,2)=2966;
  v2(178,3)=T896;
  v2(179,1)=12;
  v2(179,2)=1184;
  v2(179,3)=  v2(178,3);
  v2(180,1)=12;
  v2(180,2)=2993;
  v2(180,3)=T896;
  v2(181,1)=13;
  v2(181,2)=1361;
  v2(181,3)=params(26)*(getPowerDeriv(T215,T212,1)*(-((-params(31))*(y(21)+y(21))))/(y(21)*y(21)*y(21)*y(21))+T600*T600*getPowerDeriv(T215,T212,2));
  v2(182,1)=13;
  v2(182,2)=1565;
  v2(182,3)=(1-params(26))*(exp(y(24))*getPowerDeriv(exp(y(24)),T212,1)+exp(y(24))*exp(y(24))*getPowerDeriv(exp(y(24)),T212,2));
  v2(183,1)=14;
  v2(183,2)=1361;
  v2(183,3)=(-(exp(y(2))*params(26)*(getPowerDeriv(T215,T188,1)*(-((-params(31))*(y(21)+y(21))))/(y(21)*y(21)*y(21)*y(21))+T600*T600*getPowerDeriv(T215,T188,2))));
  v2(184,1)=14;
  v2(184,2)=1565;
  v2(184,3)=(-((1-params(26))*(exp(y(24))*getPowerDeriv(exp(y(24)),T188,1)+exp(y(24))*exp(y(24))*getPowerDeriv(exp(y(24)),T188,2))));
  v2(185,1)=14;
  v2(185,2)=88;
  v2(185,3)=(-(exp(y(2))*params(26)*T600*getPowerDeriv(T215,T188,1)));
  v2(186,1)=14;
  v2(186,2)=1342;
  v2(186,3)=  v2(185,3);
  v2(187,1)=14;
  v2(187,2)=69;
  v2(187,3)=(-(params(26)*T215^T188*exp(y(2))));
  v2(188,1)=14;
  v2(188,2)=1633;
  v2(188,3)=exp(y(25));
  v2(189,1)=15;
  v2(189,2)=1021;
  v2(189,3)=(-exp(y(16)));
  v2(190,1)=15;
  v2(190,2)=1157;
  v2(190,3)=T23;
  v2(191,1)=15;
  v2(191,2)=1225;
  v2(191,3)=(-exp(y(19)));
  v2(192,1)=15;
  v2(192,2)=2041;
  v2(192,3)=(-(1/params(30)*exp(y(31))));
  v2(193,1)=16;
  v2(193,2)=1157;
  v2(193,3)=(-(T23*params(4)*exp(y(43))));
  v2(194,1)=16;
  v2(194,2)=1225;
  v2(194,3)=exp(y(19));
  v2(195,1)=16;
  v2(195,2)=2832;
  v2(195,3)=(-(T23*params(4)*exp(y(43))));
  v2(196,1)=16;
  v2(196,2)=1182;
  v2(196,3)=  v2(195,3);
  v2(197,1)=16;
  v2(197,2)=2857;
  v2(197,3)=(-(T23*params(4)*exp(y(43))));
  v2(198,1)=17;
  v2(198,2)=1;
  v2(198,3)=(-(y(21)*((-(exp(y(20))*exp(y(1))))*exp(y(1))*exp(y(1))-(-(exp(y(20))*exp(y(1))))*(exp(y(1))*exp(y(1))+exp(y(1))*exp(y(1))))/(exp(y(1))*exp(y(1))*exp(y(1))*exp(y(1)))));
  v2(199,1)=17;
  v2(199,2)=1274;
  v2(199,3)=T542;
  v2(200,1)=17;
  v2(200,2)=20;
  v2(200,3)=  v2(199,3);
  v2(201,1)=17;
  v2(201,2)=1293;
  v2(201,3)=(-(y(21)*exp(y(20))/exp(y(1))));
  v2(202,1)=17;
  v2(202,2)=1341;
  v2(202,3)=(-T540);
  v2(203,1)=17;
  v2(203,2)=21;
  v2(203,3)=  v2(202,3);
  v2(204,1)=17;
  v2(204,2)=1360;
  v2(204,3)=(-(exp(y(20))/exp(y(1))));
  v2(205,1)=17;
  v2(205,2)=1294;
  v2(205,3)=  v2(204,3);
  v2(206,1)=18;
  v2(206,2)=1905;
  v2(206,3)=(-((T263*T263*(-(params(10)*T260*T1483))-(-(params(10)*T260*T670))*(T263*T670+T263*T670))/(T263*T263*T263*T263)/y(56)));
  v2(207,1)=18;
  v2(207,2)=3580;
  v2(207,3)=(-((-(T670*params(10)*T704))/(T263*T263)/y(56)));
  v2(208,1)=18;
  v2(208,2)=1930;
  v2(208,3)=  v2(207,3);
  v2(209,1)=18;
  v2(209,2)=3605;
  v2(209,3)=(-(params(10)*T1504/T263/y(56)));
  v2(210,1)=18;
  v2(210,2)=2240;
  v2(210,3)=(-((T263*T263*(-(params(10)*T260*T1511))-(-(params(10)*T260*T770))*(T263*T670+T263*T670))/(T263*T263*T263*T263)/y(56)));
  v2(211,1)=18;
  v2(211,2)=1910;
  v2(211,3)=  v2(210,3);
  v2(212,1)=18;
  v2(212,2)=2265;
  v2(212,3)=(-((-(params(10)*T704*T770))/(T263*T263)/y(56)));
  v2(213,1)=18;
  v2(213,2)=3585;
  v2(213,3)=  v2(212,3);
  v2(214,1)=18;
  v2(214,2)=2245;
  v2(214,3)=(-((T263*T263*(-(params(10)*T260*T1528))-(-(params(10)*T260*T770))*(T263*T770+T263*T770))/(T263*T263*T263*T263)/y(56)));
  v2(215,1)=18;
  v2(215,2)=3647;
  v2(215,3)=(-((-(T670*params(10)*T794))/(T263*T263)/y(56)));
  v2(216,1)=18;
  v2(216,2)=1931;
  v2(216,3)=  v2(215,3);
  v2(217,1)=18;
  v2(217,2)=3672;
  v2(217,3)=(-(params(10)*(-(exp(y(55))*T703))/(exp(y(55))*exp(y(55)))/T263/y(56)));
  v2(218,1)=18;
  v2(218,2)=3606;
  v2(218,3)=  v2(217,3);
  v2(219,1)=18;
  v2(219,2)=3652;
  v2(219,3)=(-((-(T770*params(10)*T794))/(T263*T263)/y(56)));
  v2(220,1)=18;
  v2(220,2)=2266;
  v2(220,3)=  v2(219,3);
  v2(221,1)=18;
  v2(221,2)=3673;
  v2(221,3)=(-(params(10)*T1561/T263/y(56)));
  v2(222,1)=18;
  v2(222,2)=3714;
  v2(222,3)=(-((-((-(params(10)*T260*T670))/(T263*T263)))/(y(56)*y(56))));
  v2(223,1)=18;
  v2(223,2)=1932;
  v2(223,3)=  v2(222,3);
  v2(224,1)=18;
  v2(224,2)=3739;
  v2(224,3)=(-((-(params(10)*T704/T263))/(y(56)*y(56))));
  v2(225,1)=18;
  v2(225,2)=3607;
  v2(225,3)=  v2(224,3);
  v2(226,1)=18;
  v2(226,2)=3719;
  v2(226,3)=(-((-((-(params(10)*T260*T770))/(T263*T263)))/(y(56)*y(56))));
  v2(227,1)=18;
  v2(227,2)=2267;
  v2(227,3)=  v2(226,3);
  v2(228,1)=18;
  v2(228,2)=3740;
  v2(228,3)=(-((-(params(10)*T794/T263))/(y(56)*y(56))));
  v2(229,1)=18;
  v2(229,2)=3674;
  v2(229,3)=  v2(228,3);
  v2(230,1)=18;
  v2(230,2)=3741;
  v2(230,3)=(-((-((-(params(10)*T260/T263))*(y(56)+y(56))))/(y(56)*y(56)*y(56)*y(56))));
  v2(231,1)=18;
  v2(231,2)=2653;
  v2(231,3)=(1+y(40)+1+y(40))/((1+y(40))*(1+y(40))*(1+y(40))*(1+y(40)));
  v2(232,1)=19;
  v2(232,2)=1905;
  v2(232,3)=exp(y(34))*(T272*getPowerDeriv(T272,T275,1)+T272*T272*getPowerDeriv(T272,T275,2));
  v2(233,1)=19;
  v2(233,2)=1972;
  v2(233,3)=exp(y(34))*(T721+T720*T272*getPowerDeriv(T272,T275,2));
  v2(234,1)=19;
  v2(234,2)=1906;
  v2(234,3)=  v2(233,3);
  v2(235,1)=19;
  v2(235,2)=1973;
  v2(235,3)=exp(y(34))*(T720*T720*getPowerDeriv(T272,T275,2)+getPowerDeriv(T272,T275,1)*((-(exp(y(29))*params(34)*exp(y(30))))*exp(y(30))*exp(y(30))-(-(exp(y(29))*params(34)*exp(y(30))))*(exp(y(30))*exp(y(30))+exp(y(30))*exp(y(30))))/(exp(y(30))*exp(y(30))*exp(y(30))*exp(y(30))));
  v2(236,1)=19;
  v2(236,2)=2240;
  v2(236,3)=exp(y(34))*T272*getPowerDeriv(T272,T275,1);
  v2(237,1)=19;
  v2(237,2)=1910;
  v2(237,3)=  v2(236,3);
  v2(238,1)=19;
  v2(238,2)=2241;
  v2(238,3)=exp(y(34))*T721;
  v2(239,1)=19;
  v2(239,2)=1977;
  v2(239,3)=  v2(238,3);
  v2(240,1)=19;
  v2(240,2)=2245;
  v2(240,3)=T277;
  v2(241,1)=20;
  v2(241,2)=1293;
  v2(241,3)=(T545*T568-T568*(T545+T545))/(T545*T545);
  v2(242,1)=20;
  v2(242,2)=1762;
  v2(242,3)=(-(exp(y(20))*(-exp(y(27)))/(exp(y(27))*exp(y(27)))))/T545;
  v2(243,1)=20;
  v2(243,2)=1300;
  v2(243,3)=  v2(242,3);
  v2(244,1)=20;
  v2(244,2)=1769;
  v2(244,3)=((-exp(y(27)))*exp(y(27))*exp(y(27))-(-exp(y(27)))*(exp(y(27))*exp(y(27))+exp(y(27))*exp(y(27))))/(exp(y(27))*exp(y(27))*exp(y(27))*exp(y(27)))/exp(y(20));
  v2(245,1)=20;
  v2(245,2)=1905;
  v2(245,3)=(-(T283*getPowerDeriv(T283,T275,1)+T283*T283*getPowerDeriv(T283,T275,2)));
  v2(246,1)=20;
  v2(246,2)=2039;
  v2(246,3)=(-(T735+T734*T283*getPowerDeriv(T283,T275,2)));
  v2(247,1)=20;
  v2(247,2)=1907;
  v2(247,3)=  v2(246,3);
  v2(248,1)=20;
  v2(248,2)=2041;
  v2(248,3)=(-(T734*T734*getPowerDeriv(T283,T275,2)+getPowerDeriv(T283,T275,1)*((-(exp(y(31))*exp(y(29))*params(35)))*exp(y(31))*exp(y(31))-(-(exp(y(31))*exp(y(29))*params(35)))*(exp(y(31))*exp(y(31))+exp(y(31))*exp(y(31))))/(exp(y(31))*exp(y(31))*exp(y(31))*exp(y(31)))));
  v2(249,1)=21;
  v2(249,2)=1905;
  v2(249,3)=exp(y(29));
  v2(250,1)=21;
  v2(250,2)=1973;
  v2(250,3)=(-(T726*params(34)^T275*(exp(y(30))*getPowerDeriv(exp(y(30)),T287,1)+exp(y(30))*exp(y(30))*getPowerDeriv(exp(y(30)),T287,2))+T725*T725*getPowerDeriv(T293,1+params(11),2)));
  v2(251,1)=21;
  v2(251,2)=2040;
  v2(251,3)=(-(T739*T725*getPowerDeriv(T293,1+params(11),2)));
  v2(252,1)=21;
  v2(252,2)=1974;
  v2(252,3)=  v2(251,3);
  v2(253,1)=21;
  v2(253,2)=2041;
  v2(253,3)=(-(T739*T739*getPowerDeriv(T293,1+params(11),2)+T726*params(35)^T275*(exp(y(31))*getPowerDeriv(exp(y(31)),T287,1)+exp(y(31))*exp(y(31))*getPowerDeriv(exp(y(31)),T287,2))));
  v2(254,1)=22;
  v2(254,2)=2381;
  v2(254,3)=(-(exp(y(36))/exp(y(37))));
  v2(255,1)=22;
  v2(255,2)=2448;
  v2(255,3)=T852;
  v2(256,1)=22;
  v2(256,2)=2382;
  v2(256,3)=  v2(255,3);
  v2(257,1)=22;
  v2(257,2)=2449;
  v2(257,3)=(-(((-(exp(y(36))*exp(y(37))))*exp(y(37))*exp(y(37))-(-(exp(y(36))*exp(y(37))))*(exp(y(37))*exp(y(37))+exp(y(37))*exp(y(37))))/(exp(y(37))*exp(y(37))*exp(y(37))*exp(y(37)))));
  v2(258,1)=22;
  v2(258,2)=2517;
  v2(258,3)=T855+exp(y(38))*exp(y(38))*getPowerDeriv(exp(y(38)),T302,2);
  v2(259,1)=23;
  v2(259,2)=1905;
  v2(259,3)=(-(T48*(T263*T263*(-(T313*T1483))-(-(T313*T670))*(T263*T670+T263*T670))/(T263*T263*T263*T263)+exp(y(57))*T324*T1686));
  v2(260,1)=23;
  v2(260,2)=3580;
  v2(260,3)=(-(exp(y(57))*T324*(-(T670*params(10)*params(25)*T704))/(T263*T263)));
  v2(261,1)=23;
  v2(261,2)=1930;
  v2(261,3)=  v2(260,3);
  v2(262,1)=23;
  v2(262,2)=3605;
  v2(262,3)=(-(exp(y(57))*T324*params(10)*params(25)*T1504/T263));
  v2(263,1)=23;
  v2(263,2)=2106;
  v2(263,3)=(-(T48*(-(T313*T670))/(T263*T263)+T48*(-(T670*T750))/(T263*T263)));
  v2(264,1)=23;
  v2(264,2)=1908;
  v2(264,3)=  v2(263,3);
  v2(265,1)=23;
  v2(265,2)=2109;
  v2(265,3)=(-(T753+T48*T750/T263+T48*T310*(T311*getPowerDeriv(T311,params(21),1)+T311*T311*getPowerDeriv(T311,params(21),2))/T263));
  v2(266,1)=23;
  v2(266,2)=2240;
  v2(266,3)=(-(T48*(T263*T263*(-(T313*T1511))-(-(T313*T770))*(T263*T670+T263*T670))/(T263*T263*T263*T263)+exp(y(57))*T324*T1730));
  v2(267,1)=23;
  v2(267,2)=1910;
  v2(267,3)=  v2(266,3);
  v2(268,1)=23;
  v2(268,2)=2265;
  v2(268,3)=(-(exp(y(57))*T324*(-(params(10)*params(25)*T704*T770))/(T263*T263)));
  v2(269,1)=23;
  v2(269,2)=3585;
  v2(269,3)=  v2(268,3);
  v2(270,1)=23;
  v2(270,2)=2243;
  v2(270,3)=(-(T48*(-(T313*T770))/(T263*T263)+T48*(-(T750*T770))/(T263*T263)));
  v2(271,1)=23;
  v2(271,2)=2111;
  v2(271,3)=  v2(270,3);
  v2(272,1)=23;
  v2(272,2)=2245;
  v2(272,3)=(-(T48*(T263*T263*(-(T313*T1528))-(-(T313*T770))*(T263*T770+T263*T770))/(T263*T263*T263*T263)+exp(y(57))*T324*T1759));
  v2(273,1)=23;
  v2(273,2)=3647;
  v2(273,3)=(-(exp(y(57))*T324*(-(T670*params(10)*params(25)*T794))/(T263*T263)));
  v2(274,1)=23;
  v2(274,2)=1931;
  v2(274,3)=  v2(273,3);
  v2(275,1)=23;
  v2(275,2)=3672;
  v2(275,3)=(-(exp(y(57))*T324*T1771));
  v2(276,1)=23;
  v2(276,2)=3606;
  v2(276,3)=  v2(275,3);
  v2(277,1)=23;
  v2(277,2)=3652;
  v2(277,3)=(-(exp(y(57))*T324*(-(T770*params(10)*params(25)*T794))/(T263*T263)));
  v2(278,1)=23;
  v2(278,2)=2266;
  v2(278,3)=  v2(277,3);
  v2(279,1)=23;
  v2(279,2)=3673;
  v2(279,3)=(-(exp(y(57))*T324*params(10)*params(25)*T1561/T263));
  v2(280,1)=23;
  v2(280,2)=3714;
  v2(280,3)=(-(exp(y(57))*T689*T837));
  v2(281,1)=23;
  v2(281,2)=1932;
  v2(281,3)=  v2(280,3);
  v2(282,1)=23;
  v2(282,2)=3739;
  v2(282,3)=(-(exp(y(57))*T710*T837));
  v2(283,1)=23;
  v2(283,2)=3607;
  v2(283,3)=  v2(282,3);
  v2(284,1)=23;
  v2(284,2)=3719;
  v2(284,3)=(-(exp(y(57))*T782*T837));
  v2(285,1)=23;
  v2(285,2)=2267;
  v2(285,3)=  v2(284,3);
  v2(286,1)=23;
  v2(286,2)=3740;
  v2(286,3)=(-(exp(y(57))*T800*T837));
  v2(287,1)=23;
  v2(287,2)=3674;
  v2(287,3)=  v2(286,3);
  v2(288,1)=23;
  v2(288,2)=3741;
  v2(288,3)=(-(exp(y(57))*T319*(getPowerDeriv(T320,T323,1)*(-((-params(36))*(y(56)+y(56))))/(y(56)*y(56)*y(56)*y(56))+T835*T835*getPowerDeriv(T320,T323,2))));
  v2(289,1)=23;
  v2(289,2)=2381;
  v2(289,3)=exp(y(36));
  v2(290,1)=23;
  v2(290,2)=3781;
  v2(290,3)=(-(exp(y(57))*T324*T689));
  v2(291,1)=23;
  v2(291,2)=1933;
  v2(291,3)=  v2(290,3);
  v2(292,1)=23;
  v2(292,2)=3806;
  v2(292,3)=(-(exp(y(57))*T324*T710));
  v2(293,1)=23;
  v2(293,2)=3608;
  v2(293,3)=  v2(292,3);
  v2(294,1)=23;
  v2(294,2)=3786;
  v2(294,3)=(-(exp(y(57))*T324*T782));
  v2(295,1)=23;
  v2(295,2)=2268;
  v2(295,3)=  v2(294,3);
  v2(296,1)=23;
  v2(296,2)=3807;
  v2(296,3)=(-(exp(y(57))*T324*T800));
  v2(297,1)=23;
  v2(297,2)=3675;
  v2(297,3)=  v2(296,3);
  v2(298,1)=23;
  v2(298,2)=3808;
  v2(298,3)=(-(exp(y(57))*T319*T837));
  v2(299,1)=23;
  v2(299,2)=3742;
  v2(299,3)=  v2(298,3);
  v2(300,1)=23;
  v2(300,2)=3809;
  v2(300,3)=(-(T319*T324*exp(y(57))));
  v2(301,1)=23;
  v2(301,2)=3111;
  v2(301,3)=(-(T48*(-(T670*T911))/(T263*T263)));
  v2(302,1)=23;
  v2(302,2)=1923;
  v2(302,3)=  v2(301,3);
  v2(303,1)=23;
  v2(303,2)=3114;
  v2(303,3)=(-(T48*T911/T263+T48*T310*(T910+T909*T311*getPowerDeriv(T311,params(21),2))/T263));
  v2(304,1)=23;
  v2(304,2)=2124;
  v2(304,3)=  v2(303,3);
  v2(305,1)=23;
  v2(305,2)=3116;
  v2(305,3)=(-(T48*(-(T770*T911))/(T263*T263)));
  v2(306,1)=23;
  v2(306,2)=2258;
  v2(306,3)=  v2(305,3);
  v2(307,1)=23;
  v2(307,2)=3129;
  v2(307,3)=(-(T48*T310*(T909*T909*getPowerDeriv(T311,params(21),2)+getPowerDeriv(T311,params(21),1)*((-(exp(y(47))*T48))*exp(y(47))*exp(y(47))-(-(exp(y(47))*T48))*(exp(y(47))*exp(y(47))+exp(y(47))*exp(y(47))))/(exp(y(47))*exp(y(47))*exp(y(47))*exp(y(47))))/T263));
  v2(308,1)=24;
  v2(308,2)=1905;
  v2(308,3)=(-(exp(y(58))*T339*T1686));
  v2(309,1)=24;
  v2(309,2)=3580;
  v2(309,3)=(-(exp(y(58))*T339*(-(T670*params(10)*params(25)*T704))/(T263*T263)));
  v2(310,1)=24;
  v2(310,2)=1930;
  v2(310,3)=  v2(309,3);
  v2(311,1)=24;
  v2(311,2)=3605;
  v2(311,3)=(-(exp(y(58))*T339*params(10)*params(25)*T1504/T263));
  v2(312,1)=24;
  v2(312,2)=2109;
  v2(312,3)=(-(T48*(1+params(37)*exp(y(48)))/params(23)));
  v2(313,1)=24;
  v2(313,2)=2240;
  v2(313,3)=(-(exp(y(58))*T339*T1730));
  v2(314,1)=24;
  v2(314,2)=1910;
  v2(314,3)=  v2(313,3);
  v2(315,1)=24;
  v2(315,2)=2265;
  v2(315,3)=(-(exp(y(58))*T339*(-(params(10)*params(25)*T704*T770))/(T263*T263)));
  v2(316,1)=24;
  v2(316,2)=3585;
  v2(316,3)=  v2(315,3);
  v2(317,1)=24;
  v2(317,2)=2245;
  v2(317,3)=(-(exp(y(58))*T339*T1759));
  v2(318,1)=24;
  v2(318,2)=3647;
  v2(318,3)=(-(exp(y(58))*T339*(-(T670*params(10)*params(25)*T794))/(T263*T263)));
  v2(319,1)=24;
  v2(319,2)=1931;
  v2(319,3)=  v2(318,3);
  v2(320,1)=24;
  v2(320,2)=3672;
  v2(320,3)=(-(exp(y(58))*T339*T1771));
  v2(321,1)=24;
  v2(321,2)=3606;
  v2(321,3)=  v2(320,3);
  v2(322,1)=24;
  v2(322,2)=3652;
  v2(322,3)=(-(exp(y(58))*T339*(-(T770*params(10)*params(25)*T794))/(T263*T263)));
  v2(323,1)=24;
  v2(323,2)=2266;
  v2(323,3)=  v2(322,3);
  v2(324,1)=24;
  v2(324,2)=3673;
  v2(324,3)=(-(exp(y(58))*T339*params(10)*params(25)*T1561/T263));
  v2(325,1)=24;
  v2(325,2)=3714;
  v2(325,3)=(-(exp(y(58))*T689*T842));
  v2(326,1)=24;
  v2(326,2)=1932;
  v2(326,3)=  v2(325,3);
  v2(327,1)=24;
  v2(327,2)=3739;
  v2(327,3)=(-(exp(y(58))*T710*T842));
  v2(328,1)=24;
  v2(328,2)=3607;
  v2(328,3)=  v2(327,3);
  v2(329,1)=24;
  v2(329,2)=3719;
  v2(329,3)=(-(exp(y(58))*T782*T842));
  v2(330,1)=24;
  v2(330,2)=2267;
  v2(330,3)=  v2(329,3);
  v2(331,1)=24;
  v2(331,2)=3740;
  v2(331,3)=(-(exp(y(58))*T800*T842));
  v2(332,1)=24;
  v2(332,2)=3674;
  v2(332,3)=  v2(331,3);
  v2(333,1)=24;
  v2(333,2)=3741;
  v2(333,3)=(-(exp(y(58))*T319*(T841*(-((-params(36))*(y(56)+y(56))))/(y(56)*y(56)*y(56)*y(56))+T835*T835*getPowerDeriv(T320,1-(1+params(23))/params(23),2))));
  v2(334,1)=24;
  v2(334,2)=2449;
  v2(334,3)=exp(y(37));
  v2(335,1)=24;
  v2(335,2)=3848;
  v2(335,3)=(-(exp(y(58))*T339*T689));
  v2(336,1)=24;
  v2(336,2)=1934;
  v2(336,3)=  v2(335,3);
  v2(337,1)=24;
  v2(337,2)=3873;
  v2(337,3)=(-(exp(y(58))*T339*T710));
  v2(338,1)=24;
  v2(338,2)=3609;
  v2(338,3)=  v2(337,3);
  v2(339,1)=24;
  v2(339,2)=3853;
  v2(339,3)=(-(exp(y(58))*T339*T782));
  v2(340,1)=24;
  v2(340,2)=2269;
  v2(340,3)=  v2(339,3);
  v2(341,1)=24;
  v2(341,2)=3874;
  v2(341,3)=(-(exp(y(58))*T339*T800));
  v2(342,1)=24;
  v2(342,2)=3676;
  v2(342,3)=  v2(341,3);
  v2(343,1)=24;
  v2(343,2)=3875;
  v2(343,3)=(-(exp(y(58))*T319*T842));
  v2(344,1)=24;
  v2(344,2)=3743;
  v2(344,3)=  v2(343,3);
  v2(345,1)=24;
  v2(345,2)=3877;
  v2(345,3)=(-(T319*T339*exp(y(58))));
  v2(346,1)=24;
  v2(346,2)=3181;
  v2(346,3)=T918;
  v2(347,1)=24;
  v2(347,2)=2125;
  v2(347,3)=  v2(346,3);
  v2(348,1)=24;
  v2(348,2)=3197;
  v2(348,3)=T918;
  v2(349,1)=25;
  v2(349,2)=2313;
  v2(349,3)=params(25)*(getPowerDeriv(T350,T347,1)*(-((-params(36))*(y(35)+y(35))))/(y(35)*y(35)*y(35)*y(35))+T821*T821*getPowerDeriv(T350,T347,2));
  v2(350,1)=25;
  v2(350,2)=2517;
  v2(350,3)=(1-params(25))*(exp(y(38))*getPowerDeriv(exp(y(38)),T347,1)+exp(y(38))*exp(y(38))*getPowerDeriv(exp(y(38)),T347,2));
  v2(351,1)=26;
  v2(351,2)=2313;
  v2(351,3)=(-(exp(y(5))*params(25)*(getPowerDeriv(T350,T323,1)*(-((-params(36))*(y(35)+y(35))))/(y(35)*y(35)*y(35)*y(35))+T821*T821*getPowerDeriv(T350,T323,2))));
  v2(352,1)=26;
  v2(352,2)=2517;
  v2(352,3)=(-((1-params(25))*(exp(y(38))*getPowerDeriv(exp(y(38)),T323,1)+exp(y(38))*exp(y(38))*getPowerDeriv(exp(y(38)),T323,2))));
  v2(353,1)=26;
  v2(353,2)=303;
  v2(353,3)=(-(exp(y(5))*params(25)*T821*getPowerDeriv(T350,T323,1)));
  v2(354,1)=26;
  v2(354,2)=2283;
  v2(354,3)=  v2(353,3);
  v2(355,1)=26;
  v2(355,2)=273;
  v2(355,3)=(-(params(25)*T350^T323*exp(y(5))));
  v2(356,1)=26;
  v2(356,2)=2585;
  v2(356,3)=exp(y(39));
  v2(357,1)=27;
  v2(357,2)=1089;
  v2(357,3)=(-(exp(y(17))*params(30)));
  v2(358,1)=27;
  v2(358,2)=1973;
  v2(358,3)=(-exp(y(30)));
  v2(359,1)=27;
  v2(359,2)=2109;
  v2(359,3)=T48;
  v2(360,1)=27;
  v2(360,2)=2177;
  v2(360,3)=(-exp(y(33)));
  v2(361,1)=28;
  v2(361,2)=2109;
  v2(361,3)=(-(T48*params(12)*exp(y(46))));
  v2(362,1)=28;
  v2(362,2)=2177;
  v2(362,3)=exp(y(33));
  v2(363,1)=28;
  v2(363,2)=3047;
  v2(363,3)=(-(T48*params(12)*exp(y(46))));
  v2(364,1)=28;
  v2(364,2)=2123;
  v2(364,3)=  v2(363,3);
  v2(365,1)=28;
  v2(365,2)=3061;
  v2(365,3)=(-(T48*params(12)*exp(y(46))));
  v2(366,1)=29;
  v2(366,2)=205;
  v2(366,3)=(-(y(35)*((-(exp(y(34))*exp(y(4))))*exp(y(4))*exp(y(4))-(-(exp(y(34))*exp(y(4))))*(exp(y(4))*exp(y(4))+exp(y(4))*exp(y(4))))/(exp(y(4))*exp(y(4))*exp(y(4))*exp(y(4)))));
  v2(367,1)=29;
  v2(367,2)=2215;
  v2(367,3)=T763;
  v2(368,1)=29;
  v2(368,2)=235;
  v2(368,3)=  v2(367,3);
  v2(369,1)=29;
  v2(369,2)=2245;
  v2(369,3)=(-(y(35)*exp(y(34))/exp(y(4))));
  v2(370,1)=29;
  v2(370,2)=2282;
  v2(370,3)=(-T761);
  v2(371,1)=29;
  v2(371,2)=236;
  v2(371,3)=  v2(370,3);
  v2(372,1)=29;
  v2(372,2)=2312;
  v2(372,3)=(-(exp(y(34))/exp(y(4))));
  v2(373,1)=29;
  v2(373,2)=2246;
  v2(373,3)=  v2(372,3);
  v2(374,1)=30;
  v2(374,2)=953;
  v2(374,3)=(-(params(48)*(T120*T120*(-(T389*T1036))-(-(T389*T447))*(T120*T447+T120*T447))/(T120*T120*T120*T120)));
  v2(375,1)=30;
  v2(375,2)=1757;
  v2(375,3)=(-(params(48)*(-(T447*T660))/(T120*T120)));
  v2(376,1)=30;
  v2(376,2)=965;
  v2(376,3)=  v2(375,3);
  v2(377,1)=30;
  v2(377,2)=1769;
  v2(377,3)=(-(params(48)*params(47)*(exp(y(27))*exp(y(27))*(-(exp(y(27))*params(46)))-(-(exp(y(27))*params(46)))*(exp(y(27))*exp(y(27))+exp(y(27))*exp(y(27))))/(exp(y(27))*exp(y(27))*exp(y(27))*exp(y(27)))/T120));
  v2(378,1)=30;
  v2(378,2)=1905;
  v2(378,3)=params(45)*(T262*T262*(-(params(44)*T1482))-(-(params(44)*T669))*(T262*T669+T262*T669))/(T262*T262*T262*T262);
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),36,4489);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],36,300763);
end
end
