function [residual, g1, g2] = BBCDLmodelcomp_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 36, 1);

%
% Model equations
%

T14 = exp(y(3))^(1-params(1))/(1-params(1));
T30 = params(27)*exp(y(32))^(-params(22))*exp(y(6))^(1+params(22))/(1+params(22))*exp(y(13));
T55 = params(33)*exp(y(35))^(-params(21))*exp(y(20))^(1+params(21))/(1+params(21))*exp(y(27));
T64 = ((1+y(14))/(1+params(38)))^params(40);
T67 = y(9)/params(31);
T69 = T67^params(41);
T86 = ((1+y(28))/(1+params(39)))^params(42);
T89 = y(23)/params(36);
T91 = T89^params(43);
T109 = exp(y(3))^(-params(1));
T112 = T109/exp(y(8));
T121 = exp(y(3))*params(28)/exp(y(4));
T124 = params(3)/(1+params(3));
T137 = exp(y(3))*params(29)/exp(y(5));
T141 = 1/(1+params(3));
T147 = params(28)^T124*exp(y(4))^T141+params(29)^T124*exp(y(5))^T141;
T165 = exp(y(6))/exp(y(32));
T167 = params(27)*(1+params(24))/params(24)*T165^params(22);
T173 = T112*params(2)*params(26)/T112;
T174 = params(31)/y(9);
T177 = (1+params(22))*(-(1+params(24)))/params(24);
T178 = T174^T177;
T191 = T174^(1-(1+params(24))/params(24));
T197 = (-1)/params(24);
T231 = exp(y(17))^(-params(9));
T232 = T231/exp(y(22));
T241 = exp(y(17))*params(34)/exp(y(18));
T244 = params(11)/(1+params(11));
T252 = exp(y(17))*params(35)/exp(y(19));
T256 = 1/(1+params(11));
T262 = params(34)^T244*exp(y(18))^T256+params(35)^T244*exp(y(19))^T256;
T280 = exp(y(20))/exp(y(35));
T282 = params(33)*(1+params(23))/params(23)*T280^params(21);
T288 = T232*params(10)*params(25)/T232;
T289 = params(36)/y(23);
T292 = (1+params(21))*(-(1+params(23)))/params(23);
T293 = T289^T292;
T306 = T289^(1-(1+params(23))/params(23));
T312 = (-1)/params(23);
T396 = (-(exp(y(3))*getPowerDeriv(exp(y(3)),1-params(1),1)/(1-params(1))));
T399 = exp(y(3))*getPowerDeriv(exp(y(3)),(-params(1)),1)/exp(y(8));
T480 = (-(T109*exp(y(8))))/(exp(y(8))*exp(y(8)));
T526 = (-params(31))/(y(9)*y(9))*getPowerDeriv(T174,T177,1);
T586 = exp(y(17))*getPowerDeriv(exp(y(17)),(-params(9)),1)/exp(y(22));
T669 = (-(exp(y(22))*T231))/(exp(y(22))*exp(y(22)));
T712 = (-params(36))/(y(23)*y(23))*getPowerDeriv(T289,T292,1);
lhs =y(1);
rhs =T14-T30;
residual(1)= lhs-rhs;
lhs =y(2);
rhs =exp(y(17))^(1-params(9))/(1-params(9))-T55;
residual(2)= lhs-rhs;
lhs =y(14);
rhs =(1+params(38))*T64*(T67*T69)^(1-params(40))*(1+x(7))-1;
residual(3)= lhs-rhs;
lhs =y(28);
rhs =(1+params(39))*T86*(T89*T91)^(1-params(42))*(1+x(8))-1;
residual(4)= lhs-rhs;
lhs =y(30);
rhs =T14+y(30)*params(2);
residual(5)= lhs-rhs;
lhs =1/(1+y(14));
rhs =params(2)*T112/T112/y(9);
residual(6)= lhs-rhs;
lhs =exp(y(8))*T121^T124;
rhs =1;
residual(7)= lhs-rhs;
lhs =exp(y(15))/exp(y(22));
rhs =T137^T124;
residual(8)= lhs-rhs;
lhs =exp(y(3));
rhs =T147^(1+params(3));
residual(9)= lhs-rhs;
lhs =exp(y(12))^(1+params(22)*(1+params(24))/params(24));
rhs =exp(y(10))/exp(y(11));
residual(10)= lhs-rhs;
lhs =exp(y(10));
rhs =exp(y(6))*T167/T112+exp(y(10))*T173*T178;
residual(11)= lhs-rhs;
lhs =exp(y(11));
rhs =exp(y(6))*(1+params(32)*exp(y(33)))/params(24)+exp(y(11))*T173*T191;
residual(12)= lhs-rhs;
lhs =(1-params(26))*exp(y(12))^T197+params(26)*T174^T197;
rhs =1;
residual(13)= lhs-rhs;
lhs =exp(y(13));
rhs =(1-params(26))*exp(y(12))^T177+exp(y(13))*params(26)*T178;
residual(14)= lhs-rhs;
lhs =exp(y(6));
rhs =exp(y(4))+exp(y(7))+1/params(30)*exp(y(19));
residual(15)= lhs-rhs;
lhs =exp(y(7));
rhs =exp(y(6))*params(4)*exp(y(31));
residual(16)= lhs-rhs;
lhs =y(16);
rhs =y(9);
residual(17)= lhs-rhs;
lhs =1/(1+y(28));
rhs =params(10)*T232/T232/y(23);
residual(18)= lhs-rhs;
lhs =exp(y(22))*T241^T244;
rhs =1;
residual(19)= lhs-rhs;
lhs =1/exp(y(15))/exp(y(8));
rhs =T252^T244;
residual(20)= lhs-rhs;
lhs =exp(y(17));
rhs =T262^(1+params(11));
residual(21)= lhs-rhs;
lhs =exp(y(26))^(1+params(21)*(1+params(23))/params(23));
rhs =exp(y(24))/exp(y(25));
residual(22)= lhs-rhs;
lhs =exp(y(24));
rhs =exp(y(20))*T282/T232+exp(y(24))*T288*T293;
residual(23)= lhs-rhs;
lhs =exp(y(25));
rhs =exp(y(20))*(1+params(37)*exp(y(36)))/params(23)+exp(y(25))*T288*T306;
residual(24)= lhs-rhs;
lhs =(1-params(25))*exp(y(26))^T312+params(25)*T289^T312;
rhs =1;
residual(25)= lhs-rhs;
lhs =exp(y(27));
rhs =(1-params(25))*exp(y(26))^T292+exp(y(27))*params(25)*T293;
residual(26)= lhs-rhs;
lhs =exp(y(20));
rhs =exp(y(18))+exp(y(21))+exp(y(5))*params(30);
residual(27)= lhs-rhs;
lhs =exp(y(21));
rhs =exp(y(20))*params(12)*exp(y(34));
residual(28)= lhs-rhs;
lhs =y(29);
rhs =y(23);
residual(29)= lhs-rhs;
lhs =params(44)/T231*params(45);
rhs =params(46)/exp(y(15))*params(47)/T109*params(48);
residual(30)= lhs-rhs;
lhs =y(31);
rhs =y(31)*params(5)+params(6)*x(1);
residual(31)= lhs-rhs;
lhs =y(32);
rhs =y(32)*params(7)+params(8)*x(2);
residual(32)= lhs-rhs;
lhs =y(33);
rhs =y(33)*params(19)+params(20)*x(6);
residual(33)= lhs-rhs;
lhs =y(34);
rhs =y(34)*params(13)+params(14)*x(3);
residual(34)= lhs-rhs;
lhs =y(35);
rhs =y(35)*params(15)+params(16)*x(4);
residual(35)= lhs-rhs;
lhs =y(36);
rhs =y(36)*params(17)+params(18)*x(5);
residual(36)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(36, 36);

  %
  % Jacobian matrix
  %

  g1(1,1)=1;
  g1(1,3)=T396;
  g1(1,6)=exp(y(13))*params(27)*exp(y(32))^(-params(22))*exp(y(6))*getPowerDeriv(exp(y(6)),1+params(22),1)/(1+params(22));
  g1(1,13)=T30;
  g1(1,32)=exp(y(13))*exp(y(6))^(1+params(22))*params(27)*exp(y(32))*getPowerDeriv(exp(y(32)),(-params(22)),1)/(1+params(22));
  g1(2,2)=1;
  g1(2,17)=(-(exp(y(17))*getPowerDeriv(exp(y(17)),1-params(9),1)/(1-params(9))));
  g1(2,20)=exp(y(27))*params(33)*exp(y(35))^(-params(21))*exp(y(20))*getPowerDeriv(exp(y(20)),1+params(21),1)/(1+params(21));
  g1(2,27)=T55;
  g1(2,35)=exp(y(27))*exp(y(20))^(1+params(21))*params(33)*exp(y(35))*getPowerDeriv(exp(y(35)),(-params(21)),1)/(1+params(21));
  g1(3,9)=(-((1+x(7))*(1+params(38))*T64*(T69*1/params(31)+T67*1/params(31)*getPowerDeriv(T67,params(41),1))*getPowerDeriv(T67*T69,1-params(40),1)));
  g1(3,14)=1-(1+x(7))*(1+params(38))*(T67*T69)^(1-params(40))*1/(1+params(38))*getPowerDeriv((1+y(14))/(1+params(38)),params(40),1);
  g1(4,23)=(-((1+x(8))*(1+params(39))*T86*(T91*1/params(36)+T89*1/params(36)*getPowerDeriv(T89,params(43),1))*getPowerDeriv(T89*T91,1-params(42),1)));
  g1(4,28)=1-(1+x(8))*(1+params(39))*(T89*T91)^(1-params(42))*1/(1+params(39))*getPowerDeriv((1+y(28))/(1+params(39)),params(42),1);
  g1(5,3)=T396;
  g1(5,30)=1-params(2);
  g1(6,3)=(-((T112*params(2)*T399-params(2)*T112*T399)/(T112*T112)/y(9)));
  g1(6,8)=(-((T112*params(2)*T480-params(2)*T112*T480)/(T112*T112)/y(9)));
  g1(6,9)=(-((-(params(2)*T112/T112))/(y(9)*y(9))));
  g1(6,14)=(-1)/((1+y(14))*(1+y(14)));
  g1(7,3)=exp(y(8))*T121*getPowerDeriv(T121,T124,1);
  g1(7,4)=exp(y(8))*getPowerDeriv(T121,T124,1)*(-(exp(y(3))*params(28)*exp(y(4))))/(exp(y(4))*exp(y(4)));
  g1(7,8)=exp(y(8))*T121^T124;
  g1(8,3)=(-(T137*getPowerDeriv(T137,T124,1)));
  g1(8,5)=(-(getPowerDeriv(T137,T124,1)*(-(exp(y(3))*params(29)*exp(y(5))))/(exp(y(5))*exp(y(5)))));
  g1(8,15)=exp(y(15))/exp(y(22));
  g1(8,22)=(-(exp(y(15))*exp(y(22))))/(exp(y(22))*exp(y(22)));
  g1(9,3)=exp(y(3));
  g1(9,4)=(-(params(28)^T124*exp(y(4))*getPowerDeriv(exp(y(4)),T141,1)*getPowerDeriv(T147,1+params(3),1)));
  g1(9,5)=(-(getPowerDeriv(T147,1+params(3),1)*params(29)^T124*exp(y(5))*getPowerDeriv(exp(y(5)),T141,1)));
  g1(10,10)=(-(exp(y(10))/exp(y(11))));
  g1(10,11)=(-((-(exp(y(10))*exp(y(11))))/(exp(y(11))*exp(y(11)))));
  g1(10,12)=exp(y(12))*getPowerDeriv(exp(y(12)),1+params(22)*(1+params(24))/params(24),1);
  g1(11,3)=(-(exp(y(6))*(-(T167*T399))/(T112*T112)+exp(y(10))*T178*(T112*params(2)*params(26)*T399-T112*params(2)*params(26)*T399)/(T112*T112)));
  g1(11,6)=(-(exp(y(6))*T167/T112+exp(y(6))*params(27)*(1+params(24))/params(24)*T165*getPowerDeriv(T165,params(22),1)/T112));
  g1(11,8)=(-(exp(y(6))*(-(T167*T480))/(T112*T112)+exp(y(10))*T178*(T112*params(2)*params(26)*T480-T112*params(2)*params(26)*T480)/(T112*T112)));
  g1(11,9)=(-(exp(y(10))*T173*T526));
  g1(11,10)=exp(y(10))-exp(y(10))*T173*T178;
  g1(11,32)=(-(exp(y(6))*params(27)*(1+params(24))/params(24)*getPowerDeriv(T165,params(22),1)*(-(exp(y(32))*exp(y(6))))/(exp(y(32))*exp(y(32)))/T112));
  g1(12,3)=(-(exp(y(11))*T191*(T112*params(2)*params(26)*T399-T112*params(2)*params(26)*T399)/(T112*T112)));
  g1(12,6)=(-(exp(y(6))*(1+params(32)*exp(y(33)))/params(24)));
  g1(12,8)=(-(exp(y(11))*T191*(T112*params(2)*params(26)*T480-T112*params(2)*params(26)*T480)/(T112*T112)));
  g1(12,9)=(-(exp(y(11))*T173*(-params(31))/(y(9)*y(9))*getPowerDeriv(T174,1-(1+params(24))/params(24),1)));
  g1(12,11)=exp(y(11))-exp(y(11))*T173*T191;
  g1(12,33)=(-(exp(y(6))*params(32)*exp(y(33))/params(24)));
  g1(13,9)=params(26)*(-params(31))/(y(9)*y(9))*getPowerDeriv(T174,T197,1);
  g1(13,12)=(1-params(26))*exp(y(12))*getPowerDeriv(exp(y(12)),T197,1);
  g1(14,9)=(-(exp(y(13))*params(26)*T526));
  g1(14,12)=(-((1-params(26))*exp(y(12))*getPowerDeriv(exp(y(12)),T177,1)));
  g1(14,13)=exp(y(13))-exp(y(13))*params(26)*T178;
  g1(15,4)=(-exp(y(4)));
  g1(15,6)=exp(y(6));
  g1(15,7)=(-exp(y(7)));
  g1(15,19)=(-(1/params(30)*exp(y(19))));
  g1(16,6)=(-(exp(y(6))*params(4)*exp(y(31))));
  g1(16,7)=exp(y(7));
  g1(16,31)=(-(exp(y(6))*params(4)*exp(y(31))));
  g1(17,9)=(-1);
  g1(17,16)=1;
  g1(18,17)=(-((T232*params(10)*T586-params(10)*T232*T586)/(T232*T232)/y(23)));
  g1(18,22)=(-((T232*params(10)*T669-params(10)*T232*T669)/(T232*T232)/y(23)));
  g1(18,23)=(-((-(params(10)*T232/T232))/(y(23)*y(23))));
  g1(18,28)=(-1)/((1+y(28))*(1+y(28)));
  g1(19,17)=exp(y(22))*T241*getPowerDeriv(T241,T244,1);
  g1(19,18)=exp(y(22))*getPowerDeriv(T241,T244,1)*(-(exp(y(17))*params(34)*exp(y(18))))/(exp(y(18))*exp(y(18)));
  g1(19,22)=exp(y(22))*T241^T244;
  g1(20,8)=(-(exp(y(8))*1/exp(y(15))))/(exp(y(8))*exp(y(8)));
  g1(20,15)=(-exp(y(15)))/(exp(y(15))*exp(y(15)))/exp(y(8));
  g1(20,17)=(-(T252*getPowerDeriv(T252,T244,1)));
  g1(20,19)=(-(getPowerDeriv(T252,T244,1)*(-(exp(y(19))*exp(y(17))*params(35)))/(exp(y(19))*exp(y(19)))));
  g1(21,17)=exp(y(17));
  g1(21,18)=(-(params(34)^T244*exp(y(18))*getPowerDeriv(exp(y(18)),T256,1)*getPowerDeriv(T262,1+params(11),1)));
  g1(21,19)=(-(getPowerDeriv(T262,1+params(11),1)*params(35)^T244*exp(y(19))*getPowerDeriv(exp(y(19)),T256,1)));
  g1(22,24)=(-(exp(y(24))/exp(y(25))));
  g1(22,25)=(-((-(exp(y(24))*exp(y(25))))/(exp(y(25))*exp(y(25)))));
  g1(22,26)=exp(y(26))*getPowerDeriv(exp(y(26)),1+params(21)*(1+params(23))/params(23),1);
  g1(23,17)=(-(exp(y(20))*(-(T282*T586))/(T232*T232)+exp(y(24))*T293*(T232*params(10)*params(25)*T586-T232*params(10)*params(25)*T586)/(T232*T232)));
  g1(23,20)=(-(exp(y(20))*T282/T232+exp(y(20))*params(33)*(1+params(23))/params(23)*T280*getPowerDeriv(T280,params(21),1)/T232));
  g1(23,22)=(-(exp(y(20))*(-(T282*T669))/(T232*T232)+exp(y(24))*T293*(T232*params(10)*params(25)*T669-T232*params(10)*params(25)*T669)/(T232*T232)));
  g1(23,23)=(-(exp(y(24))*T288*T712));
  g1(23,24)=exp(y(24))-exp(y(24))*T288*T293;
  g1(23,35)=(-(exp(y(20))*params(33)*(1+params(23))/params(23)*getPowerDeriv(T280,params(21),1)*(-(exp(y(35))*exp(y(20))))/(exp(y(35))*exp(y(35)))/T232));
  g1(24,17)=(-(exp(y(25))*T306*(T232*params(10)*params(25)*T586-T232*params(10)*params(25)*T586)/(T232*T232)));
  g1(24,20)=(-(exp(y(20))*(1+params(37)*exp(y(36)))/params(23)));
  g1(24,22)=(-(exp(y(25))*T306*(T232*params(10)*params(25)*T669-T232*params(10)*params(25)*T669)/(T232*T232)));
  g1(24,23)=(-(exp(y(25))*T288*(-params(36))/(y(23)*y(23))*getPowerDeriv(T289,1-(1+params(23))/params(23),1)));
  g1(24,25)=exp(y(25))-exp(y(25))*T288*T306;
  g1(24,36)=(-(exp(y(20))*params(37)*exp(y(36))/params(23)));
  g1(25,23)=params(25)*(-params(36))/(y(23)*y(23))*getPowerDeriv(T289,T312,1);
  g1(25,26)=(1-params(25))*exp(y(26))*getPowerDeriv(exp(y(26)),T312,1);
  g1(26,23)=(-(exp(y(27))*params(25)*T712));
  g1(26,26)=(-((1-params(25))*exp(y(26))*getPowerDeriv(exp(y(26)),T292,1)));
  g1(26,27)=exp(y(27))-exp(y(27))*params(25)*T293;
  g1(27,5)=(-(exp(y(5))*params(30)));
  g1(27,18)=(-exp(y(18)));
  g1(27,20)=exp(y(20));
  g1(27,21)=(-exp(y(21)));
  g1(28,20)=(-(exp(y(20))*params(12)*exp(y(34))));
  g1(28,21)=exp(y(21));
  g1(28,34)=(-(exp(y(20))*params(12)*exp(y(34))));
  g1(29,23)=(-1);
  g1(29,29)=1;
  g1(30,3)=(-(params(48)*(-(params(46)/exp(y(15))*params(47)*exp(y(3))*getPowerDeriv(exp(y(3)),(-params(1)),1)))/(T109*T109)));
  g1(30,15)=(-(params(48)*params(47)*(-(exp(y(15))*params(46)))/(exp(y(15))*exp(y(15)))/T109));
  g1(30,17)=params(45)*(-(params(44)*exp(y(17))*getPowerDeriv(exp(y(17)),(-params(9)),1)))/(T231*T231);
  g1(31,31)=1-params(5);
  g1(32,32)=1-params(7);
  g1(33,33)=1-params(19);
  g1(34,34)=1-params(13);
  g1(35,35)=1-params(15);
  g1(36,36)=1-params(17);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],36,1296);
end
end
