function [residual, g1, g2, g3] = BBCDLoptrule_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           columns: equations in order of declaration
%                                                           rows: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(40, 1);
T15 = ((1+y(3))/(1+params(38)))^params(40);
T18 = y(21)/params(31);
T20 = T18^params(41);
T23 = (T18*T20)^(1-params(40));
T38 = ((1+y(6))/(1+params(39)))^params(42);
T41 = y(35)/params(36);
T43 = T41^params(43);
T46 = (T41*T43)^(1-params(42));
T60 = exp(y(15))^(1-params(1))/(1-params(1));
T74 = exp(y(53))^(-params(1))/exp(y(54));
T76 = exp(y(15))^(-params(1));
T79 = T76/exp(y(20));
T88 = exp(y(15))*params(28)/exp(y(16));
T91 = params(3)/(1+params(3));
T93 = exp(y(20))*T88^T91;
T99 = exp(y(27))/exp(y(34));
T104 = exp(y(15))*params(29)/exp(y(17));
T108 = 1/(1+params(3));
T114 = params(28)^T91*exp(y(16))^T108+params(29)^T91*exp(y(17))^T108;
T124 = 1+(1+params(24))/params(24)*params(22);
T133 = (1+params(24))/params(24)*params(27);
T135 = exp(y(18));
T138 = T135/exp(y(48));
T140 = T133*T138^params(22);
T146 = T74*params(2)*params(26)/T79;
T147 = params(31)/y(55);
T151 = (-(1+params(24)))/params(24)*(1+params(22));
T152 = T147^T151;
T167 = T147^(1-(1+params(24))/params(24));
T175 = (-1)/params(24);
T178 = params(31)/y(21);
T226 = exp(y(58))^(-params(9))/exp(y(59));
T230 = exp(y(29))^(-params(9));
T231 = T230/exp(y(34));
T240 = exp(y(29))*params(34)/exp(y(30));
T243 = params(11)/(1+params(11));
T245 = exp(y(34))*T240^T243;
T251 = exp(y(29))*params(35)/exp(y(31));
T255 = 1/(1+params(11));
T261 = params(34)^T243*exp(y(30))^T255+params(35)^T243*exp(y(31))^T255;
T271 = 1+(1+params(23))/params(23)*params(21);
T280 = (1+params(23))/params(23)*params(33);
T282 = exp(y(32));
T285 = T282/exp(y(51));
T287 = T280*T285^params(21);
T293 = T226*params(10)*params(25)/T231;
T294 = params(36)/y(60);
T298 = (-(1+params(23)))/params(23)*(1+params(21));
T299 = T294^T298;
T314 = T294^(1-(1+params(23))/params(23));
T322 = (-1)/params(23);
T325 = params(36)/y(35);
T366 = params(46)/exp(y(27))*params(47);
T374 = params(27)*exp(y(48))^(-params(22));
T375 = T135^(1+params(22));
T378 = exp(y(25))*T374*T375/(1+params(22));
T387 = params(33)*exp(y(51))^(-params(21));
T388 = T282^(1+params(21));
T391 = exp(y(39))*T387*T388/(1+params(21));
T469 = (-(exp(y(15))*getPowerDeriv(exp(y(15)),1-params(1),1)/(1-params(1))));
T471 = exp(y(15))*getPowerDeriv(exp(y(15)),(-params(1)),1);
T472 = T471/exp(y(20));
T491 = (-(T74*params(2)*params(26)*T472))/(T79*T79);
T506 = exp(y(53))*getPowerDeriv(exp(y(53)),(-params(1)),1);
T507 = T506/exp(y(54));
T513 = params(2)*params(26)*T507/T79;
T523 = (-(exp(y(15))*params(28)*exp(y(16))))/(exp(y(16))*exp(y(16)));
T524 = getPowerDeriv(T88,T91,1)*T523;
T528 = params(28)^T91*exp(y(16))*getPowerDeriv(exp(y(16)),T108,1);
T529 = getPowerDeriv(T114,1+params(3),1);
T536 = (-(exp(y(15))*params(29)*exp(y(17))))/(exp(y(17))*exp(y(17)));
T537 = getPowerDeriv(T104,T91,1)*T536;
T541 = params(29)^T91*exp(y(17))*getPowerDeriv(exp(y(17)),T108,1);
T547 = T133*T138*getPowerDeriv(T138,params(22),1);
T550 = T135*T140/T79+T135*T547/T79;
T555 = T135*getPowerDeriv(T135,1+params(22),1);
T558 = exp(y(25))*T374*T555/(1+params(22));
T564 = (-(exp(y(20))*exp(y(1))))/(exp(y(1))*exp(y(1)));
T566 = (-(y(21)*T564));
T569 = exp(y(20))*exp(y(20));
T570 = (-(T76*exp(y(20))))/T569;
T582 = (-(T74*params(2)*params(26)*T570))/(T79*T79);
T592 = (-(exp(y(20))*1/exp(y(27))));
T595 = (-(exp(y(53))^(-params(1))*exp(y(54))));
T597 = T595/(exp(y(54))*exp(y(54)));
T603 = params(2)*params(26)*T597/T79;
T610 = 1/params(31);
T612 = T610*getPowerDeriv(T18,params(41),1);
T619 = (1+params(38))*T15*(T20*T610+T18*T612)*getPowerDeriv(T18*T20,1-params(40),1);
T624 = (-params(31))/(y(21)*y(21));
T638 = (-params(31))/(y(55)*y(55));
T640 = T638*getPowerDeriv(T147,T151,1);
T644 = getPowerDeriv(T147,1-(1+params(24))/params(24),1);
T645 = T638*T644;
T655 = (-((-(exp(y(22))*exp(y(23))))/(exp(y(23))*exp(y(23)))));
T658 = exp(y(24))*getPowerDeriv(exp(y(24)),T124,1);
T670 = 1/(1+params(38))*getPowerDeriv((1+y(3))/(1+params(38)),params(40),1);
T684 = params(47)*(-(exp(y(27))*params(46)))/(exp(y(27))*exp(y(27)));
T689 = exp(y(29))*getPowerDeriv(exp(y(29)),(-params(9)),1);
T690 = T689/exp(y(34));
T709 = (-(T226*params(10)*params(25)*T690))/(T231*T231);
T727 = exp(y(58))*getPowerDeriv(exp(y(58)),(-params(9)),1);
T728 = T727/exp(y(59));
T734 = params(10)*params(25)*T728/T231;
T744 = (-(exp(y(29))*params(34)*exp(y(30))))/(exp(y(30))*exp(y(30)));
T745 = getPowerDeriv(T240,T243,1)*T744;
T749 = params(34)^T243*exp(y(30))*getPowerDeriv(exp(y(30)),T255,1);
T750 = getPowerDeriv(T261,1+params(11),1);
T758 = (-(exp(y(31))*exp(y(29))*params(35)))/(exp(y(31))*exp(y(31)));
T759 = getPowerDeriv(T251,T243,1)*T758;
T763 = params(35)^T243*exp(y(31))*getPowerDeriv(exp(y(31)),T255,1);
T768 = T280*T285*getPowerDeriv(T285,params(21),1);
T771 = T282*T287/T231+T282*T768/T231;
T776 = T282*getPowerDeriv(T282,1+params(21),1);
T779 = exp(y(39))*T387*T776/(1+params(21));
T785 = (-(exp(y(34))*exp(y(4))))/(exp(y(4))*exp(y(4)));
T787 = (-(y(35)*T785));
T790 = exp(y(34))*exp(y(34));
T791 = (-(exp(y(27))*exp(y(34))))/T790;
T794 = (-(exp(y(34))*T230))/T790;
T806 = (-(T226*params(10)*params(25)*T794))/(T231*T231);
T816 = (-(exp(y(58))^(-params(9))*exp(y(59))));
T818 = T816/(exp(y(59))*exp(y(59)));
T824 = params(10)*params(25)*T818/T231;
T831 = 1/params(36);
T833 = T831*getPowerDeriv(T41,params(43),1);
T840 = (1+params(39))*T38*(T43*T831+T41*T833)*getPowerDeriv(T41*T43,1-params(42),1);
T845 = (-params(36))/(y(35)*y(35));
T859 = (-params(36))/(y(60)*y(60));
T861 = T859*getPowerDeriv(T294,T298,1);
T865 = getPowerDeriv(T294,1-(1+params(23))/params(23),1);
T866 = T859*T865;
T876 = (-((-(exp(y(36))*exp(y(37))))/(exp(y(37))*exp(y(37)))));
T879 = exp(y(38))*getPowerDeriv(exp(y(38)),T271,1);
T891 = 1/(1+params(39))*getPowerDeriv((1+y(6))/(1+params(39)),params(42),1);
T904 = (-(T135*exp(y(48))))/(exp(y(48))*exp(y(48)));
T905 = getPowerDeriv(T138,params(22),1)*T904;
T906 = T133*T905;
T915 = exp(y(25))*T375*params(27)*exp(y(48))*getPowerDeriv(exp(y(48)),(-params(22)),1)/(1+params(22));
T920 = (-(T135*params(32)*exp(y(49))/params(24)));
T926 = (-(T282*exp(y(51))))/(exp(y(51))*exp(y(51)));
T927 = getPowerDeriv(T285,params(21),1)*T926;
T928 = T280*T927;
T937 = exp(y(39))*T388*params(33)*exp(y(51))*getPowerDeriv(exp(y(51)),(-params(21)),1)/(1+params(21));
T942 = (-(T282*params(37)*exp(y(52))/params(23)));
T1014 = (-((exp(y(15))*getPowerDeriv(exp(y(15)),1-params(1),1)+exp(y(15))*exp(y(15))*getPowerDeriv(exp(y(15)),1-params(1),2))/(1-params(1))));
T1018 = T471+exp(y(15))*exp(y(15))*getPowerDeriv(exp(y(15)),(-params(1)),2);
T1019 = T1018/exp(y(20));
T1040 = (T506+exp(y(53))*exp(y(53))*getPowerDeriv(exp(y(53)),(-params(1)),2))/exp(y(54));
T1047 = (-(exp(y(20))*T471))/T569;
T1066 = ((-(T76*exp(y(20))))*T569-(-(T76*exp(y(20))))*(T569+T569))/(T569*T569);
T1099 = (T595*exp(y(54))*exp(y(54))-T595*(exp(y(54))*exp(y(54))+exp(y(54))*exp(y(54))))/(exp(y(54))*exp(y(54))*exp(y(54))*exp(y(54)));
T1216 = (T79*T79*(-(T74*params(2)*params(26)*T1019))-(-(T74*params(2)*params(26)*T472))*(T79*T472+T79*T472))/(T79*T79*T79*T79);
T1260 = (T79*T79*(-(T74*params(2)*params(26)*T1047))-(-(T74*params(2)*params(26)*T570))*(T79*T472+T79*T472))/(T79*T79*T79*T79);
T1289 = (T79*T79*(-(T74*params(2)*params(26)*T1066))-(-(T74*params(2)*params(26)*T570))*(T79*T570+T79*T570))/(T79*T79*T79*T79);
T1301 = params(2)*params(26)*(-(exp(y(54))*T506))/(exp(y(54))*exp(y(54)))/T79;
T1464 = T689+exp(y(29))*exp(y(29))*getPowerDeriv(exp(y(29)),(-params(9)),2);
T1465 = T1464/exp(y(34));
T1486 = (T727+exp(y(58))*exp(y(58))*getPowerDeriv(exp(y(58)),(-params(9)),2))/exp(y(59));
T1493 = (-(exp(y(34))*T689))/T790;
T1510 = (T790*(-(exp(y(34))*T230))-(-(exp(y(34))*T230))*(T790+T790))/(T790*T790);
T1543 = (T816*exp(y(59))*exp(y(59))-T816*(exp(y(59))*exp(y(59))+exp(y(59))*exp(y(59))))/(exp(y(59))*exp(y(59))*exp(y(59))*exp(y(59)));
T1668 = (T231*T231*(-(T226*params(10)*params(25)*T1465))-(-(T226*params(10)*params(25)*T690))*(T231*T690+T231*T690))/(T231*T231*T231*T231);
T1712 = (T231*T231*(-(T226*params(10)*params(25)*T1493))-(-(T226*params(10)*params(25)*T794))*(T231*T690+T231*T690))/(T231*T231*T231*T231);
T1741 = (T231*T231*(-(T226*params(10)*params(25)*T1510))-(-(T226*params(10)*params(25)*T794))*(T231*T794+T231*T794))/(T231*T231*T231*T231);
T1753 = params(10)*params(25)*(-(exp(y(59))*T727))/(exp(y(59))*exp(y(59)))/T231;
lhs =y(26);
rhs =(1+params(38))*T15*T23*(1+x(it_, 7))-1;
residual(1)= lhs-rhs;
lhs =y(40);
rhs =(1+params(39))*T38*T46*(1+x(it_, 8))-1;
residual(2)= lhs-rhs;
lhs =y(42);
rhs =T60+params(2)*y(63);
residual(3)= lhs-rhs;
lhs =1/(1+y(26));
rhs =params(2)*T74/T79/y(55);
residual(4)= lhs-rhs;
lhs =T93;
rhs =1;
residual(5)= lhs-rhs;
lhs =T99;
rhs =T104^T91;
residual(6)= lhs-rhs;
lhs =exp(y(15));
rhs =T114^(1+params(3));
residual(7)= lhs-rhs;
lhs =exp(y(24))^T124;
rhs =exp(y(22))/exp(y(23));
residual(8)= lhs-rhs;
lhs =exp(y(22));
rhs =T135*T140/T79+T146*T152*exp(y(56));
residual(9)= lhs-rhs;
lhs =exp(y(23));
rhs =T135*(1+params(32)*exp(y(49)))/params(24)+T146*T167*exp(y(57));
residual(10)= lhs-rhs;
lhs =(1-params(26))*exp(y(24))^T175+params(26)*T178^T175;
rhs =1;
residual(11)= lhs-rhs;
lhs =exp(y(25));
rhs =(1-params(26))*exp(y(24))^T151+params(26)*T178^T151*exp(y(2));
residual(12)= lhs-rhs;
lhs =T135;
rhs =exp(y(16))+exp(y(19))+1/params(30)*exp(y(31));
residual(13)= lhs-rhs;
lhs =exp(y(19));
rhs =T135*params(4)*exp(y(47));
residual(14)= lhs-rhs;
lhs =y(28);
rhs =y(21)*exp(y(20))/exp(y(1));
residual(15)= lhs-rhs;
lhs =1/(1+y(40));
rhs =params(10)*T226/T231/y(60);
residual(16)= lhs-rhs;
lhs =T245;
rhs =1;
residual(17)= lhs-rhs;
lhs =1/exp(y(27))/exp(y(20));
rhs =T251^T243;
residual(18)= lhs-rhs;
lhs =exp(y(29));
rhs =T261^(1+params(11));
residual(19)= lhs-rhs;
lhs =exp(y(38))^T271;
rhs =exp(y(36))/exp(y(37));
residual(20)= lhs-rhs;
lhs =exp(y(36));
rhs =T282*T287/T231+T293*T299*exp(y(61));
residual(21)= lhs-rhs;
lhs =exp(y(37));
rhs =T282*(1+params(37)*exp(y(52)))/params(23)+T293*T314*exp(y(62));
residual(22)= lhs-rhs;
lhs =(1-params(25))*exp(y(38))^T322+params(25)*T325^T322;
rhs =1;
residual(23)= lhs-rhs;
lhs =exp(y(39));
rhs =(1-params(25))*exp(y(38))^T298+params(25)*T325^T298*exp(y(5));
residual(24)= lhs-rhs;
lhs =T282;
rhs =exp(y(30))+exp(y(33))+exp(y(17))*params(30);
residual(25)= lhs-rhs;
lhs =exp(y(33));
rhs =T282*params(12)*exp(y(50));
residual(26)= lhs-rhs;
lhs =y(41);
rhs =y(35)*exp(y(34))/exp(y(4));
residual(27)= lhs-rhs;
lhs =params(44)/T230*params(45);
rhs =T366/T76*params(48);
residual(28)= lhs-rhs;
lhs =y(13);
rhs =T60-T378;
residual(29)= lhs-rhs;
lhs =y(14);
rhs =exp(y(29))^(1-params(9))/(1-params(9))-T391;
residual(30)= lhs-rhs;
lhs =y(43);
rhs =y(13)+params(2)*y(64);
residual(31)= lhs-rhs;
lhs =y(44);
rhs =y(14)+params(2)*y(65);
residual(32)= lhs-rhs;
lhs =y(46);
rhs =y(13)*params(49)+y(14)*params(50);
residual(33)= lhs-rhs;
lhs =y(45);
rhs =y(46)+params(2)*y(66);
residual(34)= lhs-rhs;
lhs =y(47);
rhs =params(5)*y(7)+params(6)*x(it_, 1);
residual(35)= lhs-rhs;
lhs =y(48);
rhs =params(7)*y(8)+params(8)*x(it_, 2);
residual(36)= lhs-rhs;
lhs =y(49);
rhs =params(19)*y(9)+params(20)*x(it_, 6);
residual(37)= lhs-rhs;
lhs =y(50);
rhs =params(13)*y(10)+params(14)*x(it_, 3);
residual(38)= lhs-rhs;
lhs =y(51);
rhs =params(15)*y(11)+params(16)*x(it_, 4);
residual(39)= lhs-rhs;
lhs =y(52);
rhs =params(17)*y(12)+params(18)*x(it_, 5);
residual(40)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(40, 74);

  %
  % Jacobian matrix
  %

  g1(1,21)=(-((1+x(it_, 7))*T619));
  g1(1,3)=(-((1+x(it_, 7))*(1+params(38))*T23*T670));
  g1(1,26)=1;
  g1(1,73)=(-((1+params(38))*T15*T23));
  g1(2,35)=(-((1+x(it_, 8))*T840));
  g1(2,6)=(-((1+x(it_, 8))*(1+params(39))*T46*T891));
  g1(2,40)=1;
  g1(2,74)=(-((1+params(39))*T38*T46));
  g1(3,15)=T469;
  g1(3,42)=1;
  g1(3,63)=(-params(2));
  g1(4,15)=(-((-(params(2)*T74*T472))/(T79*T79)/y(55)));
  g1(4,53)=(-(params(2)*T507/T79/y(55)));
  g1(4,20)=(-((-(params(2)*T74*T570))/(T79*T79)/y(55)));
  g1(4,54)=(-(params(2)*T597/T79/y(55)));
  g1(4,55)=(-((-(params(2)*T74/T79))/(y(55)*y(55))));
  g1(4,26)=(-1)/((1+y(26))*(1+y(26)));
  g1(5,15)=exp(y(20))*T88*getPowerDeriv(T88,T91,1);
  g1(5,16)=exp(y(20))*T524;
  g1(5,20)=T93;
  g1(6,15)=(-(T104*getPowerDeriv(T104,T91,1)));
  g1(6,17)=(-T537);
  g1(6,27)=T99;
  g1(6,34)=T791;
  g1(7,15)=exp(y(15));
  g1(7,16)=(-(T528*T529));
  g1(7,17)=(-(T529*T541));
  g1(8,22)=(-(exp(y(22))/exp(y(23))));
  g1(8,23)=T655;
  g1(8,24)=T658;
  g1(9,15)=(-(T135*(-(T140*T472))/(T79*T79)+exp(y(56))*T152*T491));
  g1(9,53)=(-(exp(y(56))*T152*T513));
  g1(9,18)=(-T550);
  g1(9,20)=(-(T135*(-(T140*T570))/(T79*T79)+exp(y(56))*T152*T582));
  g1(9,54)=(-(exp(y(56))*T152*T603));
  g1(9,55)=(-(exp(y(56))*T146*T640));
  g1(9,22)=exp(y(22));
  g1(9,56)=(-(T146*T152*exp(y(56))));
  g1(9,48)=(-(T135*T906/T79));
  g1(10,15)=(-(exp(y(57))*T167*T491));
  g1(10,53)=(-(exp(y(57))*T167*T513));
  g1(10,18)=(-(T135*(1+params(32)*exp(y(49)))/params(24)));
  g1(10,20)=(-(exp(y(57))*T167*T582));
  g1(10,54)=(-(exp(y(57))*T167*T603));
  g1(10,55)=(-(exp(y(57))*T146*T645));
  g1(10,23)=exp(y(23));
  g1(10,57)=(-(T146*T167*exp(y(57))));
  g1(10,49)=T920;
  g1(11,21)=params(26)*T624*getPowerDeriv(T178,T175,1);
  g1(11,24)=(1-params(26))*exp(y(24))*getPowerDeriv(exp(y(24)),T175,1);
  g1(12,21)=(-(exp(y(2))*params(26)*T624*getPowerDeriv(T178,T151,1)));
  g1(12,24)=(-((1-params(26))*exp(y(24))*getPowerDeriv(exp(y(24)),T151,1)));
  g1(12,2)=(-(params(26)*T178^T151*exp(y(2))));
  g1(12,25)=exp(y(25));
  g1(13,16)=(-exp(y(16)));
  g1(13,18)=T135;
  g1(13,19)=(-exp(y(19)));
  g1(13,31)=(-(1/params(30)*exp(y(31))));
  g1(14,18)=(-(T135*params(4)*exp(y(47))));
  g1(14,19)=exp(y(19));
  g1(14,47)=(-(T135*params(4)*exp(y(47))));
  g1(15,1)=T566;
  g1(15,20)=(-(y(21)*exp(y(20))/exp(y(1))));
  g1(15,21)=(-(exp(y(20))/exp(y(1))));
  g1(15,28)=1;
  g1(16,29)=(-((-(params(10)*T226*T690))/(T231*T231)/y(60)));
  g1(16,58)=(-(params(10)*T728/T231/y(60)));
  g1(16,34)=(-((-(params(10)*T226*T794))/(T231*T231)/y(60)));
  g1(16,59)=(-(params(10)*T818/T231/y(60)));
  g1(16,60)=(-((-(params(10)*T226/T231))/(y(60)*y(60))));
  g1(16,40)=(-1)/((1+y(40))*(1+y(40)));
  g1(17,29)=exp(y(34))*T240*getPowerDeriv(T240,T243,1);
  g1(17,30)=exp(y(34))*T745;
  g1(17,34)=T245;
  g1(18,20)=T592/T569;
  g1(18,27)=(-exp(y(27)))/(exp(y(27))*exp(y(27)))/exp(y(20));
  g1(18,29)=(-(T251*getPowerDeriv(T251,T243,1)));
  g1(18,31)=(-T759);
  g1(19,29)=exp(y(29));
  g1(19,30)=(-(T749*T750));
  g1(19,31)=(-(T750*T763));
  g1(20,36)=(-(exp(y(36))/exp(y(37))));
  g1(20,37)=T876;
  g1(20,38)=T879;
  g1(21,29)=(-(T282*(-(T287*T690))/(T231*T231)+exp(y(61))*T299*T709));
  g1(21,58)=(-(exp(y(61))*T299*T734));
  g1(21,32)=(-T771);
  g1(21,34)=(-(T282*(-(T287*T794))/(T231*T231)+exp(y(61))*T299*T806));
  g1(21,59)=(-(exp(y(61))*T299*T824));
  g1(21,60)=(-(exp(y(61))*T293*T861));
  g1(21,36)=exp(y(36));
  g1(21,61)=(-(T293*T299*exp(y(61))));
  g1(21,51)=(-(T282*T928/T231));
  g1(22,29)=(-(exp(y(62))*T314*T709));
  g1(22,58)=(-(exp(y(62))*T314*T734));
  g1(22,32)=(-(T282*(1+params(37)*exp(y(52)))/params(23)));
  g1(22,34)=(-(exp(y(62))*T314*T806));
  g1(22,59)=(-(exp(y(62))*T314*T824));
  g1(22,60)=(-(exp(y(62))*T293*T866));
  g1(22,37)=exp(y(37));
  g1(22,62)=(-(T293*T314*exp(y(62))));
  g1(22,52)=T942;
  g1(23,35)=params(25)*T845*getPowerDeriv(T325,T322,1);
  g1(23,38)=(1-params(25))*exp(y(38))*getPowerDeriv(exp(y(38)),T322,1);
  g1(24,35)=(-(exp(y(5))*params(25)*T845*getPowerDeriv(T325,T298,1)));
  g1(24,38)=(-((1-params(25))*exp(y(38))*getPowerDeriv(exp(y(38)),T298,1)));
  g1(24,5)=(-(params(25)*T325^T298*exp(y(5))));
  g1(24,39)=exp(y(39));
  g1(25,17)=(-(exp(y(17))*params(30)));
  g1(25,30)=(-exp(y(30)));
  g1(25,32)=T282;
  g1(25,33)=(-exp(y(33)));
  g1(26,32)=(-(T282*params(12)*exp(y(50))));
  g1(26,33)=exp(y(33));
  g1(26,50)=(-(T282*params(12)*exp(y(50))));
  g1(27,4)=T787;
  g1(27,34)=(-(y(35)*exp(y(34))/exp(y(4))));
  g1(27,35)=(-(exp(y(34))/exp(y(4))));
  g1(27,41)=1;
  g1(28,15)=(-(params(48)*(-(T366*T471))/(T76*T76)));
  g1(28,27)=(-(params(48)*T684/T76));
  g1(28,29)=params(45)*(-(params(44)*T689))/(T230*T230);
  g1(29,13)=1;
  g1(29,15)=T469;
  g1(29,18)=T558;
  g1(29,25)=T378;
  g1(29,48)=T915;
  g1(30,14)=1;
  g1(30,29)=(-(exp(y(29))*getPowerDeriv(exp(y(29)),1-params(9),1)/(1-params(9))));
  g1(30,32)=T779;
  g1(30,39)=T391;
  g1(30,51)=T937;
  g1(31,13)=(-1);
  g1(31,43)=1;
  g1(31,64)=(-params(2));
  g1(32,14)=(-1);
  g1(32,44)=1;
  g1(32,65)=(-params(2));
  g1(33,13)=(-params(49));
  g1(33,14)=(-params(50));
  g1(33,46)=1;
  g1(34,45)=1;
  g1(34,66)=(-params(2));
  g1(34,46)=(-1);
  g1(35,7)=(-params(5));
  g1(35,47)=1;
  g1(35,67)=(-params(6));
  g1(36,8)=(-params(7));
  g1(36,48)=1;
  g1(36,68)=(-params(8));
  g1(37,9)=(-params(19));
  g1(37,49)=1;
  g1(37,72)=(-params(20));
  g1(38,10)=(-params(13));
  g1(38,50)=1;
  g1(38,69)=(-params(14));
  g1(39,11)=(-params(15));
  g1(39,51)=1;
  g1(39,70)=(-params(16));
  g1(40,12)=(-params(17));
  g1(40,52)=1;
  g1(40,71)=(-params(18));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(378,3);
  v2(1,1)=1;
  v2(1,2)=1501;
  v2(1,3)=(-((1+x(it_, 7))*(1+params(38))*T15*(getPowerDeriv(T18*T20,1-params(40),1)*(T610*T612+T610*T612+T18*T610*T610*getPowerDeriv(T18,params(41),2))+(T20*T610+T18*T612)*(T20*T610+T18*T612)*getPowerDeriv(T18*T20,1-params(40),2))));
  v2(2,1)=1;
  v2(2,2)=169;
  v2(2,3)=(-((1+x(it_, 7))*(1+params(38))*(T20*T610+T18*T612)*getPowerDeriv(T18*T20,1-params(40),1)*T670));
  v2(3,1)=1;
  v2(3,2)=1483;
  v2(3,3)=  v2(2,3);
  v2(4,1)=1;
  v2(4,2)=151;
  v2(4,3)=(-((1+x(it_, 7))*(1+params(38))*T23*1/(1+params(38))*1/(1+params(38))*getPowerDeriv((1+y(3))/(1+params(38)),params(40),2)));
  v2(5,1)=1;
  v2(5,2)=5349;
  v2(5,3)=(-T619);
  v2(6,1)=1;
  v2(6,2)=1553;
  v2(6,3)=  v2(5,3);
  v2(7,1)=1;
  v2(7,2)=5331;
  v2(7,3)=(-((1+params(38))*T23*T670));
  v2(8,1)=1;
  v2(8,2)=221;
  v2(8,3)=  v2(7,3);
  v2(9,1)=2;
  v2(9,2)=2551;
  v2(9,3)=(-((1+x(it_, 8))*(1+params(39))*T38*(getPowerDeriv(T41*T43,1-params(42),1)*(T831*T833+T831*T833+T41*T831*T831*getPowerDeriv(T41,params(43),2))+(T43*T831+T41*T833)*(T43*T831+T41*T833)*getPowerDeriv(T41*T43,1-params(42),2))));
  v2(10,1)=2;
  v2(10,2)=405;
  v2(10,3)=(-((1+x(it_, 8))*(1+params(39))*(T43*T831+T41*T833)*getPowerDeriv(T41*T43,1-params(42),1)*T891));
  v2(11,1)=2;
  v2(11,2)=2522;
  v2(11,3)=  v2(10,3);
  v2(12,1)=2;
  v2(12,2)=376;
  v2(12,3)=(-((1+x(it_, 8))*(1+params(39))*T46*1/(1+params(39))*1/(1+params(39))*getPowerDeriv((1+y(6))/(1+params(39)),params(42),2)));
  v2(13,1)=2;
  v2(13,2)=5437;
  v2(13,3)=(-T840);
  v2(14,1)=2;
  v2(14,2)=2590;
  v2(14,3)=  v2(13,3);
  v2(15,1)=2;
  v2(15,2)=5408;
  v2(15,3)=(-((1+params(39))*T46*T891));
  v2(16,1)=2;
  v2(16,2)=444;
  v2(16,3)=  v2(15,3);
  v2(17,1)=3;
  v2(17,2)=1051;
  v2(17,3)=T1014;
  v2(18,1)=4;
  v2(18,2)=1051;
  v2(18,3)=(-((T79*T79*(-(params(2)*T74*T1019))-(-(params(2)*T74*T472))*(T79*T472+T79*T472))/(T79*T79*T79*T79)/y(55)));
  v2(19,1)=4;
  v2(19,2)=3863;
  v2(19,3)=(-((-(T472*params(2)*T507))/(T79*T79)/y(55)));
  v2(20,1)=4;
  v2(20,2)=1089;
  v2(20,3)=  v2(19,3);
  v2(21,1)=4;
  v2(21,2)=3901;
  v2(21,3)=(-(params(2)*T1040/T79/y(55)));
  v2(22,1)=4;
  v2(22,2)=1421;
  v2(22,3)=(-((T79*T79*(-(params(2)*T74*T1047))-(-(params(2)*T74*T570))*(T79*T472+T79*T472))/(T79*T79*T79*T79)/y(55)));
  v2(23,1)=4;
  v2(23,2)=1056;
  v2(23,3)=  v2(22,3);
  v2(24,1)=4;
  v2(24,2)=1459;
  v2(24,3)=(-((-(params(2)*T507*T570))/(T79*T79)/y(55)));
  v2(25,1)=4;
  v2(25,2)=3868;
  v2(25,3)=  v2(24,3);
  v2(26,1)=4;
  v2(26,2)=1426;
  v2(26,3)=(-((T79*T79*(-(params(2)*T74*T1066))-(-(params(2)*T74*T570))*(T79*T570+T79*T570))/(T79*T79*T79*T79)/y(55)));
  v2(27,1)=4;
  v2(27,2)=3937;
  v2(27,3)=(-((-(T472*params(2)*T597))/(T79*T79)/y(55)));
  v2(28,1)=4;
  v2(28,2)=1090;
  v2(28,3)=  v2(27,3);
  v2(29,1)=4;
  v2(29,2)=3975;
  v2(29,3)=(-(params(2)*(-(exp(y(54))*T506))/(exp(y(54))*exp(y(54)))/T79/y(55)));
  v2(30,1)=4;
  v2(30,2)=3902;
  v2(30,3)=  v2(29,3);
  v2(31,1)=4;
  v2(31,2)=3942;
  v2(31,3)=(-((-(T570*params(2)*T597))/(T79*T79)/y(55)));
  v2(32,1)=4;
  v2(32,2)=1460;
  v2(32,3)=  v2(31,3);
  v2(33,1)=4;
  v2(33,2)=3976;
  v2(33,3)=(-(params(2)*T1099/T79/y(55)));
  v2(34,1)=4;
  v2(34,2)=4011;
  v2(34,3)=(-((-((-(params(2)*T74*T472))/(T79*T79)))/(y(55)*y(55))));
  v2(35,1)=4;
  v2(35,2)=1091;
  v2(35,3)=  v2(34,3);
  v2(36,1)=4;
  v2(36,2)=4049;
  v2(36,3)=(-((-(params(2)*T507/T79))/(y(55)*y(55))));
  v2(37,1)=4;
  v2(37,2)=3903;
  v2(37,3)=  v2(36,3);
  v2(38,1)=4;
  v2(38,2)=4016;
  v2(38,3)=(-((-((-(params(2)*T74*T570))/(T79*T79)))/(y(55)*y(55))));
  v2(39,1)=4;
  v2(39,2)=1461;
  v2(39,3)=  v2(38,3);
  v2(40,1)=4;
  v2(40,2)=4050;
  v2(40,3)=(-((-(params(2)*T597/T79))/(y(55)*y(55))));
  v2(41,1)=4;
  v2(41,2)=3977;
  v2(41,3)=  v2(40,3);
  v2(42,1)=4;
  v2(42,2)=4051;
  v2(42,3)=(-((-((-(params(2)*T74/T79))*(y(55)+y(55))))/(y(55)*y(55)*y(55)*y(55))));
  v2(43,1)=4;
  v2(43,2)=1876;
  v2(43,3)=(1+y(26)+1+y(26))/((1+y(26))*(1+y(26))*(1+y(26))*(1+y(26)));
  v2(44,1)=5;
  v2(44,2)=1051;
  v2(44,3)=exp(y(20))*(T88*getPowerDeriv(T88,T91,1)+T88*T88*getPowerDeriv(T88,T91,2));
  v2(45,1)=5;
  v2(45,2)=1125;
  v2(45,3)=exp(y(20))*(T524+T523*T88*getPowerDeriv(T88,T91,2));
  v2(46,1)=5;
  v2(46,2)=1052;
  v2(46,3)=  v2(45,3);
  v2(47,1)=5;
  v2(47,2)=1126;
  v2(47,3)=exp(y(20))*(T523*T523*getPowerDeriv(T88,T91,2)+getPowerDeriv(T88,T91,1)*((-(exp(y(15))*params(28)*exp(y(16))))*exp(y(16))*exp(y(16))-(-(exp(y(15))*params(28)*exp(y(16))))*(exp(y(16))*exp(y(16))+exp(y(16))*exp(y(16))))/(exp(y(16))*exp(y(16))*exp(y(16))*exp(y(16))));
  v2(48,1)=5;
  v2(48,2)=1421;
  v2(48,3)=exp(y(20))*T88*getPowerDeriv(T88,T91,1);
  v2(49,1)=5;
  v2(49,2)=1056;
  v2(49,3)=  v2(48,3);
  v2(50,1)=5;
  v2(50,2)=1422;
  v2(50,3)=exp(y(20))*T524;
  v2(51,1)=5;
  v2(51,2)=1130;
  v2(51,3)=  v2(50,3);
  v2(52,1)=5;
  v2(52,2)=1426;
  v2(52,3)=T93;
  v2(53,1)=6;
  v2(53,2)=1051;
  v2(53,3)=(-(T104*getPowerDeriv(T104,T91,1)+T104*T104*getPowerDeriv(T104,T91,2)));
  v2(54,1)=6;
  v2(54,2)=1199;
  v2(54,3)=(-(T537+T536*T104*getPowerDeriv(T104,T91,2)));
  v2(55,1)=6;
  v2(55,2)=1053;
  v2(55,3)=  v2(54,3);
  v2(56,1)=6;
  v2(56,2)=1201;
  v2(56,3)=(-(T536*T536*getPowerDeriv(T104,T91,2)+getPowerDeriv(T104,T91,1)*((-(exp(y(15))*params(29)*exp(y(17))))*exp(y(17))*exp(y(17))-(-(exp(y(15))*params(29)*exp(y(17))))*(exp(y(17))*exp(y(17))+exp(y(17))*exp(y(17))))/(exp(y(17))*exp(y(17))*exp(y(17))*exp(y(17)))));
  v2(57,1)=6;
  v2(57,2)=1951;
  v2(57,3)=T99;
  v2(58,1)=6;
  v2(58,2)=2469;
  v2(58,3)=T791;
  v2(59,1)=6;
  v2(59,2)=1958;
  v2(59,3)=  v2(58,3);
  v2(60,1)=6;
  v2(60,2)=2476;
  v2(60,3)=((-(exp(y(27))*exp(y(34))))*T790-(-(exp(y(27))*exp(y(34))))*(T790+T790))/(T790*T790);
  v2(61,1)=7;
  v2(61,2)=1051;
  v2(61,3)=exp(y(15));
  v2(62,1)=7;
  v2(62,2)=1126;
  v2(62,3)=(-(T529*params(28)^T91*(exp(y(16))*getPowerDeriv(exp(y(16)),T108,1)+exp(y(16))*exp(y(16))*getPowerDeriv(exp(y(16)),T108,2))+T528*T528*getPowerDeriv(T114,1+params(3),2)));
  v2(63,1)=7;
  v2(63,2)=1200;
  v2(63,3)=(-(T541*T528*getPowerDeriv(T114,1+params(3),2)));
  v2(64,1)=7;
  v2(64,2)=1127;
  v2(64,3)=  v2(63,3);
  v2(65,1)=7;
  v2(65,2)=1201;
  v2(65,3)=(-(T541*T541*getPowerDeriv(T114,1+params(3),2)+T529*params(29)^T91*(exp(y(17))*getPowerDeriv(exp(y(17)),T108,1)+exp(y(17))*exp(y(17))*getPowerDeriv(exp(y(17)),T108,2))));
  v2(66,1)=8;
  v2(66,2)=1576;
  v2(66,3)=(-(exp(y(22))/exp(y(23))));
  v2(67,1)=8;
  v2(67,2)=1650;
  v2(67,3)=T655;
  v2(68,1)=8;
  v2(68,2)=1577;
  v2(68,3)=  v2(67,3);
  v2(69,1)=8;
  v2(69,2)=1651;
  v2(69,3)=(-(((-(exp(y(22))*exp(y(23))))*exp(y(23))*exp(y(23))-(-(exp(y(22))*exp(y(23))))*(exp(y(23))*exp(y(23))+exp(y(23))*exp(y(23))))/(exp(y(23))*exp(y(23))*exp(y(23))*exp(y(23)))));
  v2(70,1)=8;
  v2(70,2)=1726;
  v2(70,3)=T658+exp(y(24))*exp(y(24))*getPowerDeriv(exp(y(24)),T124,2);
  v2(71,1)=9;
  v2(71,2)=1051;
  v2(71,3)=(-(T135*(T79*T79*(-(T140*T1019))-(-(T140*T472))*(T79*T472+T79*T472))/(T79*T79*T79*T79)+exp(y(56))*T152*T1216));
  v2(72,1)=9;
  v2(72,2)=3863;
  v2(72,3)=(-(exp(y(56))*T152*(-(T472*params(2)*params(26)*T507))/(T79*T79)));
  v2(73,1)=9;
  v2(73,2)=1089;
  v2(73,3)=  v2(72,3);
  v2(74,1)=9;
  v2(74,2)=3901;
  v2(74,3)=(-(exp(y(56))*T152*params(2)*params(26)*T1040/T79));
  v2(75,1)=9;
  v2(75,2)=1273;
  v2(75,3)=(-(T135*(-(T140*T472))/(T79*T79)+T135*(-(T472*T547))/(T79*T79)));
  v2(76,1)=9;
  v2(76,2)=1054;
  v2(76,3)=  v2(75,3);
  v2(77,1)=9;
  v2(77,2)=1276;
  v2(77,3)=(-(T550+T135*T547/T79+T135*T133*(T138*getPowerDeriv(T138,params(22),1)+T138*T138*getPowerDeriv(T138,params(22),2))/T79));
  v2(78,1)=9;
  v2(78,2)=1421;
  v2(78,3)=(-(T135*(T79*T79*(-(T140*T1047))-(-(T140*T570))*(T79*T472+T79*T472))/(T79*T79*T79*T79)+exp(y(56))*T152*T1260));
  v2(79,1)=9;
  v2(79,2)=1056;
  v2(79,3)=  v2(78,3);
  v2(80,1)=9;
  v2(80,2)=1459;
  v2(80,3)=(-(exp(y(56))*T152*(-(params(2)*params(26)*T507*T570))/(T79*T79)));
  v2(81,1)=9;
  v2(81,2)=3868;
  v2(81,3)=  v2(80,3);
  v2(82,1)=9;
  v2(82,2)=1424;
  v2(82,3)=(-(T135*(-(T140*T570))/(T79*T79)+T135*(-(T547*T570))/(T79*T79)));
  v2(83,1)=9;
  v2(83,2)=1278;
  v2(83,3)=  v2(82,3);
  v2(84,1)=9;
  v2(84,2)=1426;
  v2(84,3)=(-(T135*(T79*T79*(-(T140*T1066))-(-(T140*T570))*(T79*T570+T79*T570))/(T79*T79*T79*T79)+exp(y(56))*T152*T1289));
  v2(85,1)=9;
  v2(85,2)=3937;
  v2(85,3)=(-(exp(y(56))*T152*(-(T472*params(2)*params(26)*T597))/(T79*T79)));
  v2(86,1)=9;
  v2(86,2)=1090;
  v2(86,3)=  v2(85,3);
  v2(87,1)=9;
  v2(87,2)=3975;
  v2(87,3)=(-(exp(y(56))*T152*T1301));
  v2(88,1)=9;
  v2(88,2)=3902;
  v2(88,3)=  v2(87,3);
  v2(89,1)=9;
  v2(89,2)=3942;
  v2(89,3)=(-(exp(y(56))*T152*(-(T570*params(2)*params(26)*T597))/(T79*T79)));
  v2(90,1)=9;
  v2(90,2)=1460;
  v2(90,3)=  v2(89,3);
  v2(91,1)=9;
  v2(91,2)=3976;
  v2(91,3)=(-(exp(y(56))*T152*params(2)*params(26)*T1099/T79));
  v2(92,1)=9;
  v2(92,2)=4011;
  v2(92,3)=(-(exp(y(56))*T491*T640));
  v2(93,1)=9;
  v2(93,2)=1091;
  v2(93,3)=  v2(92,3);
  v2(94,1)=9;
  v2(94,2)=4049;
  v2(94,3)=(-(exp(y(56))*T513*T640));
  v2(95,1)=9;
  v2(95,2)=3903;
  v2(95,3)=  v2(94,3);
  v2(96,1)=9;
  v2(96,2)=4016;
  v2(96,3)=(-(exp(y(56))*T582*T640));
  v2(97,1)=9;
  v2(97,2)=1461;
  v2(97,3)=  v2(96,3);
  v2(98,1)=9;
  v2(98,2)=4050;
  v2(98,3)=(-(exp(y(56))*T603*T640));
  v2(99,1)=9;
  v2(99,2)=3977;
  v2(99,3)=  v2(98,3);
  v2(100,1)=9;
  v2(100,2)=4051;
  v2(100,3)=(-(exp(y(56))*T146*(getPowerDeriv(T147,T151,1)*(-((-params(31))*(y(55)+y(55))))/(y(55)*y(55)*y(55)*y(55))+T638*T638*getPowerDeriv(T147,T151,2))));
  v2(101,1)=9;
  v2(101,2)=1576;
  v2(101,3)=exp(y(22));
  v2(102,1)=9;
  v2(102,2)=4085;
  v2(102,3)=(-(exp(y(56))*T152*T491));
  v2(103,1)=9;
  v2(103,2)=1092;
  v2(103,3)=  v2(102,3);
  v2(104,1)=9;
  v2(104,2)=4123;
  v2(104,3)=(-(exp(y(56))*T152*T513));
  v2(105,1)=9;
  v2(105,2)=3904;
  v2(105,3)=  v2(104,3);
  v2(106,1)=9;
  v2(106,2)=4090;
  v2(106,3)=(-(exp(y(56))*T152*T582));
  v2(107,1)=9;
  v2(107,2)=1462;
  v2(107,3)=  v2(106,3);
  v2(108,1)=9;
  v2(108,2)=4124;
  v2(108,3)=(-(exp(y(56))*T152*T603));
  v2(109,1)=9;
  v2(109,2)=3978;
  v2(109,3)=  v2(108,3);
  v2(110,1)=9;
  v2(110,2)=4125;
  v2(110,3)=(-(exp(y(56))*T146*T640));
  v2(111,1)=9;
  v2(111,2)=4052;
  v2(111,3)=  v2(110,3);
  v2(112,1)=9;
  v2(112,2)=4126;
  v2(112,3)=(-(T146*T152*exp(y(56))));
  v2(113,1)=9;
  v2(113,2)=3493;
  v2(113,3)=(-(T135*(-(T472*T906))/(T79*T79)));
  v2(114,1)=9;
  v2(114,2)=1084;
  v2(114,3)=  v2(113,3);
  v2(115,1)=9;
  v2(115,2)=3496;
  v2(115,3)=(-(T135*T906/T79+T135*T133*(T905+T904*T138*getPowerDeriv(T138,params(22),2))/T79));
  v2(116,1)=9;
  v2(116,2)=1306;
  v2(116,3)=  v2(115,3);
  v2(117,1)=9;
  v2(117,2)=3498;
  v2(117,3)=(-(T135*(-(T570*T906))/(T79*T79)));
  v2(118,1)=9;
  v2(118,2)=1454;
  v2(118,3)=  v2(117,3);
  v2(119,1)=9;
  v2(119,2)=3526;
  v2(119,3)=(-(T135*T133*(T904*T904*getPowerDeriv(T138,params(22),2)+getPowerDeriv(T138,params(22),1)*((-(T135*exp(y(48))))*exp(y(48))*exp(y(48))-(-(T135*exp(y(48))))*(exp(y(48))*exp(y(48))+exp(y(48))*exp(y(48))))/(exp(y(48))*exp(y(48))*exp(y(48))*exp(y(48))))/T79));
  v2(120,1)=10;
  v2(120,2)=1051;
  v2(120,3)=(-(exp(y(57))*T167*T1216));
  v2(121,1)=10;
  v2(121,2)=3863;
  v2(121,3)=(-(exp(y(57))*T167*(-(T472*params(2)*params(26)*T507))/(T79*T79)));
  v2(122,1)=10;
  v2(122,2)=1089;
  v2(122,3)=  v2(121,3);
  v2(123,1)=10;
  v2(123,2)=3901;
  v2(123,3)=(-(exp(y(57))*T167*params(2)*params(26)*T1040/T79));
  v2(124,1)=10;
  v2(124,2)=1276;
  v2(124,3)=(-(T135*(1+params(32)*exp(y(49)))/params(24)));
  v2(125,1)=10;
  v2(125,2)=1421;
  v2(125,3)=(-(exp(y(57))*T167*T1260));
  v2(126,1)=10;
  v2(126,2)=1056;
  v2(126,3)=  v2(125,3);
  v2(127,1)=10;
  v2(127,2)=1459;
  v2(127,3)=(-(exp(y(57))*T167*(-(params(2)*params(26)*T507*T570))/(T79*T79)));
  v2(128,1)=10;
  v2(128,2)=3868;
  v2(128,3)=  v2(127,3);
  v2(129,1)=10;
  v2(129,2)=1426;
  v2(129,3)=(-(exp(y(57))*T167*T1289));
  v2(130,1)=10;
  v2(130,2)=3937;
  v2(130,3)=(-(exp(y(57))*T167*(-(T472*params(2)*params(26)*T597))/(T79*T79)));
  v2(131,1)=10;
  v2(131,2)=1090;
  v2(131,3)=  v2(130,3);
  v2(132,1)=10;
  v2(132,2)=3975;
  v2(132,3)=(-(exp(y(57))*T167*T1301));
  v2(133,1)=10;
  v2(133,2)=3902;
  v2(133,3)=  v2(132,3);
  v2(134,1)=10;
  v2(134,2)=3942;
  v2(134,3)=(-(exp(y(57))*T167*(-(T570*params(2)*params(26)*T597))/(T79*T79)));
  v2(135,1)=10;
  v2(135,2)=1460;
  v2(135,3)=  v2(134,3);
  v2(136,1)=10;
  v2(136,2)=3976;
  v2(136,3)=(-(exp(y(57))*T167*params(2)*params(26)*T1099/T79));
  v2(137,1)=10;
  v2(137,2)=4011;
  v2(137,3)=(-(exp(y(57))*T491*T645));
  v2(138,1)=10;
  v2(138,2)=1091;
  v2(138,3)=  v2(137,3);
  v2(139,1)=10;
  v2(139,2)=4049;
  v2(139,3)=(-(exp(y(57))*T513*T645));
  v2(140,1)=10;
  v2(140,2)=3903;
  v2(140,3)=  v2(139,3);
  v2(141,1)=10;
  v2(141,2)=4016;
  v2(141,3)=(-(exp(y(57))*T582*T645));
  v2(142,1)=10;
  v2(142,2)=1461;
  v2(142,3)=  v2(141,3);
  v2(143,1)=10;
  v2(143,2)=4050;
  v2(143,3)=(-(exp(y(57))*T603*T645));
  v2(144,1)=10;
  v2(144,2)=3977;
  v2(144,3)=  v2(143,3);
  v2(145,1)=10;
  v2(145,2)=4051;
  v2(145,3)=(-(exp(y(57))*T146*(T644*(-((-params(31))*(y(55)+y(55))))/(y(55)*y(55)*y(55)*y(55))+T638*T638*getPowerDeriv(T147,1-(1+params(24))/params(24),2))));
  v2(146,1)=10;
  v2(146,2)=1651;
  v2(146,3)=exp(y(23));
  v2(147,1)=10;
  v2(147,2)=4159;
  v2(147,3)=(-(exp(y(57))*T167*T491));
  v2(148,1)=10;
  v2(148,2)=1093;
  v2(148,3)=  v2(147,3);
  v2(149,1)=10;
  v2(149,2)=4197;
  v2(149,3)=(-(exp(y(57))*T167*T513));
  v2(150,1)=10;
  v2(150,2)=3905;
  v2(150,3)=  v2(149,3);
  v2(151,1)=10;
  v2(151,2)=4164;
  v2(151,3)=(-(exp(y(57))*T167*T582));
  v2(152,1)=10;
  v2(152,2)=1463;
  v2(152,3)=  v2(151,3);
  v2(153,1)=10;
  v2(153,2)=4198;
  v2(153,3)=(-(exp(y(57))*T167*T603));
  v2(154,1)=10;
  v2(154,2)=3979;
  v2(154,3)=  v2(153,3);
  v2(155,1)=10;
  v2(155,2)=4199;
  v2(155,3)=(-(exp(y(57))*T146*T645));
  v2(156,1)=10;
  v2(156,2)=4053;
  v2(156,3)=  v2(155,3);
  v2(157,1)=10;
  v2(157,2)=4201;
  v2(157,3)=(-(T146*T167*exp(y(57))));
  v2(158,1)=10;
  v2(158,2)=3570;
  v2(158,3)=T920;
  v2(159,1)=10;
  v2(159,2)=1307;
  v2(159,3)=  v2(158,3);
  v2(160,1)=10;
  v2(160,2)=3601;
  v2(160,3)=T920;
  v2(161,1)=11;
  v2(161,2)=1501;
  v2(161,3)=params(26)*(getPowerDeriv(T178,T175,1)*(-((-params(31))*(y(21)+y(21))))/(y(21)*y(21)*y(21)*y(21))+T624*T624*getPowerDeriv(T178,T175,2));
  v2(162,1)=11;
  v2(162,2)=1726;
  v2(162,3)=(1-params(26))*(exp(y(24))*getPowerDeriv(exp(y(24)),T175,1)+exp(y(24))*exp(y(24))*getPowerDeriv(exp(y(24)),T175,2));
  v2(163,1)=12;
  v2(163,2)=1501;
  v2(163,3)=(-(exp(y(2))*params(26)*(getPowerDeriv(T178,T151,1)*(-((-params(31))*(y(21)+y(21))))/(y(21)*y(21)*y(21)*y(21))+T624*T624*getPowerDeriv(T178,T151,2))));
  v2(164,1)=12;
  v2(164,2)=1726;
  v2(164,3)=(-((1-params(26))*(exp(y(24))*getPowerDeriv(exp(y(24)),T151,1)+exp(y(24))*exp(y(24))*getPowerDeriv(exp(y(24)),T151,2))));
  v2(165,1)=12;
  v2(165,2)=95;
  v2(165,3)=(-(exp(y(2))*params(26)*T624*getPowerDeriv(T178,T151,1)));
  v2(166,1)=12;
  v2(166,2)=1482;
  v2(166,3)=  v2(165,3);
  v2(167,1)=12;
  v2(167,2)=76;
  v2(167,3)=(-(params(26)*T178^T151*exp(y(2))));
  v2(168,1)=12;
  v2(168,2)=1801;
  v2(168,3)=exp(y(25));
  v2(169,1)=13;
  v2(169,2)=1126;
  v2(169,3)=(-exp(y(16)));
  v2(170,1)=13;
  v2(170,2)=1276;
  v2(170,3)=T135;
  v2(171,1)=13;
  v2(171,2)=1351;
  v2(171,3)=(-exp(y(19)));
  v2(172,1)=13;
  v2(172,2)=2251;
  v2(172,3)=(-(1/params(30)*exp(y(31))));
  v2(173,1)=14;
  v2(173,2)=1276;
  v2(173,3)=(-(T135*params(4)*exp(y(47))));
  v2(174,1)=14;
  v2(174,2)=1351;
  v2(174,3)=exp(y(19));
  v2(175,1)=14;
  v2(175,2)=3422;
  v2(175,3)=(-(T135*params(4)*exp(y(47))));
  v2(176,1)=14;
  v2(176,2)=1305;
  v2(176,3)=  v2(175,3);
  v2(177,1)=14;
  v2(177,2)=3451;
  v2(177,3)=(-(T135*params(4)*exp(y(47))));
  v2(178,1)=15;
  v2(178,2)=1;
  v2(178,3)=(-(y(21)*((-(exp(y(20))*exp(y(1))))*exp(y(1))*exp(y(1))-(-(exp(y(20))*exp(y(1))))*(exp(y(1))*exp(y(1))+exp(y(1))*exp(y(1))))/(exp(y(1))*exp(y(1))*exp(y(1))*exp(y(1)))));
  v2(179,1)=15;
  v2(179,2)=1407;
  v2(179,3)=T566;
  v2(180,1)=15;
  v2(180,2)=20;
  v2(180,3)=  v2(179,3);
  v2(181,1)=15;
  v2(181,2)=1426;
  v2(181,3)=(-(y(21)*exp(y(20))/exp(y(1))));
  v2(182,1)=15;
  v2(182,2)=1481;
  v2(182,3)=(-T564);
  v2(183,1)=15;
  v2(183,2)=21;
  v2(183,3)=  v2(182,3);
  v2(184,1)=15;
  v2(184,2)=1500;
  v2(184,3)=(-(exp(y(20))/exp(y(1))));
  v2(185,1)=15;
  v2(185,2)=1427;
  v2(185,3)=  v2(184,3);
  v2(186,1)=16;
  v2(186,2)=2101;
  v2(186,3)=(-((T231*T231*(-(params(10)*T226*T1465))-(-(params(10)*T226*T690))*(T231*T690+T231*T690))/(T231*T231*T231*T231)/y(60)));
  v2(187,1)=16;
  v2(187,2)=4247;
  v2(187,3)=(-((-(T690*params(10)*T728))/(T231*T231)/y(60)));
  v2(188,1)=16;
  v2(188,2)=2130;
  v2(188,3)=  v2(187,3);
  v2(189,1)=16;
  v2(189,2)=4276;
  v2(189,3)=(-(params(10)*T1486/T231/y(60)));
  v2(190,1)=16;
  v2(190,2)=2471;
  v2(190,3)=(-((T231*T231*(-(params(10)*T226*T1493))-(-(params(10)*T226*T794))*(T231*T690+T231*T690))/(T231*T231*T231*T231)/y(60)));
  v2(191,1)=16;
  v2(191,2)=2106;
  v2(191,3)=  v2(190,3);
  v2(192,1)=16;
  v2(192,2)=2500;
  v2(192,3)=(-((-(params(10)*T728*T794))/(T231*T231)/y(60)));
  v2(193,1)=16;
  v2(193,2)=4252;
  v2(193,3)=  v2(192,3);
  v2(194,1)=16;
  v2(194,2)=2476;
  v2(194,3)=(-((T231*T231*(-(params(10)*T226*T1510))-(-(params(10)*T226*T794))*(T231*T794+T231*T794))/(T231*T231*T231*T231)/y(60)));
  v2(195,1)=16;
  v2(195,2)=4321;
  v2(195,3)=(-((-(T690*params(10)*T818))/(T231*T231)/y(60)));
  v2(196,1)=16;
  v2(196,2)=2131;
  v2(196,3)=  v2(195,3);
  v2(197,1)=16;
  v2(197,2)=4350;
  v2(197,3)=(-(params(10)*(-(exp(y(59))*T727))/(exp(y(59))*exp(y(59)))/T231/y(60)));
  v2(198,1)=16;
  v2(198,2)=4277;
  v2(198,3)=  v2(197,3);
  v2(199,1)=16;
  v2(199,2)=4326;
  v2(199,3)=(-((-(T794*params(10)*T818))/(T231*T231)/y(60)));
  v2(200,1)=16;
  v2(200,2)=2501;
  v2(200,3)=  v2(199,3);
  v2(201,1)=16;
  v2(201,2)=4351;
  v2(201,3)=(-(params(10)*T1543/T231/y(60)));
  v2(202,1)=16;
  v2(202,2)=4395;
  v2(202,3)=(-((-((-(params(10)*T226*T690))/(T231*T231)))/(y(60)*y(60))));
  v2(203,1)=16;
  v2(203,2)=2132;
  v2(203,3)=  v2(202,3);
  v2(204,1)=16;
  v2(204,2)=4424;
  v2(204,3)=(-((-(params(10)*T728/T231))/(y(60)*y(60))));
  v2(205,1)=16;
  v2(205,2)=4278;
  v2(205,3)=  v2(204,3);
  v2(206,1)=16;
  v2(206,2)=4400;
  v2(206,3)=(-((-((-(params(10)*T226*T794))/(T231*T231)))/(y(60)*y(60))));
  v2(207,1)=16;
  v2(207,2)=2502;
  v2(207,3)=  v2(206,3);
  v2(208,1)=16;
  v2(208,2)=4425;
  v2(208,3)=(-((-(params(10)*T818/T231))/(y(60)*y(60))));
  v2(209,1)=16;
  v2(209,2)=4352;
  v2(209,3)=  v2(208,3);
  v2(210,1)=16;
  v2(210,2)=4426;
  v2(210,3)=(-((-((-(params(10)*T226/T231))*(y(60)+y(60))))/(y(60)*y(60)*y(60)*y(60))));
  v2(211,1)=16;
  v2(211,2)=2926;
  v2(211,3)=(1+y(40)+1+y(40))/((1+y(40))*(1+y(40))*(1+y(40))*(1+y(40)));
  v2(212,1)=17;
  v2(212,2)=2101;
  v2(212,3)=exp(y(34))*(T240*getPowerDeriv(T240,T243,1)+T240*T240*getPowerDeriv(T240,T243,2));
  v2(213,1)=17;
  v2(213,2)=2175;
  v2(213,3)=exp(y(34))*(T745+T744*T240*getPowerDeriv(T240,T243,2));
  v2(214,1)=17;
  v2(214,2)=2102;
  v2(214,3)=  v2(213,3);
  v2(215,1)=17;
  v2(215,2)=2176;
  v2(215,3)=exp(y(34))*(T744*T744*getPowerDeriv(T240,T243,2)+getPowerDeriv(T240,T243,1)*((-(exp(y(29))*params(34)*exp(y(30))))*exp(y(30))*exp(y(30))-(-(exp(y(29))*params(34)*exp(y(30))))*(exp(y(30))*exp(y(30))+exp(y(30))*exp(y(30))))/(exp(y(30))*exp(y(30))*exp(y(30))*exp(y(30))));
  v2(216,1)=17;
  v2(216,2)=2471;
  v2(216,3)=exp(y(34))*T240*getPowerDeriv(T240,T243,1);
  v2(217,1)=17;
  v2(217,2)=2106;
  v2(217,3)=  v2(216,3);
  v2(218,1)=17;
  v2(218,2)=2472;
  v2(218,3)=exp(y(34))*T745;
  v2(219,1)=17;
  v2(219,2)=2180;
  v2(219,3)=  v2(218,3);
  v2(220,1)=17;
  v2(220,2)=2476;
  v2(220,3)=T245;
  v2(221,1)=18;
  v2(221,2)=1426;
  v2(221,3)=(T569*T592-T592*(T569+T569))/(T569*T569);
  v2(222,1)=18;
  v2(222,2)=1944;
  v2(222,3)=(-(exp(y(20))*(-exp(y(27)))/(exp(y(27))*exp(y(27)))))/T569;
  v2(223,1)=18;
  v2(223,2)=1433;
  v2(223,3)=  v2(222,3);
  v2(224,1)=18;
  v2(224,2)=1951;
  v2(224,3)=((-exp(y(27)))*exp(y(27))*exp(y(27))-(-exp(y(27)))*(exp(y(27))*exp(y(27))+exp(y(27))*exp(y(27))))/(exp(y(27))*exp(y(27))*exp(y(27))*exp(y(27)))/exp(y(20));
  v2(225,1)=18;
  v2(225,2)=2101;
  v2(225,3)=(-(T251*getPowerDeriv(T251,T243,1)+T251*T251*getPowerDeriv(T251,T243,2)));
  v2(226,1)=18;
  v2(226,2)=2249;
  v2(226,3)=(-(T759+T758*T251*getPowerDeriv(T251,T243,2)));
  v2(227,1)=18;
  v2(227,2)=2103;
  v2(227,3)=  v2(226,3);
  v2(228,1)=18;
  v2(228,2)=2251;
  v2(228,3)=(-(T758*T758*getPowerDeriv(T251,T243,2)+getPowerDeriv(T251,T243,1)*((-(exp(y(31))*exp(y(29))*params(35)))*exp(y(31))*exp(y(31))-(-(exp(y(31))*exp(y(29))*params(35)))*(exp(y(31))*exp(y(31))+exp(y(31))*exp(y(31))))/(exp(y(31))*exp(y(31))*exp(y(31))*exp(y(31)))));
  v2(229,1)=19;
  v2(229,2)=2101;
  v2(229,3)=exp(y(29));
  v2(230,1)=19;
  v2(230,2)=2176;
  v2(230,3)=(-(T750*params(34)^T243*(exp(y(30))*getPowerDeriv(exp(y(30)),T255,1)+exp(y(30))*exp(y(30))*getPowerDeriv(exp(y(30)),T255,2))+T749*T749*getPowerDeriv(T261,1+params(11),2)));
  v2(231,1)=19;
  v2(231,2)=2250;
  v2(231,3)=(-(T763*T749*getPowerDeriv(T261,1+params(11),2)));
  v2(232,1)=19;
  v2(232,2)=2177;
  v2(232,3)=  v2(231,3);
  v2(233,1)=19;
  v2(233,2)=2251;
  v2(233,3)=(-(T763*T763*getPowerDeriv(T261,1+params(11),2)+T750*params(35)^T243*(exp(y(31))*getPowerDeriv(exp(y(31)),T255,1)+exp(y(31))*exp(y(31))*getPowerDeriv(exp(y(31)),T255,2))));
  v2(234,1)=20;
  v2(234,2)=2626;
  v2(234,3)=(-(exp(y(36))/exp(y(37))));
  v2(235,1)=20;
  v2(235,2)=2700;
  v2(235,3)=T876;
  v2(236,1)=20;
  v2(236,2)=2627;
  v2(236,3)=  v2(235,3);
  v2(237,1)=20;
  v2(237,2)=2701;
  v2(237,3)=(-(((-(exp(y(36))*exp(y(37))))*exp(y(37))*exp(y(37))-(-(exp(y(36))*exp(y(37))))*(exp(y(37))*exp(y(37))+exp(y(37))*exp(y(37))))/(exp(y(37))*exp(y(37))*exp(y(37))*exp(y(37)))));
  v2(238,1)=20;
  v2(238,2)=2776;
  v2(238,3)=T879+exp(y(38))*exp(y(38))*getPowerDeriv(exp(y(38)),T271,2);
  v2(239,1)=21;
  v2(239,2)=2101;
  v2(239,3)=(-(T282*(T231*T231*(-(T287*T1465))-(-(T287*T690))*(T231*T690+T231*T690))/(T231*T231*T231*T231)+exp(y(61))*T299*T1668));
  v2(240,1)=21;
  v2(240,2)=4247;
  v2(240,3)=(-(exp(y(61))*T299*(-(T690*params(10)*params(25)*T728))/(T231*T231)));
  v2(241,1)=21;
  v2(241,2)=2130;
  v2(241,3)=  v2(240,3);
  v2(242,1)=21;
  v2(242,2)=4276;
  v2(242,3)=(-(exp(y(61))*T299*params(10)*params(25)*T1486/T231));
  v2(243,1)=21;
  v2(243,2)=2323;
  v2(243,3)=(-(T282*(-(T287*T690))/(T231*T231)+T282*(-(T690*T768))/(T231*T231)));
  v2(244,1)=21;
  v2(244,2)=2104;
  v2(244,3)=  v2(243,3);
  v2(245,1)=21;
  v2(245,2)=2326;
  v2(245,3)=(-(T771+T282*T768/T231+T282*T280*(T285*getPowerDeriv(T285,params(21),1)+T285*T285*getPowerDeriv(T285,params(21),2))/T231));
  v2(246,1)=21;
  v2(246,2)=2471;
  v2(246,3)=(-(T282*(T231*T231*(-(T287*T1493))-(-(T287*T794))*(T231*T690+T231*T690))/(T231*T231*T231*T231)+exp(y(61))*T299*T1712));
  v2(247,1)=21;
  v2(247,2)=2106;
  v2(247,3)=  v2(246,3);
  v2(248,1)=21;
  v2(248,2)=2500;
  v2(248,3)=(-(exp(y(61))*T299*(-(params(10)*params(25)*T728*T794))/(T231*T231)));
  v2(249,1)=21;
  v2(249,2)=4252;
  v2(249,3)=  v2(248,3);
  v2(250,1)=21;
  v2(250,2)=2474;
  v2(250,3)=(-(T282*(-(T287*T794))/(T231*T231)+T282*(-(T768*T794))/(T231*T231)));
  v2(251,1)=21;
  v2(251,2)=2328;
  v2(251,3)=  v2(250,3);
  v2(252,1)=21;
  v2(252,2)=2476;
  v2(252,3)=(-(T282*(T231*T231*(-(T287*T1510))-(-(T287*T794))*(T231*T794+T231*T794))/(T231*T231*T231*T231)+exp(y(61))*T299*T1741));
  v2(253,1)=21;
  v2(253,2)=4321;
  v2(253,3)=(-(exp(y(61))*T299*(-(T690*params(10)*params(25)*T818))/(T231*T231)));
  v2(254,1)=21;
  v2(254,2)=2131;
  v2(254,3)=  v2(253,3);
  v2(255,1)=21;
  v2(255,2)=4350;
  v2(255,3)=(-(exp(y(61))*T299*T1753));
  v2(256,1)=21;
  v2(256,2)=4277;
  v2(256,3)=  v2(255,3);
  v2(257,1)=21;
  v2(257,2)=4326;
  v2(257,3)=(-(exp(y(61))*T299*(-(T794*params(10)*params(25)*T818))/(T231*T231)));
  v2(258,1)=21;
  v2(258,2)=2501;
  v2(258,3)=  v2(257,3);
  v2(259,1)=21;
  v2(259,2)=4351;
  v2(259,3)=(-(exp(y(61))*T299*params(10)*params(25)*T1543/T231));
  v2(260,1)=21;
  v2(260,2)=4395;
  v2(260,3)=(-(exp(y(61))*T709*T861));
  v2(261,1)=21;
  v2(261,2)=2132;
  v2(261,3)=  v2(260,3);
  v2(262,1)=21;
  v2(262,2)=4424;
  v2(262,3)=(-(exp(y(61))*T734*T861));
  v2(263,1)=21;
  v2(263,2)=4278;
  v2(263,3)=  v2(262,3);
  v2(264,1)=21;
  v2(264,2)=4400;
  v2(264,3)=(-(exp(y(61))*T806*T861));
  v2(265,1)=21;
  v2(265,2)=2502;
  v2(265,3)=  v2(264,3);
  v2(266,1)=21;
  v2(266,2)=4425;
  v2(266,3)=(-(exp(y(61))*T824*T861));
  v2(267,1)=21;
  v2(267,2)=4352;
  v2(267,3)=  v2(266,3);
  v2(268,1)=21;
  v2(268,2)=4426;
  v2(268,3)=(-(exp(y(61))*T293*(getPowerDeriv(T294,T298,1)*(-((-params(36))*(y(60)+y(60))))/(y(60)*y(60)*y(60)*y(60))+T859*T859*getPowerDeriv(T294,T298,2))));
  v2(269,1)=21;
  v2(269,2)=2626;
  v2(269,3)=exp(y(36));
  v2(270,1)=21;
  v2(270,2)=4469;
  v2(270,3)=(-(exp(y(61))*T299*T709));
  v2(271,1)=21;
  v2(271,2)=2133;
  v2(271,3)=  v2(270,3);
  v2(272,1)=21;
  v2(272,2)=4498;
  v2(272,3)=(-(exp(y(61))*T299*T734));
  v2(273,1)=21;
  v2(273,2)=4279;
  v2(273,3)=  v2(272,3);
  v2(274,1)=21;
  v2(274,2)=4474;
  v2(274,3)=(-(exp(y(61))*T299*T806));
  v2(275,1)=21;
  v2(275,2)=2503;
  v2(275,3)=  v2(274,3);
  v2(276,1)=21;
  v2(276,2)=4499;
  v2(276,3)=(-(exp(y(61))*T299*T824));
  v2(277,1)=21;
  v2(277,2)=4353;
  v2(277,3)=  v2(276,3);
  v2(278,1)=21;
  v2(278,2)=4500;
  v2(278,3)=(-(exp(y(61))*T293*T861));
  v2(279,1)=21;
  v2(279,2)=4427;
  v2(279,3)=  v2(278,3);
  v2(280,1)=21;
  v2(280,2)=4501;
  v2(280,3)=(-(T293*T299*exp(y(61))));
  v2(281,1)=21;
  v2(281,2)=3729;
  v2(281,3)=(-(T282*(-(T690*T928))/(T231*T231)));
  v2(282,1)=21;
  v2(282,2)=2123;
  v2(282,3)=  v2(281,3);
  v2(283,1)=21;
  v2(283,2)=3732;
  v2(283,3)=(-(T282*T928/T231+T282*T280*(T927+T926*T285*getPowerDeriv(T285,params(21),2))/T231));
  v2(284,1)=21;
  v2(284,2)=2345;
  v2(284,3)=  v2(283,3);
  v2(285,1)=21;
  v2(285,2)=3734;
  v2(285,3)=(-(T282*(-(T794*T928))/(T231*T231)));
  v2(286,1)=21;
  v2(286,2)=2493;
  v2(286,3)=  v2(285,3);
  v2(287,1)=21;
  v2(287,2)=3751;
  v2(287,3)=(-(T282*T280*(T926*T926*getPowerDeriv(T285,params(21),2)+getPowerDeriv(T285,params(21),1)*((-(T282*exp(y(51))))*exp(y(51))*exp(y(51))-(-(T282*exp(y(51))))*(exp(y(51))*exp(y(51))+exp(y(51))*exp(y(51))))/(exp(y(51))*exp(y(51))*exp(y(51))*exp(y(51))))/T231));
  v2(288,1)=22;
  v2(288,2)=2101;
  v2(288,3)=(-(exp(y(62))*T314*T1668));
  v2(289,1)=22;
  v2(289,2)=4247;
  v2(289,3)=(-(exp(y(62))*T314*(-(T690*params(10)*params(25)*T728))/(T231*T231)));
  v2(290,1)=22;
  v2(290,2)=2130;
  v2(290,3)=  v2(289,3);
  v2(291,1)=22;
  v2(291,2)=4276;
  v2(291,3)=(-(exp(y(62))*T314*params(10)*params(25)*T1486/T231));
  v2(292,1)=22;
  v2(292,2)=2326;
  v2(292,3)=(-(T282*(1+params(37)*exp(y(52)))/params(23)));
  v2(293,1)=22;
  v2(293,2)=2471;
  v2(293,3)=(-(exp(y(62))*T314*T1712));
  v2(294,1)=22;
  v2(294,2)=2106;
  v2(294,3)=  v2(293,3);
  v2(295,1)=22;
  v2(295,2)=2500;
  v2(295,3)=(-(exp(y(62))*T314*(-(params(10)*params(25)*T728*T794))/(T231*T231)));
  v2(296,1)=22;
  v2(296,2)=4252;
  v2(296,3)=  v2(295,3);
  v2(297,1)=22;
  v2(297,2)=2476;
  v2(297,3)=(-(exp(y(62))*T314*T1741));
  v2(298,1)=22;
  v2(298,2)=4321;
  v2(298,3)=(-(exp(y(62))*T314*(-(T690*params(10)*params(25)*T818))/(T231*T231)));
  v2(299,1)=22;
  v2(299,2)=2131;
  v2(299,3)=  v2(298,3);
  v2(300,1)=22;
  v2(300,2)=4350;
  v2(300,3)=(-(exp(y(62))*T314*T1753));
  v2(301,1)=22;
  v2(301,2)=4277;
  v2(301,3)=  v2(300,3);
  v2(302,1)=22;
  v2(302,2)=4326;
  v2(302,3)=(-(exp(y(62))*T314*(-(T794*params(10)*params(25)*T818))/(T231*T231)));
  v2(303,1)=22;
  v2(303,2)=2501;
  v2(303,3)=  v2(302,3);
  v2(304,1)=22;
  v2(304,2)=4351;
  v2(304,3)=(-(exp(y(62))*T314*params(10)*params(25)*T1543/T231));
  v2(305,1)=22;
  v2(305,2)=4395;
  v2(305,3)=(-(exp(y(62))*T709*T866));
  v2(306,1)=22;
  v2(306,2)=2132;
  v2(306,3)=  v2(305,3);
  v2(307,1)=22;
  v2(307,2)=4424;
  v2(307,3)=(-(exp(y(62))*T734*T866));
  v2(308,1)=22;
  v2(308,2)=4278;
  v2(308,3)=  v2(307,3);
  v2(309,1)=22;
  v2(309,2)=4400;
  v2(309,3)=(-(exp(y(62))*T806*T866));
  v2(310,1)=22;
  v2(310,2)=2502;
  v2(310,3)=  v2(309,3);
  v2(311,1)=22;
  v2(311,2)=4425;
  v2(311,3)=(-(exp(y(62))*T824*T866));
  v2(312,1)=22;
  v2(312,2)=4352;
  v2(312,3)=  v2(311,3);
  v2(313,1)=22;
  v2(313,2)=4426;
  v2(313,3)=(-(exp(y(62))*T293*(T865*(-((-params(36))*(y(60)+y(60))))/(y(60)*y(60)*y(60)*y(60))+T859*T859*getPowerDeriv(T294,1-(1+params(23))/params(23),2))));
  v2(314,1)=22;
  v2(314,2)=2701;
  v2(314,3)=exp(y(37));
  v2(315,1)=22;
  v2(315,2)=4543;
  v2(315,3)=(-(exp(y(62))*T314*T709));
  v2(316,1)=22;
  v2(316,2)=2134;
  v2(316,3)=  v2(315,3);
  v2(317,1)=22;
  v2(317,2)=4572;
  v2(317,3)=(-(exp(y(62))*T314*T734));
  v2(318,1)=22;
  v2(318,2)=4280;
  v2(318,3)=  v2(317,3);
  v2(319,1)=22;
  v2(319,2)=4548;
  v2(319,3)=(-(exp(y(62))*T314*T806));
  v2(320,1)=22;
  v2(320,2)=2504;
  v2(320,3)=  v2(319,3);
  v2(321,1)=22;
  v2(321,2)=4573;
  v2(321,3)=(-(exp(y(62))*T314*T824));
  v2(322,1)=22;
  v2(322,2)=4354;
  v2(322,3)=  v2(321,3);
  v2(323,1)=22;
  v2(323,2)=4574;
  v2(323,3)=(-(exp(y(62))*T293*T866));
  v2(324,1)=22;
  v2(324,2)=4428;
  v2(324,3)=  v2(323,3);
  v2(325,1)=22;
  v2(325,2)=4576;
  v2(325,3)=(-(T293*T314*exp(y(62))));
  v2(326,1)=22;
  v2(326,2)=3806;
  v2(326,3)=T942;
  v2(327,1)=22;
  v2(327,2)=2346;
  v2(327,3)=  v2(326,3);
  v2(328,1)=22;
  v2(328,2)=3826;
  v2(328,3)=T942;
  v2(329,1)=23;
  v2(329,2)=2551;
  v2(329,3)=params(25)*(getPowerDeriv(T325,T322,1)*(-((-params(36))*(y(35)+y(35))))/(y(35)*y(35)*y(35)*y(35))+T845*T845*getPowerDeriv(T325,T322,2));
  v2(330,1)=23;
  v2(330,2)=2776;
  v2(330,3)=(1-params(25))*(exp(y(38))*getPowerDeriv(exp(y(38)),T322,1)+exp(y(38))*exp(y(38))*getPowerDeriv(exp(y(38)),T322,2));
  v2(331,1)=24;
  v2(331,2)=2551;
  v2(331,3)=(-(exp(y(5))*params(25)*(getPowerDeriv(T325,T298,1)*(-((-params(36))*(y(35)+y(35))))/(y(35)*y(35)*y(35)*y(35))+T845*T845*getPowerDeriv(T325,T298,2))));
  v2(332,1)=24;
  v2(332,2)=2776;
  v2(332,3)=(-((1-params(25))*(exp(y(38))*getPowerDeriv(exp(y(38)),T298,1)+exp(y(38))*exp(y(38))*getPowerDeriv(exp(y(38)),T298,2))));
  v2(333,1)=24;
  v2(333,2)=331;
  v2(333,3)=(-(exp(y(5))*params(25)*T845*getPowerDeriv(T325,T298,1)));
  v2(334,1)=24;
  v2(334,2)=2521;
  v2(334,3)=  v2(333,3);
  v2(335,1)=24;
  v2(335,2)=301;
  v2(335,3)=(-(params(25)*T325^T298*exp(y(5))));
  v2(336,1)=24;
  v2(336,2)=2851;
  v2(336,3)=exp(y(39));
  v2(337,1)=25;
  v2(337,2)=1201;
  v2(337,3)=(-(exp(y(17))*params(30)));
  v2(338,1)=25;
  v2(338,2)=2176;
  v2(338,3)=(-exp(y(30)));
  v2(339,1)=25;
  v2(339,2)=2326;
  v2(339,3)=T282;
  v2(340,1)=25;
  v2(340,2)=2401;
  v2(340,3)=(-exp(y(33)));
  v2(341,1)=26;
  v2(341,2)=2326;
  v2(341,3)=(-(T282*params(12)*exp(y(50))));
  v2(342,1)=26;
  v2(342,2)=2401;
  v2(342,3)=exp(y(33));
  v2(343,1)=26;
  v2(343,2)=3658;
  v2(343,3)=(-(T282*params(12)*exp(y(50))));
  v2(344,1)=26;
  v2(344,2)=2344;
  v2(344,3)=  v2(343,3);
  v2(345,1)=26;
  v2(345,2)=3676;
  v2(345,3)=(-(T282*params(12)*exp(y(50))));
  v2(346,1)=27;
  v2(346,2)=226;
  v2(346,3)=(-(y(35)*((-(exp(y(34))*exp(y(4))))*exp(y(4))*exp(y(4))-(-(exp(y(34))*exp(y(4))))*(exp(y(4))*exp(y(4))+exp(y(4))*exp(y(4))))/(exp(y(4))*exp(y(4))*exp(y(4))*exp(y(4)))));
  v2(347,1)=27;
  v2(347,2)=2446;
  v2(347,3)=T787;
  v2(348,1)=27;
  v2(348,2)=256;
  v2(348,3)=  v2(347,3);
  v2(349,1)=27;
  v2(349,2)=2476;
  v2(349,3)=(-(y(35)*exp(y(34))/exp(y(4))));
  v2(350,1)=27;
  v2(350,2)=2520;
  v2(350,3)=(-T785);
  v2(351,1)=27;
  v2(351,2)=257;
  v2(351,3)=  v2(350,3);
  v2(352,1)=27;
  v2(352,2)=2550;
  v2(352,3)=(-(exp(y(34))/exp(y(4))));
  v2(353,1)=27;
  v2(353,2)=2477;
  v2(353,3)=  v2(352,3);
  v2(354,1)=28;
  v2(354,2)=1051;
  v2(354,3)=(-(params(48)*(T76*T76*(-(T366*T1018))-(-(T366*T471))*(T76*T471+T76*T471))/(T76*T76*T76*T76)));
  v2(355,1)=28;
  v2(355,2)=1939;
  v2(355,3)=(-(params(48)*(-(T471*T684))/(T76*T76)));
  v2(356,1)=28;
  v2(356,2)=1063;
  v2(356,3)=  v2(355,3);
  v2(357,1)=28;
  v2(357,2)=1951;
  v2(357,3)=(-(params(48)*params(47)*(exp(y(27))*exp(y(27))*(-(exp(y(27))*params(46)))-(-(exp(y(27))*params(46)))*(exp(y(27))*exp(y(27))+exp(y(27))*exp(y(27))))/(exp(y(27))*exp(y(27))*exp(y(27))*exp(y(27)))/T76));
  v2(358,1)=28;
  v2(358,2)=2101;
  v2(358,3)=params(45)*(T230*T230*(-(params(44)*T1464))-(-(params(44)*T689))*(T230*T689+T230*T689))/(T230*T230*T230*T230);
  v2(359,1)=29;
  v2(359,2)=1051;
  v2(359,3)=T1014;
  v2(360,1)=29;
  v2(360,2)=1276;
  v2(360,3)=exp(y(25))*T374*(T555+T135*T135*getPowerDeriv(T135,1+params(22),2))/(1+params(22));
  v2(361,1)=29;
  v2(361,2)=1794;
  v2(361,3)=T558;
  v2(362,1)=29;
  v2(362,2)=1283;
  v2(362,3)=  v2(361,3);
  v2(363,1)=29;
  v2(363,2)=1801;
  v2(363,3)=T378;
  v2(364,1)=29;
  v2(364,2)=3496;
  v2(364,3)=exp(y(25))*T555*params(27)*exp(y(48))*getPowerDeriv(exp(y(48)),(-params(22)),1)/(1+params(22));
  v2(365,1)=29;
  v2(365,2)=1306;
  v2(365,3)=  v2(364,3);
  v2(366,1)=29;
  v2(366,2)=3503;
  v2(366,3)=T915;
  v2(367,1)=29;
  v2(367,2)=1824;
  v2(367,3)=  v2(366,3);
  v2(368,1)=29;
  v2(368,2)=3526;
  v2(368,3)=exp(y(25))*T375*params(27)*(exp(y(48))*getPowerDeriv(exp(y(48)),(-params(22)),1)+exp(y(48))*exp(y(48))*getPowerDeriv(exp(y(48)),(-params(22)),2))/(1+params(22));
  v2(369,1)=30;
  v2(369,2)=2101;
  v2(369,3)=(-((exp(y(29))*getPowerDeriv(exp(y(29)),1-params(9),1)+exp(y(29))*exp(y(29))*getPowerDeriv(exp(y(29)),1-params(9),2))/(1-params(9))));
  v2(370,1)=30;
  v2(370,2)=2326;
  v2(370,3)=exp(y(39))*T387*(T776+T282*T282*getPowerDeriv(T282,1+params(21),2))/(1+params(21));
  v2(371,1)=30;
  v2(371,2)=2844;
  v2(371,3)=T779;
  v2(372,1)=30;
  v2(372,2)=2333;
  v2(372,3)=  v2(371,3);
  v2(373,1)=30;
  v2(373,2)=2851;
  v2(373,3)=T391;
  v2(374,1)=30;
  v2(374,2)=3732;
  v2(374,3)=exp(y(39))*T776*params(33)*exp(y(51))*getPowerDeriv(exp(y(51)),(-params(21)),1)/(1+params(21));
  v2(375,1)=30;
  v2(375,2)=2345;
  v2(375,3)=  v2(374,3);
  v2(376,1)=30;
  v2(376,2)=3739;
  v2(376,3)=T937;
  v2(377,1)=30;
  v2(377,2)=2863;
  v2(377,3)=  v2(376,3);
  v2(378,1)=30;
  v2(378,2)=3751;
  v2(378,3)=exp(y(39))*T388*params(33)*(exp(y(51))*getPowerDeriv(exp(y(51)),(-params(21)),1)+exp(y(51))*exp(y(51))*getPowerDeriv(exp(y(51)),(-params(21)),2))/(1+params(21));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),40,5476);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],40,405224);
end
end
