function [residual, g1, g2] = shadow_ramsey_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 146, 1);

%
% Model equations
%

T68 = exp(y(105))^(1-params(4))/(1-params(4));
T76 = exp(y(105))^(-params(4));
T78 = T76/exp(y(110));
T87 = exp(y(105))*params(31)/exp(y(106));
T90 = params(6)/(1+params(6));
T102 = exp(y(105))*params(32)/exp(y(107));
T105 = params(31)^T90;
T106 = 1/(1+params(6));
T109 = params(32)^T90;
T112 = T105*exp(y(106))^T106+T109*exp(y(107))^T106;
T119 = (1+params(27))/params(27);
T136 = exp(y(108))/exp(y(140));
T138 = T119*params(30)*T136^params(25);
T144 = T78*params(5)*params(29)/T78;
T146 = params(34)/y(111);
T150 = (-(1+params(27)))/params(27)*(1+params(25));
T151 = T146^T150;
T164 = T146^(1-T119);
T170 = (-1)/params(27);
T213 = exp(y(119))^(-params(12));
T214 = T213/exp(y(124));
T223 = exp(y(119))*params(37)/exp(y(120));
T226 = params(14)/(1+params(14));
T234 = exp(y(119))*params(38)/exp(y(121));
T237 = params(37)^T226;
T238 = 1/(1+params(14));
T241 = params(38)^T226;
T244 = T237*exp(y(120))^T238+T241*exp(y(121))^T238;
T251 = (1+params(26))/params(26);
T268 = exp(y(122))/exp(y(143));
T270 = T251*params(36)*T268^params(24);
T276 = T214*params(13)*params(28)/T214;
T278 = params(39)/y(125);
T282 = (-(1+params(26)))/params(26)*(1+params(24));
T283 = T278^T282;
T296 = T278^(1-T251);
T302 = (-1)/params(26);
T352 = exp(y(115))*params(30)*exp(y(140))^(-params(25))*exp(y(108))^(1+params(25))/(1+params(25));
T364 = exp(y(129))*params(36)*exp(y(143))^(-params(24))*exp(y(122))^(1+params(24))/(1+params(24));
T411 = exp(y(8));
T417 = exp(y(13));
T420 = exp(y(11));
T423 = T411^(params(4)-1);
T429 = (T420*exp((-y(49))))^params(25);
T432 = (1+params(27))*T411*params(4)*params(30)*T417*T420*T423*T429/params(27);
T436 = exp((-y(13)));
T440 = exp(y(15));
T442 = T417*T411*params(29)*params(4)*params(5)*T436*T440;
T443 = T423*T442;
T444 = T411^params(4);
T445 = params(34)/y(14);
T447 = (1+params(27))*(1+params(25))/params(27);
T448 = T445^T447;
T473 = (T411*params(32)*exp((-y(10))))^(T90-1);
T474 = T411*params(6)*params(32)*y(71)*exp((-y(10)))*T473;
T475 = T474/(1+params(6));
T500 = (T411*params(31)*exp((-y(9))))^(T90-1);
T501 = T417*T411*params(31)*params(6)*y(70)*exp((-y(9)))*T500;
T502 = T501/(1+params(6));
T517 = params(3)*y(14)*T411^(1+params(4));
T525 = exp(y(16));
T527 = T417*T411*T436*params(29)*params(4)*params(5)*y(75)*T525;
T529 = T445^(1-T119);
T535 = params(3)*T411^(1+params(4));
T543 = T444*T417*T440*T411*T436*y(74)*params(29)*params(4)*params(5);
T556 = exp(y(9))*T105*y(72)*exp(y(9))^(T106-1);
T562 = T105*exp(y(9))^T106+T109*exp(y(10))^T106;
T563 = T562^params(6);
T579 = T420^(1+params(25));
T580 = exp(y(18))*params(30)*y(94)*T579;
T582 = exp(y(49))^params(25);
T583 = (1+params(25))*T582;
T584 = T580/T583;
T619 = T529*T444*T417*T525*T436*params(5)*params(29)*y(75)/(params(3)*T444);
T630 = T444*T417*T440*T436*params(5)*params(29)*y(74)/(T448*params(3)*T444);
T636 = exp(y(10))*T109*y(72)*exp(y(10))^(T106-1);
T648 = params(27)*y(14)^2;
T650 = 1+1/params(27);
T651 = T445^T650;
T667 = T444*params(3)*y(14)^2;
T675 = T445^(1+T447);
T677 = (1+params(27))*(1+params(25))*exp(y(36))*y(77)*params(29)*params(34)/(T648*T675);
T689 = T667*T445^T119;
T690 = T444*T417*T525*T436*y(75)*params(29)*params(5)*params(34)*(T119-1)/T689;
T698 = (1+params(27))*(1+params(25))*T444*T417*T440*T436*y(74)*params(29)*params(5)*params(34);
T706 = exp(y(17));
T710 = T706^((1+params(27))*params(25)/params(27));
T711 = y(73)*T706*T710;
T712 = 1+(1+params(27))*params(25)/params(27);
T718 = params(27)*T706^T650;
T726 = params(27)*T706^(1+T447);
T732 = exp((-y(27)));
T750 = (1+y(19))^2;
T767 = (1+params(27))*T429*T444*T420*params(30)*T417/params(27);
T772 = T444*T417*T440*params(5)*params(29)*T436/(T444*T448);
T809 = (T420*exp((-y(49))))^(params(25)-1);
T813 = T767+(1+params(27))*T444*T417*exp((-y(49)))*params(25)*params(30)*exp(2*y(11))*T809/params(27);
T814 = y(74)*T813;
T832 = T420*exp(y(18))*params(30)*y(94)*T420^params(25);
T838 = exp(y(22));
T843 = exp(y(27));
T846 = exp(y(25));
T849 = T838^(params(12)-1);
T855 = (T846*exp((-y(52))))^params(24);
T858 = (1+params(26))*T838*params(12)*params(36)*T843*T846*T849*T855/params(26);
T864 = exp(y(29));
T866 = T843*T838*T732*params(28)*params(13)*params(12)*T864;
T867 = T849*T866;
T868 = T838^params(12);
T869 = params(39)/y(28);
T871 = (1+params(26))*(1+params(24))/params(26);
T872 = T869^T871;
T898 = (T838*params(38)*exp((-y(24))))^(T226-1);
T899 = T838*y(83)*params(14)*params(38)*exp((-y(24)))*T898;
T900 = T899/(1+params(14));
T913 = (T838*params(37)*exp((-y(23))))^(T226-1);
T914 = T843*T838*params(37)*params(14)*y(82)*exp((-y(23)))*T913;
T915 = T914/(1+params(14));
T930 = params(3)*y(28)*T838^(1+params(12));
T938 = exp(y(30));
T940 = T843*T838*T732*params(28)*params(13)*params(12)*y(87)*T938;
T942 = T869^(1-T251);
T948 = params(3)*T838^(1+params(12));
T956 = T868*T843*T864*T838*T732*y(86)*params(28)*params(13)*params(12);
T968 = exp(y(23))*T237*y(84)*exp(y(23))^(T238-1);
T974 = T237*exp(y(23))^T238+T241*exp(y(24))^T238;
T975 = T974^params(14);
T991 = T846^(1+params(24));
T992 = exp(y(32))*params(36)*y(95)*T991;
T994 = exp(y(52))^params(24);
T995 = (1+params(24))*T994;
T996 = T992/T995;
T1031 = T942*T868*T843*T938*T732*params(13)*params(28)*y(87)/(params(3)*T868);
T1042 = T868*T843*T864*T732*params(13)*params(28)*y(86)/(T872*params(3)*T868);
T1048 = exp(y(24))*T241*y(84)*exp(y(24))^(T238-1);
T1059 = params(26)*y(28)^2;
T1061 = 1+1/params(26);
T1062 = T869^T1061;
T1078 = T868*params(3)*y(28)^2;
T1086 = T869^(1+T871);
T1088 = (1+params(26))*(1+params(24))*exp(y(39))*y(89)*params(28)*params(39)/(T1059*T1086);
T1100 = T1078*T869^T251;
T1101 = T868*T843*T938*T732*y(87)*params(28)*params(13)*params(39)*(T251-1)/T1100;
T1109 = (1+params(26))*(1+params(24))*T868*T843*T864*T732*y(86)*params(28)*params(13)*params(39);
T1117 = exp(y(31));
T1121 = T1117^((1+params(26))*params(24)/params(26));
T1122 = y(85)*T1117*T1121;
T1123 = 1+(1+params(26))*params(24)/params(26);
T1129 = params(26)*T1117^T1061;
T1137 = params(26)*T1117^(1+T871);
T1146 = (1+y(33))^2;
T1163 = (1+params(26))*T855*T868*T846*params(36)*T843/params(26);
T1168 = T868*T843*T864*params(13)*params(28)*T732/(T868*T872);
T1205 = (T846*exp((-y(52))))^(params(24)-1);
T1209 = T1163+(1+params(26))*T868*T843*exp((-y(52)))*params(24)*params(36)*exp(2*y(25))*T1205/params(26);
T1210 = y(86)*T1209;
T1228 = T846*exp(y(32))*params(36)*y(95)*T846^params(24);
T1247 = T411^(1-params(4))/(params(4)-1);
T1255 = 1/(1+y(19))-T444*T417*params(5)*T436/(y(14)*T444);
T1264 = T525-T420*(1+params(35)*exp(y(50)))/params(27);
T1269 = T529*T444*T417*T525*params(5)*params(29)*T436/T444;
T1278 = 1/(1+y(33))-T868*T843*params(13)*T732/(y(28)*T868);
T1287 = T938-T846*(1+params(40)*exp(y(53)))/params(26);
T1292 = T942*T868*T843*T938*params(13)*params(28)*T732/T868;
T1306 = exp(y(105))^params(4);
T1309 = 1/(1+y(19))-T444*T417*params(5)*exp((-y(110)))/(y(111)*T1306);
T1317 = T1306*T146^T447;
T1318 = T444*T417*exp(y(112))*params(5)*params(29)*exp((-y(110)))/T1317;
T1326 = T164*T444*T417*exp(y(113))*params(5)*params(29)*exp((-y(110)))/T1306;
T1335 = exp(y(119))^params(12);
T1338 = 1/(1+y(33))-T868*T843*params(13)*exp((-y(124)))/(y(125)*T1335);
T1346 = T1335*T278^T871;
T1347 = T868*T843*exp(y(126))*params(13)*params(28)*exp((-y(124)))/T1346;
T1355 = T296*T868*T843*exp(y(127))*params(13)*params(28)*exp((-y(124)))/T1335;
T1403 = T411^(1-params(4))/(1-params(4));
T1406 = T411^(-params(4));
T1407 = T1406/T417;
T1413 = params(31)*T411/exp(y(9));
T1419 = params(32)*T411/exp(y(10));
T1429 = T119*params(30)*(T420/exp(y(49)))^params(25);
T1433 = params(5)*params(29)*T1407/T1407;
T1434 = T445^T150;
T1469 = T838^(-params(12));
T1470 = T1469/T843;
T1476 = params(37)*T838/exp(y(23));
T1483 = params(38)*T838/exp(y(24));
T1493 = T251*params(36)*(T846/exp(y(52)))^params(24);
T1497 = params(13)*params(28)*T1470/T1470;
T1498 = T869^T282;
T1544 = exp(y(18))*T579*params(30)*exp(y(49))^(-params(25))/(1+params(25));
T1553 = exp(y(32))*T991*params(36)*exp(y(52))^(-params(24))/(1+params(24));
T1578 = T411*getPowerDeriv(T411,params(4)-1,1);
T1587 = T411*getPowerDeriv(T411,params(4),1);
T1612 = (T474+T411*params(6)*params(32)*y(71)*exp((-y(10)))*T411*params(32)*exp((-y(10)))*getPowerDeriv(T411*params(32)*exp((-y(10))),T90-1,1))/(1+params(6));
T1621 = (T501+T417*T411*params(31)*params(6)*y(70)*exp((-y(9)))*T411*params(31)*exp((-y(9)))*getPowerDeriv(T411*params(31)*exp((-y(9))),T90-1,1))/(1+params(6));
T1678 = (params(3)*T444*T529*T417*T525*T436*params(5)*params(29)*y(75)*T1587-T529*T444*T417*T525*T436*params(5)*params(29)*y(75)*params(3)*T1587)/(params(3)*T444*params(3)*T444);
T1686 = (T448*params(3)*T444*T417*T440*T436*params(5)*params(29)*y(74)*T1587-T444*T417*T440*T436*params(5)*params(29)*y(74)*T448*params(3)*T1587)/(T448*params(3)*T444*T448*params(3)*T444);
T1722 = (1+params(27))*T429*T420*params(30)*T417*T1587/params(27);
T1727 = (T444*T448*T417*T440*params(5)*params(29)*T436*T1587-T444*T417*T440*params(5)*params(29)*T436*T448*T1587)/(T444*T448*T444*T448);
T1760 = y(68)*T411*getPowerDeriv(T411,1-params(4),1)/(params(4)-1);
T1801 = (-(T411*getPowerDeriv(T411,1-params(4),1)/(1-params(4))));
T1804 = T411*getPowerDeriv(T411,(-params(4)),1)/T417;
T1851 = (T500*T417*T411*params(31)*params(6)*y(70)*(-exp((-y(9))))+T417*T411*params(31)*params(6)*y(70)*exp((-y(9)))*getPowerDeriv(T411*params(31)*exp((-y(9))),T90-1,1)*T411*params(31)*(-exp((-y(9)))))/(1+params(6));
T1860 = T105*exp(y(9))*getPowerDeriv(exp(y(9)),T106,1)*getPowerDeriv(T562,params(6),1);
T1889 = (T473*T411*params(6)*params(32)*y(71)*(-exp((-y(10))))+T411*params(6)*params(32)*y(71)*exp((-y(10)))*getPowerDeriv(T411*params(32)*exp((-y(10))),T90-1,1)*T411*params(32)*(-exp((-y(10)))))/(1+params(6));
T1894 = getPowerDeriv(T562,params(6),1)*T109*exp(y(10))*getPowerDeriv(exp(y(10)),T106,1);
T1916 = T420*exp((-y(49)))*getPowerDeriv(T420*exp((-y(49))),params(25),1);
T1930 = (1+params(27))*(T429*T444*T420*params(30)*T417+T444*T420*params(30)*T417*T1916)/params(27);
T1961 = (-(y(74)*(-T1930)+y(75)*(-(T420*(1+params(35)*exp(y(50)))/params(27)))));
T1962 = getPowerDeriv(T420/exp(y(49)),params(25),1);
T2026 = T529*T444*(T417*T525*T436*params(5)*params(29)*y(75)+T417*T525*params(5)*params(29)*y(75)*(-T436))/(params(3)*T444);
T2033 = T444*(T417*T440*T436*params(5)*params(29)*y(74)+T417*T440*params(5)*params(29)*y(74)*(-T436))/(T448*params(3)*T444);
T2066 = T444*(T417*T440*params(5)*params(29)*T436+T417*T440*params(5)*params(29)*(-T436))/(T444*T448);
T2114 = (-(T417*T1406))/(T417*T417);
T2145 = (-params(34))/(y(14)*y(14));
T2147 = T2145*getPowerDeriv(T445,T447,1);
T2163 = T2145*getPowerDeriv(T445,1-T119,1);
T2181 = T444*T417*T525*T436*params(5)*params(29)*y(75)*T2163/(params(3)*T444);
T2186 = (-(T444*T417*T440*T436*params(5)*params(29)*y(74)*params(3)*T444*T2147))/(T448*params(3)*T444*T448*params(3)*T444);
T2235 = (-(T444*T417*T440*params(5)*params(29)*T436*T444*T2147))/(T444*T448*T444*T448);
T2386 = T838*getPowerDeriv(T838,params(12)-1,1);
T2395 = T838*getPowerDeriv(T838,params(12),1);
T2418 = (T899+T838*y(83)*params(14)*params(38)*exp((-y(24)))*T838*params(38)*exp((-y(24)))*getPowerDeriv(T838*params(38)*exp((-y(24))),T226-1,1))/(1+params(14));
T2424 = (T914+T843*T838*params(37)*params(14)*y(82)*exp((-y(23)))*T838*params(37)*exp((-y(23)))*getPowerDeriv(T838*params(37)*exp((-y(23))),T226-1,1))/(1+params(14));
T2481 = (params(3)*T868*T942*T843*T938*T732*params(13)*params(28)*y(87)*T2395-T942*T868*T843*T938*T732*params(13)*params(28)*y(87)*params(3)*T2395)/(params(3)*T868*params(3)*T868);
T2489 = (T872*params(3)*T868*T843*T864*T732*params(13)*params(28)*y(86)*T2395-T868*T843*T864*T732*params(13)*params(28)*y(86)*T872*params(3)*T2395)/(T872*params(3)*T868*T872*params(3)*T868);
T2524 = (1+params(26))*T855*T846*params(36)*T843*T2395/params(26);
T2529 = (T868*T872*T843*T864*params(13)*params(28)*T732*T2395-T868*T843*T864*params(13)*params(28)*T732*T872*T2395)/(T868*T872*T868*T872);
T2598 = T838*getPowerDeriv(T838,(-params(12)),1)/T843;
T2648 = (T913*T843*T838*params(37)*params(14)*y(82)*(-exp((-y(23))))+T843*T838*params(37)*params(14)*y(82)*exp((-y(23)))*getPowerDeriv(T838*params(37)*exp((-y(23))),T226-1,1)*T838*params(37)*(-exp((-y(23)))))/(1+params(14));
T2657 = T237*exp(y(23))*getPowerDeriv(exp(y(23)),T238,1)*getPowerDeriv(T974,params(14),1);
T2686 = (T898*T838*y(83)*params(14)*params(38)*(-exp((-y(24))))+T838*y(83)*params(14)*params(38)*exp((-y(24)))*getPowerDeriv(T838*params(38)*exp((-y(24))),T226-1,1)*T838*params(38)*(-exp((-y(24)))))/(1+params(14));
T2691 = getPowerDeriv(T974,params(14),1)*T241*exp(y(24))*getPowerDeriv(exp(y(24)),T238,1);
T2713 = T846*exp((-y(52)))*getPowerDeriv(T846*exp((-y(52))),params(24),1);
T2727 = (1+params(26))*(T855*T868*T846*params(36)*T843+T868*T846*params(36)*T843*T2713)/params(26);
T2758 = (-(y(86)*(-T2727)+y(87)*(-(T846*(1+params(40)*exp(y(53)))/params(26)))));
T2759 = getPowerDeriv(T846/exp(y(52)),params(24),1);
T2825 = T942*T868*(T843*T938*T732*params(13)*params(28)*y(87)+T843*T938*params(13)*params(28)*y(87)*(-T732))/(params(3)*T868);
T2832 = T868*(T843*T864*T732*params(13)*params(28)*y(86)+T843*T864*params(13)*params(28)*y(86)*(-T732))/(T872*params(3)*T868);
T2863 = T868*(T843*T864*params(13)*params(28)*T732+T843*T864*params(13)*params(28)*(-T732))/(T868*T872);
T2914 = (-(T843*T1469))/(T843*T843);
T2941 = (-params(39))/(y(28)*y(28));
T2943 = T2941*getPowerDeriv(T869,T871,1);
T2959 = T2941*getPowerDeriv(T869,1-T251,1);
T2977 = T868*T843*T938*T732*params(13)*params(28)*y(87)*T2959/(params(3)*T868);
T2982 = (-(T868*T843*T864*T732*params(13)*params(28)*y(86)*params(3)*T868*T2943))/(T872*params(3)*T868*T872*params(3)*T868);
T3031 = (-(T868*T843*T864*params(13)*params(28)*T732*T868*T2943))/(T868*T872*T868*T872);
T3197 = getPowerDeriv(T420*exp((-y(49))),params(25),1)*T420*(-exp((-y(49))));
T3212 = (1+params(27))*T444*T420*params(30)*T417*T3197/params(27);
T3268 = getPowerDeriv(T846*exp((-y(52))),params(24),1)*T846*(-exp((-y(52))));
T3283 = (1+params(26))*T868*T846*params(36)*T843*T3268/params(26);
T3585 = (-(exp(y(105))*getPowerDeriv(exp(y(105)),1-params(4),1)/(1-params(4))));
T3588 = exp(y(105))*getPowerDeriv(exp(y(105)),(-params(4)),1)/exp(y(110));
T3626 = exp(y(105))*getPowerDeriv(exp(y(105)),params(4),1);
T3694 = (-(T76*exp(y(110))))/(exp(y(110))*exp(y(110)));
T3750 = (-params(34))/(y(111)*y(111));
T3752 = T3750*getPowerDeriv(T146,T150,1);
T3825 = exp(y(119))*getPowerDeriv(exp(y(119)),(-params(12)),1)/exp(y(124));
T3866 = exp(y(119))*getPowerDeriv(exp(y(119)),params(12),1);
T3937 = (-(exp(y(124))*T213))/(exp(y(124))*exp(y(124)));
T3990 = (-params(39))/(y(125)*y(125));
T3992 = T3990*getPowerDeriv(T278,T282,1);
lhs =y(99);
rhs =params(1)*y(103)+params(2)*y(104);
residual(1)= lhs-rhs;
lhs =y(100);
rhs =y(99)+y(100)*params(3);
residual(2)= lhs-rhs;
lhs =y(145);
rhs =y(103)+params(3)*y(145);
residual(3)= lhs-rhs;
lhs =y(146);
rhs =y(104)+params(3)*y(146);
residual(4)= lhs-rhs;
lhs =y(101);
rhs =y(111);
residual(5)= lhs-rhs;
lhs =y(102);
rhs =y(125);
residual(6)= lhs-rhs;
lhs =y(133);
rhs =y(115);
residual(7)= lhs-rhs;
lhs =y(134);
rhs =y(116);
residual(8)= lhs-rhs;
lhs =y(135);
rhs =y(110);
residual(9)= lhs-rhs;
lhs =y(136);
rhs =y(129);
residual(10)= lhs-rhs;
lhs =y(137);
rhs =y(130);
residual(11)= lhs-rhs;
lhs =y(138);
rhs =y(124);
residual(12)= lhs-rhs;
lhs =y(111);
rhs =params(52)+(1-params(52))*y(14);
residual(13)= lhs-rhs;
lhs =y(125);
rhs =y(28);
residual(14)= lhs-rhs;
lhs =y(132);
rhs =T68+y(132)*params(5);
residual(15)= lhs-rhs;
lhs =1/(1+y(116));
rhs =params(5)*T78/T78/y(111);
residual(16)= lhs-rhs;
lhs =exp(y(110))*T87^T90;
rhs =1;
residual(17)= lhs-rhs;
lhs =exp(y(117))/exp(y(124));
rhs =T102^T90;
residual(18)= lhs-rhs;
lhs =exp(y(105));
rhs =T112^(1+params(6));
residual(19)= lhs-rhs;
lhs =exp(y(114))^(1+T119*params(25));
rhs =exp(y(112))/exp(y(113));
residual(20)= lhs-rhs;
lhs =exp(y(112));
rhs =exp(y(108))*T138/T78+exp(y(112))*T144*T151;
residual(21)= lhs-rhs;
lhs =exp(y(113));
rhs =exp(y(108))*(1+params(35)*exp(y(141)))/params(27)+exp(y(113))*T144*T164;
residual(22)= lhs-rhs;
lhs =(1-params(29))*exp(y(114))^T170+params(29)*T146^T170;
rhs =1;
residual(23)= lhs-rhs;
lhs =exp(y(115));
rhs =(1-params(29))*exp(y(114))^T150+params(29)*T151*exp(y(133));
residual(24)= lhs-rhs;
lhs =exp(y(108));
rhs =exp(y(106))+exp(y(109))+1/params(33)*exp(y(121));
residual(25)= lhs-rhs;
lhs =exp(y(109));
rhs =exp(y(108))*params(7)*exp(y(139));
residual(26)= lhs-rhs;
lhs =y(118);
rhs =y(111)*exp(y(110))/exp(y(135));
residual(27)= lhs-rhs;
lhs =1/(1+y(130));
rhs =params(13)*T214/T214/y(125);
residual(28)= lhs-rhs;
lhs =exp(y(124))*T223^T226;
rhs =1;
residual(29)= lhs-rhs;
lhs =1/exp(y(117))/exp(y(110));
rhs =T234^T226;
residual(30)= lhs-rhs;
lhs =exp(y(119));
rhs =T244^(1+params(14));
residual(31)= lhs-rhs;
lhs =exp(y(128))^(1+T251*params(24));
rhs =exp(y(126))/exp(y(127));
residual(32)= lhs-rhs;
lhs =exp(y(126));
rhs =exp(y(122))*T270/T214+exp(y(126))*T276*T283;
residual(33)= lhs-rhs;
lhs =exp(y(127));
rhs =exp(y(122))*(1+params(40)*exp(y(144)))/params(26)+exp(y(127))*T276*T296;
residual(34)= lhs-rhs;
lhs =(1-params(28))*exp(y(128))^T302+params(28)*T278^T302;
rhs =1;
residual(35)= lhs-rhs;
lhs =exp(y(129));
rhs =(1-params(28))*exp(y(128))^T282+params(28)*T283*exp(y(136));
residual(36)= lhs-rhs;
lhs =exp(y(122));
rhs =exp(y(120))+exp(y(123))+exp(y(107))*params(33);
residual(37)= lhs-rhs;
lhs =exp(y(123));
rhs =exp(y(122))*params(15)*exp(y(142));
residual(38)= lhs-rhs;
lhs =y(131);
rhs =y(125)*exp(y(124))/exp(y(138));
residual(39)= lhs-rhs;
lhs =params(47)/T213*params(48);
rhs =params(49)/exp(y(117))*params(50)/T76*params(51);
residual(40)= lhs-rhs;
lhs =y(103);
rhs =T68-T352;
residual(41)= lhs-rhs;
lhs =y(104);
rhs =exp(y(119))^(1-params(12))/(1-params(12))-T364;
residual(42)= lhs-rhs;
lhs =y(139);
rhs =y(139)*params(8)+params(9)*x(1);
residual(43)= lhs-rhs;
lhs =y(140);
rhs =y(140)*params(10)+params(11)*x(2);
residual(44)= lhs-rhs;
lhs =y(141);
rhs =y(141)*params(22)+params(23)*x(6);
residual(45)= lhs-rhs;
lhs =y(142);
rhs =y(142)*params(16)+params(17)*x(3);
residual(46)= lhs-rhs;
lhs =y(143);
rhs =y(143)*params(18)+params(19)*x(4);
residual(47)= lhs-rhs;
lhs =y(144);
rhs =y(144)*params(20)+params(21)*x(5);
residual(48)= lhs-rhs;
residual(49) = y(72)*T411-y(74)*(T432+T443/(T444*T448))-T411*y(68)/T444-T411*y(94)/T444-T475-T423*T411*params(4)*params(51)*params(49)*params(50)*y(93)*exp((-y(20)))+T502-T423*T417*T411*T436*params(4)*params(5)*y(69)/(y(14)*T444)+T444*T417*T411*T436*params(4)*params(5)*y(69)/T517-T423*T527*T529/T444+T529*T444*T527/T535+T543/(T448*T535);
residual(50) = (-y(78))*exp(y(9))-T556*T563-T502;
residual(51) = y(80);
residual(52) = y(77)*exp(y(18))-params(3)*y(56)+T584;
residual(53) = y(56)-params(3)*y(57)-params(29)*y(77)*exp(y(36))/T448;
residual(54) = y(57);
residual(55) = y(79)*exp(y(12))-y(78)*exp(y(12));
residual(56) = y(75)*T525+T440*y(73)*exp((-y(16)))-T619;
residual(57) = y(74)*T440-T440*y(73)*exp((-y(16)))-T630;
residual(58) = T475-T563*T636-exp(y(10))*params(33)*y(90);
residual(59) = params(29)*params(34)*y(76)/(T648*T651)-T417*y(80)*exp((-y(38)))-y(54)+T444*T417*T436*params(5)*y(69)/T667-T677-T690-T698/(T675*T444*params(3)*T648);
residual(60) = T711*T712+y(76)*T706*(params(29)-1)/T718-(params(29)-1)*(1+params(27))*(1+params(25))*y(77)*T706/T726;
residual(61) = y(71)*T732*exp(y(20))-T436*exp((-y(20)))*y(83)+T444*exp((-y(20)))*params(51)*params(49)*params(50)*y(93);
residual(62) = params(3)*(-y(58))-y(69)/T750;
residual(63) = y(58)-params(3)*y(59);
residual(64) = y(59);
residual(65) = T619+T630+T417*y(70)*(T411*params(31)*exp((-y(9))))^T90-y(74)*(T767+T772)-T436*exp((-y(20)))*y(83)-params(3)*y(60)-T417*exp((-y(38)))*y(14)*y(80)-T444*T417*T436*params(5)*y(69)/(y(14)*T444)+T444*T417*T436*params(5)*y(69)/(T444*params(3)*y(14))-T529*T444*T417*T525*T436*params(5)*params(29)*y(75)/T444;
residual(66) = T417*exp((-y(38)))*y(14)*y(80)+y(60)-params(3)*y(61);
residual(67) = y(61);
residual(68) = T420*y(78)-T814-T420*y(75)*(1+params(35)*exp(y(50)))/params(27)-T420*params(7)*y(79)*exp(y(48))+T832/T582;
residual(69) = y(84)*T838-y(86)*(T858+T867/(T868*T872))-T838*y(95)/T868+T849*T838*y(93)*params(12)*params(47)*params(48)-T900+T915-T849*T843*T838*T732*params(13)*params(12)*y(81)/(y(28)*T868)+T868*T843*T838*T732*params(13)*params(12)*y(81)/T930-T849*T940*T942/T868+T942*T868*T940/T948+T956/(T872*T948);
residual(70) = (-y(90))*exp(y(23))-T968*T975-T915;
residual(71) = y(92);
residual(72) = y(89)*exp(y(32))-params(3)*y(62)+T996;
residual(73) = y(62)-params(3)*y(63)-params(28)*y(89)*exp(y(39))/T872;
residual(74) = y(63);
residual(75) = y(91)*exp(y(26))-y(90)*exp(y(26));
residual(76) = y(87)*T938+T864*y(85)*exp((-y(30)))-T1031;
residual(77) = y(86)*T864-T864*y(85)*exp((-y(30)))-T1042;
residual(78) = T900-T975*T1048-y(78)*exp(y(24))/params(33);
residual(79) = params(28)*params(39)*y(88)/(T1059*T1062)-T843*y(92)*exp((-y(41)))-y(55)+T868*T843*T732*params(13)*y(81)/T1078-T1088-T1101-T1109/(T1086*T868*params(3)*T1059);
residual(80) = T1122*T1123+y(88)*T1117*(params(28)-1)/T1129-(params(28)-1)*(1+params(26))*(1+params(24))*y(89)*T1117/T1137;
residual(81) = params(3)*(-y(64))-y(81)/T1146;
residual(82) = y(64)-params(3)*y(65);
residual(83) = y(65);
residual(84) = T1031+T1042+T843*y(82)*(T838*params(37)*exp((-y(23))))^T226-y(86)*(T1163+T1168)-params(3)*y(66)-y(71)*T732*exp(y(20))-T843*exp((-y(41)))*y(28)*y(92)-T868*T843*T732*params(13)*y(81)/(y(28)*T868)+T868*T843*T732*params(13)*y(81)/(T868*params(3)*y(28))-T942*T868*T843*T938*T732*params(13)*params(28)*y(87)/T868;
residual(85) = T843*exp((-y(41)))*y(28)*y(92)+y(66)-params(3)*y(67);
residual(86) = y(67);
residual(87) = y(90)*T846-T1210-T846*y(87)*(1+params(40)*exp(y(53)))/params(26)-T846*params(15)*y(91)*exp(y(51))+T1228/T994;
residual(88) = y(54);
residual(89) = y(55);
residual(90) = params(1)+y(94);
residual(91) = params(2)+y(95);
residual(92) = y(68)-params(5)*y(68)/params(3);
lhs =y(98);
rhs =y(68)*(y(35)-params(5)*y(35)+T1247)+y(69)*T1255+y(74)*(T440-T767-T772)+y(75)*(T1264-T1269)+y(81)*T1278+y(86)*(T864-T1163-T1168)+y(87)*(T1287-T1292);
residual(93)= lhs-rhs;
lhs =y(1);
rhs =y(68)*(T1247+y(35)-y(132)*params(5))+y(69)*T1309+y(74)*(T440-T767-T1318)+y(75)*(T1264-T1326)+y(81)*T1338+y(86)*(T864-T1163-T1347)+y(87)*(T1287-T1355);
residual(94)= lhs-rhs;
lhs =y(2);
rhs =params(1)*y(6)+params(2)*y(7);
residual(95)= lhs-rhs;
lhs =y(3);
rhs =y(2)+params(3)*y(3);
residual(96)= lhs-rhs;
lhs =y(96);
rhs =y(6)+params(3)*y(96);
residual(97)= lhs-rhs;
lhs =y(97);
rhs =y(7)+params(3)*y(97);
residual(98)= lhs-rhs;
lhs =y(4);
rhs =y(14);
residual(99)= lhs-rhs;
lhs =y(5);
rhs =y(28);
residual(100)= lhs-rhs;
lhs =y(36);
rhs =y(18);
residual(101)= lhs-rhs;
lhs =y(42);
rhs =y(36);
residual(102)= lhs-rhs;
lhs =y(37);
rhs =y(19);
residual(103)= lhs-rhs;
lhs =y(43);
rhs =y(37);
residual(104)= lhs-rhs;
lhs =y(38);
rhs =y(13);
residual(105)= lhs-rhs;
lhs =y(44);
rhs =y(38);
residual(106)= lhs-rhs;
lhs =y(39);
rhs =y(32);
residual(107)= lhs-rhs;
lhs =y(45);
rhs =y(39);
residual(108)= lhs-rhs;
lhs =y(40);
rhs =y(33);
residual(109)= lhs-rhs;
lhs =y(46);
rhs =y(40);
residual(110)= lhs-rhs;
lhs =y(41);
rhs =y(27);
residual(111)= lhs-rhs;
lhs =y(47);
rhs =y(41);
residual(112)= lhs-rhs;
lhs =y(35);
rhs =params(5)*y(35)+T1403;
residual(113)= lhs-rhs;
lhs =1/(1+y(19));
rhs =params(5)*T1407/T1407/y(14);
residual(114)= lhs-rhs;
lhs =T417*T1413^T90;
rhs =1;
residual(115)= lhs-rhs;
lhs =exp(y(20))/T843;
rhs =T1419^T90;
residual(116)= lhs-rhs;
lhs =T411;
rhs =T562^(1+params(6));
residual(117)= lhs-rhs;
lhs =T706^(1+T119*params(25));
rhs =T440/T525;
residual(118)= lhs-rhs;
lhs =T440;
rhs =T420*T1429/T1407+T440*T1433*T1434;
residual(119)= lhs-rhs;
lhs =T525;
rhs =T420*(1+params(35)*exp(y(50)))/params(27)+T525*T529*T1433;
residual(120)= lhs-rhs;
lhs =(1-params(29))*T706^T170+params(29)*T445^T170;
rhs =1;
residual(121)= lhs-rhs;
lhs =exp(y(18));
rhs =(1-params(29))*T706^T150+exp(y(36))*params(29)*T1434;
residual(122)= lhs-rhs;
lhs =T420;
rhs =exp(y(9))+exp(y(12))+1/params(33)*exp(y(24));
residual(123)= lhs-rhs;
lhs =exp(y(12));
rhs =exp(y(48))*params(7)*T420;
residual(124)= lhs-rhs;
lhs =y(21);
rhs =y(14)*T417/exp(y(38));
residual(125)= lhs-rhs;
lhs =1/(1+y(33));
rhs =params(13)*T1470/T1470/y(28);
residual(126)= lhs-rhs;
lhs =T843*T1476^T226;
rhs =1;
residual(127)= lhs-rhs;
lhs =1/exp(y(20))/T417;
rhs =T1483^T226;
residual(128)= lhs-rhs;
lhs =T838;
rhs =T974^(1+params(14));
residual(129)= lhs-rhs;
lhs =T1117^(1+T251*params(24));
rhs =T864/T938;
residual(130)= lhs-rhs;
lhs =T864;
rhs =T846*T1493/T1470+T864*T1497*T1498;
residual(131)= lhs-rhs;
lhs =T938;
rhs =T846*(1+params(40)*exp(y(53)))/params(26)+T938*T942*T1497;
residual(132)= lhs-rhs;
lhs =(1-params(28))*T1117^T302+params(28)*T869^T302;
rhs =1;
residual(133)= lhs-rhs;
lhs =exp(y(32));
rhs =(1-params(28))*T1117^T282+exp(y(39))*params(28)*T1498;
residual(134)= lhs-rhs;
lhs =T846;
rhs =exp(y(23))+exp(y(26))+params(33)*exp(y(10));
residual(135)= lhs-rhs;
lhs =exp(y(26));
rhs =exp(y(51))*params(15)*T846;
residual(136)= lhs-rhs;
lhs =y(34);
rhs =y(28)*T843/exp(y(41));
residual(137)= lhs-rhs;
lhs =params(48)*params(47)/T1469;
rhs =params(51)*params(50)*params(49)/exp(y(20))/T1406;
residual(138)= lhs-rhs;
lhs =y(6);
rhs =T1403-T1544;
residual(139)= lhs-rhs;
lhs =y(7);
rhs =T838^(1-params(12))/(1-params(12))-T1553;
residual(140)= lhs-rhs;
lhs =y(48);
rhs =params(9)*x(1)+params(8)*y(48);
residual(141)= lhs-rhs;
lhs =y(49);
rhs =params(11)*x(2)+params(10)*y(49);
residual(142)= lhs-rhs;
lhs =y(50);
rhs =params(23)*x(6)+params(22)*y(50);
residual(143)= lhs-rhs;
lhs =y(51);
rhs =params(17)*x(3)+params(16)*y(51);
residual(144)= lhs-rhs;
lhs =y(52);
rhs =params(19)*x(4)+params(18)*y(52);
residual(145)= lhs-rhs;
lhs =y(53);
rhs =params(21)*x(5)+params(20)*y(53);
residual(146)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(146, 146);

  %
  % Jacobian matrix
  %

  g1(1,99)=1;
  g1(1,103)=(-params(1));
  g1(1,104)=(-params(2));
  g1(2,99)=(-1);
  g1(2,100)=1-params(3);
  g1(3,103)=(-1);
  g1(3,145)=1-params(3);
  g1(4,104)=(-1);
  g1(4,146)=1-params(3);
  g1(5,101)=1;
  g1(5,111)=(-1);
  g1(6,102)=1;
  g1(6,125)=(-1);
  g1(7,115)=(-1);
  g1(7,133)=1;
  g1(8,116)=(-1);
  g1(8,134)=1;
  g1(9,110)=(-1);
  g1(9,135)=1;
  g1(10,129)=(-1);
  g1(10,136)=1;
  g1(11,130)=(-1);
  g1(11,137)=1;
  g1(12,124)=(-1);
  g1(12,138)=1;
  g1(13,14)=(-(1-params(52)));
  g1(13,111)=1;
  g1(14,28)=(-1);
  g1(14,125)=1;
  g1(15,105)=T3585;
  g1(15,132)=1-params(5);
  g1(16,105)=(-((T78*params(5)*T3588-params(5)*T78*T3588)/(T78*T78)/y(111)));
  g1(16,110)=(-((T78*params(5)*T3694-params(5)*T78*T3694)/(T78*T78)/y(111)));
  g1(16,111)=(-((-(params(5)*T78/T78))/(y(111)*y(111))));
  g1(16,116)=(-1)/((1+y(116))*(1+y(116)));
  g1(17,105)=exp(y(110))*T87*getPowerDeriv(T87,T90,1);
  g1(17,106)=exp(y(110))*getPowerDeriv(T87,T90,1)*(-(exp(y(105))*params(31)*exp(y(106))))/(exp(y(106))*exp(y(106)));
  g1(17,110)=exp(y(110))*T87^T90;
  g1(18,105)=(-(T102*getPowerDeriv(T102,T90,1)));
  g1(18,107)=(-(getPowerDeriv(T102,T90,1)*(-(exp(y(105))*params(32)*exp(y(107))))/(exp(y(107))*exp(y(107)))));
  g1(18,117)=exp(y(117))/exp(y(124));
  g1(18,124)=(-(exp(y(117))*exp(y(124))))/(exp(y(124))*exp(y(124)));
  g1(19,105)=exp(y(105));
  g1(19,106)=(-(T105*exp(y(106))*getPowerDeriv(exp(y(106)),T106,1)*getPowerDeriv(T112,1+params(6),1)));
  g1(19,107)=(-(getPowerDeriv(T112,1+params(6),1)*T109*exp(y(107))*getPowerDeriv(exp(y(107)),T106,1)));
  g1(20,112)=(-(exp(y(112))/exp(y(113))));
  g1(20,113)=(-((-(exp(y(112))*exp(y(113))))/(exp(y(113))*exp(y(113)))));
  g1(20,114)=exp(y(114))*getPowerDeriv(exp(y(114)),1+T119*params(25),1);
  g1(21,105)=(-(exp(y(108))*(-(T138*T3588))/(T78*T78)+exp(y(112))*T151*(T78*params(5)*params(29)*T3588-T78*params(5)*params(29)*T3588)/(T78*T78)));
  g1(21,108)=(-(exp(y(108))*T138/T78+exp(y(108))*T119*params(30)*T136*getPowerDeriv(T136,params(25),1)/T78));
  g1(21,110)=(-(exp(y(108))*(-(T138*T3694))/(T78*T78)+exp(y(112))*T151*(T78*params(5)*params(29)*T3694-T78*params(5)*params(29)*T3694)/(T78*T78)));
  g1(21,111)=(-(exp(y(112))*T144*T3752));
  g1(21,112)=exp(y(112))-exp(y(112))*T144*T151;
  g1(21,140)=(-(exp(y(108))*T119*params(30)*getPowerDeriv(T136,params(25),1)*(-(exp(y(108))*exp(y(140))))/(exp(y(140))*exp(y(140)))/T78));
  g1(22,105)=(-(exp(y(113))*T164*(T78*params(5)*params(29)*T3588-T78*params(5)*params(29)*T3588)/(T78*T78)));
  g1(22,108)=(-(exp(y(108))*(1+params(35)*exp(y(141)))/params(27)));
  g1(22,110)=(-(exp(y(113))*T164*(T78*params(5)*params(29)*T3694-T78*params(5)*params(29)*T3694)/(T78*T78)));
  g1(22,111)=(-(exp(y(113))*T144*T3750*getPowerDeriv(T146,1-T119,1)));
  g1(22,113)=exp(y(113))-exp(y(113))*T144*T164;
  g1(22,141)=(-(exp(y(108))*params(35)*exp(y(141))/params(27)));
  g1(23,111)=params(29)*T3750*getPowerDeriv(T146,T170,1);
  g1(23,114)=(1-params(29))*exp(y(114))*getPowerDeriv(exp(y(114)),T170,1);
  g1(24,111)=(-(exp(y(133))*params(29)*T3752));
  g1(24,114)=(-((1-params(29))*exp(y(114))*getPowerDeriv(exp(y(114)),T150,1)));
  g1(24,115)=exp(y(115));
  g1(24,133)=(-(params(29)*T151*exp(y(133))));
  g1(25,106)=(-exp(y(106)));
  g1(25,108)=exp(y(108));
  g1(25,109)=(-exp(y(109)));
  g1(25,121)=(-(1/params(33)*exp(y(121))));
  g1(26,108)=(-(exp(y(108))*params(7)*exp(y(139))));
  g1(26,109)=exp(y(109));
  g1(26,139)=(-(exp(y(108))*params(7)*exp(y(139))));
  g1(27,110)=(-(y(111)*exp(y(110))/exp(y(135))));
  g1(27,111)=(-(exp(y(110))/exp(y(135))));
  g1(27,118)=1;
  g1(27,135)=(-(y(111)*(-(exp(y(110))*exp(y(135))))/(exp(y(135))*exp(y(135)))));
  g1(28,119)=(-((T214*params(13)*T3825-params(13)*T214*T3825)/(T214*T214)/y(125)));
  g1(28,124)=(-((T214*params(13)*T3937-params(13)*T214*T3937)/(T214*T214)/y(125)));
  g1(28,125)=(-((-(params(13)*T214/T214))/(y(125)*y(125))));
  g1(28,130)=(-1)/((1+y(130))*(1+y(130)));
  g1(29,119)=exp(y(124))*T223*getPowerDeriv(T223,T226,1);
  g1(29,120)=exp(y(124))*getPowerDeriv(T223,T226,1)*(-(exp(y(119))*params(37)*exp(y(120))))/(exp(y(120))*exp(y(120)));
  g1(29,124)=exp(y(124))*T223^T226;
  g1(30,110)=(-(exp(y(110))*1/exp(y(117))))/(exp(y(110))*exp(y(110)));
  g1(30,117)=(-exp(y(117)))/(exp(y(117))*exp(y(117)))/exp(y(110));
  g1(30,119)=(-(T234*getPowerDeriv(T234,T226,1)));
  g1(30,121)=(-(getPowerDeriv(T234,T226,1)*(-(exp(y(121))*exp(y(119))*params(38)))/(exp(y(121))*exp(y(121)))));
  g1(31,119)=exp(y(119));
  g1(31,120)=(-(T237*exp(y(120))*getPowerDeriv(exp(y(120)),T238,1)*getPowerDeriv(T244,1+params(14),1)));
  g1(31,121)=(-(getPowerDeriv(T244,1+params(14),1)*T241*exp(y(121))*getPowerDeriv(exp(y(121)),T238,1)));
  g1(32,126)=(-(exp(y(126))/exp(y(127))));
  g1(32,127)=(-((-(exp(y(126))*exp(y(127))))/(exp(y(127))*exp(y(127)))));
  g1(32,128)=exp(y(128))*getPowerDeriv(exp(y(128)),1+T251*params(24),1);
  g1(33,119)=(-(exp(y(122))*(-(T270*T3825))/(T214*T214)+exp(y(126))*T283*(T214*params(13)*params(28)*T3825-T214*params(13)*params(28)*T3825)/(T214*T214)));
  g1(33,122)=(-(exp(y(122))*T270/T214+exp(y(122))*T251*params(36)*T268*getPowerDeriv(T268,params(24),1)/T214));
  g1(33,124)=(-(exp(y(122))*(-(T270*T3937))/(T214*T214)+exp(y(126))*T283*(T214*params(13)*params(28)*T3937-T214*params(13)*params(28)*T3937)/(T214*T214)));
  g1(33,125)=(-(exp(y(126))*T276*T3992));
  g1(33,126)=exp(y(126))-exp(y(126))*T276*T283;
  g1(33,143)=(-(exp(y(122))*T251*params(36)*getPowerDeriv(T268,params(24),1)*(-(exp(y(122))*exp(y(143))))/(exp(y(143))*exp(y(143)))/T214));
  g1(34,119)=(-(exp(y(127))*T296*(T214*params(13)*params(28)*T3825-T214*params(13)*params(28)*T3825)/(T214*T214)));
  g1(34,122)=(-(exp(y(122))*(1+params(40)*exp(y(144)))/params(26)));
  g1(34,124)=(-(exp(y(127))*T296*(T214*params(13)*params(28)*T3937-T214*params(13)*params(28)*T3937)/(T214*T214)));
  g1(34,125)=(-(exp(y(127))*T276*T3990*getPowerDeriv(T278,1-T251,1)));
  g1(34,127)=exp(y(127))-exp(y(127))*T276*T296;
  g1(34,144)=(-(exp(y(122))*params(40)*exp(y(144))/params(26)));
  g1(35,125)=params(28)*T3990*getPowerDeriv(T278,T302,1);
  g1(35,128)=(1-params(28))*exp(y(128))*getPowerDeriv(exp(y(128)),T302,1);
  g1(36,125)=(-(exp(y(136))*params(28)*T3992));
  g1(36,128)=(-((1-params(28))*exp(y(128))*getPowerDeriv(exp(y(128)),T282,1)));
  g1(36,129)=exp(y(129));
  g1(36,136)=(-(params(28)*T283*exp(y(136))));
  g1(37,107)=(-(exp(y(107))*params(33)));
  g1(37,120)=(-exp(y(120)));
  g1(37,122)=exp(y(122));
  g1(37,123)=(-exp(y(123)));
  g1(38,122)=(-(exp(y(122))*params(15)*exp(y(142))));
  g1(38,123)=exp(y(123));
  g1(38,142)=(-(exp(y(122))*params(15)*exp(y(142))));
  g1(39,124)=(-(y(125)*exp(y(124))/exp(y(138))));
  g1(39,125)=(-(exp(y(124))/exp(y(138))));
  g1(39,131)=1;
  g1(39,138)=(-(y(125)*(-(exp(y(124))*exp(y(138))))/(exp(y(138))*exp(y(138)))));
  g1(40,105)=(-(params(51)*(-(params(49)/exp(y(117))*params(50)*exp(y(105))*getPowerDeriv(exp(y(105)),(-params(4)),1)))/(T76*T76)));
  g1(40,117)=(-(params(51)*params(50)*(-(exp(y(117))*params(49)))/(exp(y(117))*exp(y(117)))/T76));
  g1(40,119)=params(48)*(-(params(47)*exp(y(119))*getPowerDeriv(exp(y(119)),(-params(12)),1)))/(T213*T213);
  g1(41,103)=1;
  g1(41,105)=T3585;
  g1(41,108)=exp(y(115))*params(30)*exp(y(140))^(-params(25))*exp(y(108))*getPowerDeriv(exp(y(108)),1+params(25),1)/(1+params(25));
  g1(41,115)=T352;
  g1(41,140)=exp(y(115))*exp(y(108))^(1+params(25))*params(30)*exp(y(140))*getPowerDeriv(exp(y(140)),(-params(25)),1)/(1+params(25));
  g1(42,104)=1;
  g1(42,119)=(-(exp(y(119))*getPowerDeriv(exp(y(119)),1-params(12),1)/(1-params(12))));
  g1(42,122)=exp(y(129))*params(36)*exp(y(143))^(-params(24))*exp(y(122))*getPowerDeriv(exp(y(122)),1+params(24),1)/(1+params(24));
  g1(42,129)=T364;
  g1(42,143)=exp(y(129))*exp(y(122))^(1+params(24))*params(36)*exp(y(143))*getPowerDeriv(exp(y(143)),(-params(24)),1)/(1+params(24));
  g1(43,139)=1-params(8);
  g1(44,140)=1-params(10);
  g1(45,141)=1-params(22);
  g1(46,142)=1-params(16);
  g1(47,143)=1-params(18);
  g1(48,144)=1-params(20);
  g1(49,8)=y(72)*T411-y(74)*((1+params(27))*T429*(T411*params(4)*params(30)*T417*T420*T423+T411*params(4)*params(30)*T417*T420*T1578)/params(27)+(T444*T448*(T443+T442*T1578)-T443*T448*T1587)/(T444*T448*T444*T448))-(T444*T411*y(68)-T411*y(68)*T1587)/(T444*T444)-(T444*T411*y(94)-T411*y(94)*T1587)/(T444*T444)-T1612-(T423*T411*params(4)*params(51)*params(49)*params(50)*y(93)*exp((-y(20)))+T411*params(4)*params(51)*params(49)*params(50)*y(93)*exp((-y(20)))*T1578)+T1621-(y(14)*T444*(T423*T417*T411*T436*params(4)*params(5)*y(69)+T417*T411*T436*params(4)*params(5)*y(69)*T1578)-T423*T417*T411*T436*params(4)*params(5)*y(69)*y(14)*T1587)/(y(14)*T444*y(14)*T444)+(T517*(T444*T417*T411*T436*params(4)*params(5)*y(69)+T417*T411*T436*params(4)*params(5)*y(69)*T1587)-T444*T417*T411*T436*params(4)*params(5)*y(69)*params(3)*y(14)*T411*getPowerDeriv(T411,1+params(4),1))/(T517*T517)-(T444*T529*(T423*T527+T527*T1578)-T423*T527*T529*T1587)/(T444*T444)+(T535*T529*(T444*T527+T527*T1587)-T529*T444*T527*params(3)*T411*getPowerDeriv(T411,1+params(4),1))/(T535*T535)+(T448*T535*(T543+T417*T440*T411*T436*y(74)*params(29)*params(4)*params(5)*T1587)-T543*T448*params(3)*T411*getPowerDeriv(T411,1+params(4),1))/(T448*T535*T448*T535);
  g1(49,9)=T1851;
  g1(49,10)=(-T1889);
  g1(49,11)=(-(y(74)*(1+params(27))*(T411*params(4)*params(30)*T417*T420*T423*T429+T411*params(4)*params(30)*T417*T420*T423*T1916)/params(27)));
  g1(49,13)=T502+(-(y(74)*(T432+T423*(T442+T417*T440*T411*params(29)*params(4)*params(5)*(-T436))/(T444*T448))))-T423*(T417*T411*T436*params(4)*params(5)*y(69)+T417*T411*params(4)*params(5)*y(69)*(-T436))/(y(14)*T444)+T444*(T417*T411*T436*params(4)*params(5)*y(69)+T417*T411*params(4)*params(5)*y(69)*(-T436))/T517-T529*T423*(T527+T417*T525*T411*params(29)*params(4)*params(5)*y(75)*(-T436))/T444+T529*T444*(T527+T417*T525*T411*params(29)*params(4)*params(5)*y(75)*(-T436))/T535+T444*(T417*T440*T411*T436*y(74)*params(29)*params(4)*params(5)+T417*T440*T411*y(74)*params(29)*params(4)*params(5)*(-T436))/(T448*T535);
  g1(49,14)=(-(y(74)*(-(T443*T444*T2147))/(T444*T448*T444*T448)))-(-(T444*T423*T417*T411*T436*params(4)*params(5)*y(69)))/(y(14)*T444*y(14)*T444)+(-(T444*T417*T411*T436*params(4)*params(5)*y(69)*T535))/(T517*T517)-T423*T527*T2163/T444+T444*T527*T2163/T535+(-(T543*T535*T2147))/(T448*T535*T448*T535);
  g1(49,15)=T543/(T448*T535)+(-(y(74)*T443/(T444*T448)));
  g1(49,16)=T529*T444*T527/T535+(-(T423*T527*T529/T444));
  g1(49,20)=(-(T423*T411*params(4)*params(51)*params(49)*params(50)*y(93)*(-exp((-y(20))))));
  g1(49,49)=(-(y(74)*(1+params(27))*T411*params(4)*params(30)*T417*T420*T423*T3197/params(27)));
  g1(49,68)=(-(T411/T444));
  g1(49,69)=(-(T423*T417*T411*params(4)*params(5)*T436/(y(14)*T444)))+T444*T417*T411*params(4)*params(5)*T436/T517;
  g1(49,70)=T500*T417*T411*params(31)*params(6)*exp((-y(9)))/(1+params(6));
  g1(49,71)=(-(T473*T411*params(6)*params(32)*exp((-y(10)))/(1+params(6))));
  g1(49,72)=T411;
  g1(49,74)=(-(T432+T443/(T444*T448)))+T442*T444/(T448*T535);
  g1(49,75)=(-(T529*T423*T417*T411*params(29)*params(4)*params(5)*T436*T525/T444))+T529*T444*T417*T411*params(29)*params(4)*params(5)*T436*T525/T535;
  g1(49,93)=(-(T423*T411*params(4)*params(51)*params(49)*params(50)*exp((-y(20)))));
  g1(49,94)=(-(T411/T444));
  g1(50,8)=(-T1621);
  g1(50,9)=(-y(78))*exp(y(9))-(T563*(T556+exp(y(9))*T105*y(72)*exp(y(9))*getPowerDeriv(exp(y(9)),T106-1,1))+T556*T1860)-T1851;
  g1(50,10)=(-(T556*T1894));
  g1(50,13)=(-T502);
  g1(50,70)=(-(T500*T417*T411*params(31)*params(6)*exp((-y(9)))/(1+params(6))));
  g1(50,72)=(-(T563*exp(y(9))^(T106-1)*T105*exp(y(9))));
  g1(50,78)=(-exp(y(9)));
  g1(51,80)=1;
  g1(52,11)=exp(y(18))*params(30)*y(94)*T420*getPowerDeriv(T420,1+params(25),1)/T583;
  g1(52,18)=y(77)*exp(y(18))+T584;
  g1(52,49)=(-(T580*(1+params(25))*exp(y(49))*getPowerDeriv(exp(y(49)),params(25),1)))/(T583*T583);
  g1(52,56)=(-params(3));
  g1(52,77)=exp(y(18));
  g1(52,94)=T579*params(30)*exp(y(18))/T583;
  g1(53,14)=(-((-(params(29)*y(77)*exp(y(36))*T2147))/(T448*T448)));
  g1(53,36)=(-(params(29)*y(77)*exp(y(36))/T448));
  g1(53,56)=1;
  g1(53,57)=(-params(3));
  g1(53,77)=(-(params(29)*exp(y(36))/T448));
  g1(54,57)=1;
  g1(55,12)=y(79)*exp(y(12))-y(78)*exp(y(12));
  g1(55,78)=(-exp(y(12)));
  g1(55,79)=exp(y(12));
  g1(56,8)=(-T1678);
  g1(56,13)=(-T2026);
  g1(56,14)=(-T2181);
  g1(56,15)=T440*y(73)*exp((-y(16)));
  g1(56,16)=y(75)*T525+T440*y(73)*(-exp((-y(16))))-T619;
  g1(56,73)=T440*exp((-y(16)));
  g1(56,75)=T525-T529*T444*T417*T525*params(5)*params(29)*T436/(params(3)*T444);
  g1(57,8)=(-T1686);
  g1(57,13)=(-T2033);
  g1(57,14)=(-T2186);
  g1(57,15)=y(74)*T440-T440*y(73)*exp((-y(16)))-T630;
  g1(57,16)=(-(T440*y(73)*(-exp((-y(16))))));
  g1(57,73)=(-(T440*exp((-y(16)))));
  g1(57,74)=T440-T444*T417*T440*params(5)*params(29)*T436/(T448*params(3)*T444);
  g1(58,8)=T1612;
  g1(58,9)=(-(T636*T1860));
  g1(58,10)=T1889-(T636*T1894+T563*(T636+exp(y(10))*T109*y(72)*exp(y(10))*getPowerDeriv(exp(y(10)),T106-1,1)))-exp(y(10))*params(33)*y(90);
  g1(58,71)=T473*T411*params(6)*params(32)*exp((-y(10)))/(1+params(6));
  g1(58,72)=(-(T563*exp(y(10))^(T106-1)*T109*exp(y(10))));
  g1(58,90)=(-(params(33)*exp(y(10))));
  g1(59,8)=(T667*T417*T436*params(5)*y(69)*T1587-T444*T417*T436*params(5)*y(69)*params(3)*y(14)^2*T1587)/(T667*T667)-(T689*(T119-1)*T417*T525*T436*y(75)*params(29)*params(5)*params(34)*T1587-T444*T417*T525*T436*y(75)*params(29)*params(5)*params(34)*(T119-1)*T445^T119*params(3)*y(14)^2*T1587)/(T689*T689)-(T675*T444*params(3)*T648*(1+params(27))*(1+params(25))*T417*T440*T436*y(74)*params(29)*params(5)*params(34)*T1587-T698*T675*params(3)*T648*T1587)/(T675*T444*params(3)*T648*T675*T444*params(3)*T648);
  g1(59,13)=(-(T417*y(80)*exp((-y(38)))))+T444*(T417*T436*params(5)*y(69)+T417*params(5)*y(69)*(-T436))/T667-(T119-1)*T444*(T417*T525*T436*y(75)*params(29)*params(5)*params(34)+T417*T525*y(75)*params(29)*params(5)*params(34)*(-T436))/T689-(1+params(27))*(1+params(25))*T444*(T417*T440*T436*y(74)*params(29)*params(5)*params(34)+T417*T440*y(74)*params(29)*params(5)*params(34)*(-T436))/(T675*T444*params(3)*T648);
  g1(59,14)=(-(params(29)*params(34)*y(76)*(T651*params(27)*2*y(14)+T648*T2145*getPowerDeriv(T445,T650,1))))/(T648*T651*T648*T651)+(-(T444*T417*T436*params(5)*y(69)*T444*params(3)*2*y(14)))/(T667*T667)-(-((1+params(27))*(1+params(25))*exp(y(36))*y(77)*params(29)*params(34)*(T675*params(27)*2*y(14)+T648*T2145*getPowerDeriv(T445,1+T447,1))))/(T648*T675*T648*T675)-(-(T444*T417*T525*T436*y(75)*params(29)*params(5)*params(34)*(T119-1)*(T445^T119*T444*params(3)*2*y(14)+T667*T2145*getPowerDeriv(T445,T119,1))))/(T689*T689)-(-(T698*(T444*params(3)*T648*T2145*getPowerDeriv(T445,1+T447,1)+T675*T444*params(3)*params(27)*2*y(14))))/(T675*T444*params(3)*T648*T675*T444*params(3)*T648);
  g1(59,15)=(-(T698/(T675*T444*params(3)*T648)));
  g1(59,16)=(-T690);
  g1(59,36)=(-T677);
  g1(59,38)=(-(T417*y(80)*(-exp((-y(38))))));
  g1(59,54)=(-1);
  g1(59,69)=T444*T417*params(5)*T436/T667;
  g1(59,74)=(-((1+params(27))*(1+params(25))*T444*T417*T440*T436*params(29)*params(5)*params(34)/(T675*T444*params(3)*T648)));
  g1(59,75)=(-((T119-1)*T444*T417*T525*T436*params(29)*params(5)*params(34)/T689));
  g1(59,76)=params(29)*params(34)/(T648*T651);
  g1(59,77)=(-((1+params(27))*(1+params(25))*exp(y(36))*params(29)*params(34)/(T648*T675)));
  g1(59,80)=(-(T417*exp((-y(38)))));
  g1(60,17)=T712*(T711+y(73)*T706*T706*getPowerDeriv(T706,(1+params(27))*params(25)/params(27),1))+(y(76)*T706*(params(29)-1)*T718-y(76)*T706*(params(29)-1)*params(27)*T706*getPowerDeriv(T706,T650,1))/(T718*T718)-((params(29)-1)*(1+params(27))*(1+params(25))*y(77)*T706*T726-(params(29)-1)*(1+params(27))*(1+params(25))*y(77)*T706*params(27)*T706*getPowerDeriv(T706,1+T447,1))/(T726*T726);
  g1(60,73)=T712*T706*T710;
  g1(60,76)=T706*(params(29)-1)/T718;
  g1(60,77)=(-((params(29)-1)*(1+params(27))*(1+params(25))*T706/T726));
  g1(61,8)=exp((-y(20)))*params(51)*params(49)*params(50)*y(93)*T1587;
  g1(61,13)=(-(exp((-y(20)))*y(83)*(-T436)));
  g1(61,20)=y(71)*T732*exp(y(20))-T436*y(83)*(-exp((-y(20))))+T444*params(51)*params(49)*params(50)*y(93)*(-exp((-y(20))));
  g1(61,27)=exp(y(20))*y(71)*(-T732);
  g1(61,71)=T732*exp(y(20));
  g1(61,83)=(-(T436*exp((-y(20)))));
  g1(61,93)=T444*params(51)*params(49)*params(50)*exp((-y(20)));
  g1(62,19)=(-((-(y(69)*2*(1+y(19))))/(T750*T750)));
  g1(62,58)=(-params(3));
  g1(62,69)=(-(1/T750));
  g1(63,58)=1;
  g1(63,59)=(-params(3));
  g1(64,59)=1;
  g1(65,8)=T1678+T1686+T417*y(70)*T411*params(31)*exp((-y(9)))*getPowerDeriv(T411*params(31)*exp((-y(9))),T90,1)-y(74)*(T1722+T1727)-(y(14)*T444*T417*T436*params(5)*y(69)*T1587-T444*T417*T436*params(5)*y(69)*y(14)*T1587)/(y(14)*T444*y(14)*T444)+(T444*params(3)*y(14)*T417*T436*params(5)*y(69)*T1587-T444*T417*T436*params(5)*y(69)*params(3)*y(14)*T1587)/(T444*params(3)*y(14)*T444*params(3)*y(14))-(T444*T529*T417*T525*T436*params(5)*params(29)*y(75)*T1587-T529*T444*T417*T525*T436*params(5)*params(29)*y(75)*T1587)/(T444*T444);
  g1(65,9)=T417*y(70)*getPowerDeriv(T411*params(31)*exp((-y(9))),T90,1)*T411*params(31)*(-exp((-y(9))));
  g1(65,11)=(-(y(74)*T1930));
  g1(65,13)=T2026+T2033+T417*y(70)*(T411*params(31)*exp((-y(9))))^T90-y(74)*(T767+T2066)-exp((-y(20)))*y(83)*(-T436)-T417*exp((-y(38)))*y(14)*y(80)-T444*(T417*T436*params(5)*y(69)+T417*params(5)*y(69)*(-T436))/(y(14)*T444)+T444*(T417*T436*params(5)*y(69)+T417*params(5)*y(69)*(-T436))/(T444*params(3)*y(14))-T529*T444*(T417*T525*T436*params(5)*params(29)*y(75)+T417*T525*params(5)*params(29)*y(75)*(-T436))/T444;
  g1(65,14)=T2181+T2186+(-(y(74)*T2235))-T417*y(80)*exp((-y(38)))-(-(T444*T444*T417*T436*params(5)*y(69)))/(y(14)*T444*y(14)*T444)+(-(params(3)*T444*T444*T417*T436*params(5)*y(69)))/(T444*params(3)*y(14)*T444*params(3)*y(14))-T444*T417*T525*T436*params(5)*params(29)*y(75)*T2163/T444;
  g1(65,15)=T630-y(74)*T772;
  g1(65,16)=T619-T529*T444*T417*T525*T436*params(5)*params(29)*y(75)/T444;
  g1(65,20)=(-(T436*y(83)*(-exp((-y(20))))));
  g1(65,38)=(-(T417*y(14)*y(80)*(-exp((-y(38))))));
  g1(65,49)=(-(y(74)*T3212));
  g1(65,60)=(-params(3));
  g1(65,69)=(-(T444*T417*params(5)*T436/(y(14)*T444)))+T444*T417*params(5)*T436/(T444*params(3)*y(14));
  g1(65,70)=T417*(T411*params(31)*exp((-y(9))))^T90;
  g1(65,74)=T444*T417*T440*params(5)*params(29)*T436/(T448*params(3)*T444)-(T767+T772);
  g1(65,75)=T529*T444*T417*T525*params(5)*params(29)*T436/(params(3)*T444)-T1269;
  g1(65,80)=(-(T417*y(14)*exp((-y(38)))));
  g1(65,83)=(-(T436*exp((-y(20)))));
  g1(66,13)=T417*exp((-y(38)))*y(14)*y(80);
  g1(66,14)=T417*y(80)*exp((-y(38)));
  g1(66,38)=T417*y(14)*y(80)*(-exp((-y(38))));
  g1(66,60)=1;
  g1(66,61)=(-params(3));
  g1(66,80)=T417*y(14)*exp((-y(38)));
  g1(67,61)=1;
  g1(68,8)=(-(y(74)*(T1722+(1+params(27))*T809*T417*exp((-y(49)))*params(25)*params(30)*exp(2*y(11))*T1587/params(27))));
  g1(68,11)=T420*y(78)-y(74)*(T1930+(1+params(27))*(T809*T444*T417*exp((-y(49)))*params(25)*params(30)*2*exp(2*y(11))+T444*T417*exp((-y(49)))*params(25)*params(30)*exp(2*y(11))*T420*exp((-y(49)))*getPowerDeriv(T420*exp((-y(49))),params(25)-1,1))/params(27))-T420*y(75)*(1+params(35)*exp(y(50)))/params(27)-T420*params(7)*y(79)*exp(y(48))+(T832+T420*exp(y(18))*params(30)*y(94)*T420*getPowerDeriv(T420,params(25),1))/T582;
  g1(68,13)=(-T814);
  g1(68,18)=T832/T582;
  g1(68,48)=(-(T420*params(7)*y(79)*exp(y(48))));
  g1(68,49)=(-(y(74)*(T3212+(1+params(27))*(T809*T444*T417*params(25)*params(30)*exp(2*y(11))*(-exp((-y(49))))+T444*T417*exp((-y(49)))*params(25)*params(30)*exp(2*y(11))*getPowerDeriv(T420*exp((-y(49))),params(25)-1,1)*T420*(-exp((-y(49)))))/params(27))))+(-(T832*exp(y(49))*getPowerDeriv(exp(y(49)),params(25),1)))/(T582*T582);
  g1(68,50)=(-(T420*y(75)*params(35)*exp(y(50))/params(27)));
  g1(68,74)=(-T813);
  g1(68,75)=(-(T420*(1+params(35)*exp(y(50)))/params(27)));
  g1(68,78)=T420;
  g1(68,79)=(-(T420*params(7)*exp(y(48))));
  g1(68,94)=T420^params(25)*T420*params(30)*exp(y(18))/T582;
  g1(69,22)=y(84)*T838-y(86)*((1+params(26))*T855*(T838*params(12)*params(36)*T843*T846*T849+T838*params(12)*params(36)*T843*T846*T2386)/params(26)+(T868*T872*(T867+T866*T2386)-T867*T872*T2395)/(T868*T872*T868*T872))-(T868*T838*y(95)-T838*y(95)*T2395)/(T868*T868)+T849*T838*y(93)*params(12)*params(47)*params(48)+T838*y(93)*params(12)*params(47)*params(48)*T2386-T2418+T2424-(y(28)*T868*(T849*T843*T838*T732*params(13)*params(12)*y(81)+T843*T838*T732*params(13)*params(12)*y(81)*T2386)-T849*T843*T838*T732*params(13)*params(12)*y(81)*y(28)*T2395)/(y(28)*T868*y(28)*T868)+(T930*(T868*T843*T838*T732*params(13)*params(12)*y(81)+T843*T838*T732*params(13)*params(12)*y(81)*T2395)-T868*T843*T838*T732*params(13)*params(12)*y(81)*params(3)*y(28)*T838*getPowerDeriv(T838,1+params(12),1))/(T930*T930)-(T868*T942*(T849*T940+T940*T2386)-T849*T940*T942*T2395)/(T868*T868)+(T948*T942*(T868*T940+T940*T2395)-T942*T868*T940*params(3)*T838*getPowerDeriv(T838,1+params(12),1))/(T948*T948)+(T872*T948*(T956+T843*T864*T838*T732*y(86)*params(28)*params(13)*params(12)*T2395)-T956*T872*params(3)*T838*getPowerDeriv(T838,1+params(12),1))/(T872*T948*T872*T948);
  g1(69,23)=T2648;
  g1(69,24)=(-T2686);
  g1(69,25)=(-(y(86)*(1+params(26))*(T838*params(12)*params(36)*T843*T846*T849*T855+T838*params(12)*params(36)*T843*T846*T849*T2713)/params(26)));
  g1(69,27)=T915+(-(y(86)*(T858+T849*(T866+T843*T864*T838*params(28)*params(13)*params(12)*(-T732))/(T868*T872))))-T849*(T843*T838*T732*params(13)*params(12)*y(81)+T843*T838*params(13)*params(12)*y(81)*(-T732))/(y(28)*T868)+T868*(T843*T838*T732*params(13)*params(12)*y(81)+T843*T838*params(13)*params(12)*y(81)*(-T732))/T930-T942*T849*(T940+T843*T938*T838*params(28)*params(13)*params(12)*y(87)*(-T732))/T868+T942*T868*(T940+T843*T938*T838*params(28)*params(13)*params(12)*y(87)*(-T732))/T948+T868*(T843*T864*T838*T732*y(86)*params(28)*params(13)*params(12)+T843*T864*T838*y(86)*params(28)*params(13)*params(12)*(-T732))/(T872*T948);
  g1(69,28)=(-(y(86)*(-(T867*T868*T2943))/(T868*T872*T868*T872)))-(-(T868*T849*T843*T838*T732*params(13)*params(12)*y(81)))/(y(28)*T868*y(28)*T868)+(-(T868*T843*T838*T732*params(13)*params(12)*y(81)*T948))/(T930*T930)-T849*T940*T2959/T868+T868*T940*T2959/T948+(-(T956*T948*T2943))/(T872*T948*T872*T948);
  g1(69,29)=T956/(T872*T948)+(-(y(86)*T867/(T868*T872)));
  g1(69,30)=T942*T868*T940/T948+(-(T849*T940*T942/T868));
  g1(69,52)=(-(y(86)*(1+params(26))*T838*params(12)*params(36)*T843*T846*T849*T3268/params(26)));
  g1(69,81)=(-(T849*T843*T838*T732*params(13)*params(12)/(y(28)*T868)))+T868*T843*T838*T732*params(13)*params(12)/T930;
  g1(69,82)=T913*T843*T838*params(37)*params(14)*exp((-y(23)))/(1+params(14));
  g1(69,83)=(-(T898*T838*params(14)*params(38)*exp((-y(24)))/(1+params(14))));
  g1(69,84)=T838;
  g1(69,86)=(-(T858+T867/(T868*T872)))+T866*T868/(T872*T948);
  g1(69,87)=(-(T942*T849*T843*T838*T732*params(28)*params(13)*params(12)*T938/T868))+T942*T868*T843*T838*T732*params(28)*params(13)*params(12)*T938/T948;
  g1(69,93)=T849*T838*params(12)*params(47)*params(48);
  g1(69,95)=(-(T838/T868));
  g1(70,22)=(-T2424);
  g1(70,23)=(-y(90))*exp(y(23))-(T975*(T968+exp(y(23))*T237*y(84)*exp(y(23))*getPowerDeriv(exp(y(23)),T238-1,1))+T968*T2657)-T2648;
  g1(70,24)=(-(T968*T2691));
  g1(70,27)=(-T915);
  g1(70,82)=(-(T913*T843*T838*params(37)*params(14)*exp((-y(23)))/(1+params(14))));
  g1(70,84)=(-(T975*exp(y(23))^(T238-1)*T237*exp(y(23))));
  g1(70,90)=(-exp(y(23)));
  g1(71,92)=1;
  g1(72,25)=exp(y(32))*params(36)*y(95)*T846*getPowerDeriv(T846,1+params(24),1)/T995;
  g1(72,32)=y(89)*exp(y(32))+T996;
  g1(72,52)=(-(T992*(1+params(24))*exp(y(52))*getPowerDeriv(exp(y(52)),params(24),1)))/(T995*T995);
  g1(72,62)=(-params(3));
  g1(72,89)=exp(y(32));
  g1(72,95)=T991*params(36)*exp(y(32))/T995;
  g1(73,28)=(-((-(params(28)*y(89)*exp(y(39))*T2943))/(T872*T872)));
  g1(73,39)=(-(params(28)*y(89)*exp(y(39))/T872));
  g1(73,62)=1;
  g1(73,63)=(-params(3));
  g1(73,89)=(-(params(28)*exp(y(39))/T872));
  g1(74,63)=1;
  g1(75,26)=y(91)*exp(y(26))-y(90)*exp(y(26));
  g1(75,90)=(-exp(y(26)));
  g1(75,91)=exp(y(26));
  g1(76,22)=(-T2481);
  g1(76,27)=(-T2825);
  g1(76,28)=(-T2977);
  g1(76,29)=T864*y(85)*exp((-y(30)));
  g1(76,30)=y(87)*T938+T864*y(85)*(-exp((-y(30))))-T1031;
  g1(76,85)=T864*exp((-y(30)));
  g1(76,87)=T938-T942*T868*T843*T938*params(13)*params(28)*T732/(params(3)*T868);
  g1(77,22)=(-T2489);
  g1(77,27)=(-T2832);
  g1(77,28)=(-T2982);
  g1(77,29)=y(86)*T864-T864*y(85)*exp((-y(30)))-T1042;
  g1(77,30)=(-(T864*y(85)*(-exp((-y(30))))));
  g1(77,85)=(-(T864*exp((-y(30)))));
  g1(77,86)=T864-T868*T843*T864*params(13)*params(28)*T732/(T872*params(3)*T868);
  g1(78,22)=T2418;
  g1(78,23)=(-(T1048*T2657));
  g1(78,24)=T2686-(T1048*T2691+T975*(T1048+exp(y(24))*T241*y(84)*exp(y(24))*getPowerDeriv(exp(y(24)),T238-1,1)))-y(78)*exp(y(24))/params(33);
  g1(78,78)=(-(exp(y(24))/params(33)));
  g1(78,83)=T898*T838*params(14)*params(38)*exp((-y(24)))/(1+params(14));
  g1(78,84)=(-(T975*exp(y(24))^(T238-1)*T241*exp(y(24))));
  g1(79,22)=(T1078*T843*T732*params(13)*y(81)*T2395-T868*T843*T732*params(13)*y(81)*params(3)*y(28)^2*T2395)/(T1078*T1078)-(T1100*(T251-1)*T843*T938*T732*y(87)*params(28)*params(13)*params(39)*T2395-T868*T843*T938*T732*y(87)*params(28)*params(13)*params(39)*(T251-1)*T869^T251*params(3)*y(28)^2*T2395)/(T1100*T1100)-(T1086*T868*params(3)*T1059*(1+params(26))*(1+params(24))*T843*T864*T732*y(86)*params(28)*params(13)*params(39)*T2395-T1109*T1086*params(3)*T1059*T2395)/(T1086*T868*params(3)*T1059*T1086*T868*params(3)*T1059);
  g1(79,27)=(-(T843*y(92)*exp((-y(41)))))+T868*(T843*T732*params(13)*y(81)+T843*params(13)*y(81)*(-T732))/T1078-(T251-1)*T868*(T843*T938*T732*y(87)*params(28)*params(13)*params(39)+T843*T938*y(87)*params(28)*params(13)*params(39)*(-T732))/T1100-(1+params(26))*(1+params(24))*T868*(T843*T864*T732*y(86)*params(28)*params(13)*params(39)+T843*T864*y(86)*params(28)*params(13)*params(39)*(-T732))/(T1086*T868*params(3)*T1059);
  g1(79,28)=(-(params(28)*params(39)*y(88)*(T1062*params(26)*2*y(28)+T1059*T2941*getPowerDeriv(T869,T1061,1))))/(T1059*T1062*T1059*T1062)+(-(T868*T843*T732*params(13)*y(81)*T868*params(3)*2*y(28)))/(T1078*T1078)-(-((1+params(26))*(1+params(24))*exp(y(39))*y(89)*params(28)*params(39)*(T1086*params(26)*2*y(28)+T1059*T2941*getPowerDeriv(T869,1+T871,1))))/(T1059*T1086*T1059*T1086)-(-(T868*T843*T938*T732*y(87)*params(28)*params(13)*params(39)*(T251-1)*(T869^T251*T868*params(3)*2*y(28)+T1078*T2941*getPowerDeriv(T869,T251,1))))/(T1100*T1100)-(-(T1109*(T868*params(3)*T1059*T2941*getPowerDeriv(T869,1+T871,1)+T1086*T868*params(3)*params(26)*2*y(28))))/(T1086*T868*params(3)*T1059*T1086*T868*params(3)*T1059);
  g1(79,29)=(-(T1109/(T1086*T868*params(3)*T1059)));
  g1(79,30)=(-T1101);
  g1(79,39)=(-T1088);
  g1(79,41)=(-(T843*y(92)*(-exp((-y(41))))));
  g1(79,55)=(-1);
  g1(79,81)=T868*T843*params(13)*T732/T1078;
  g1(79,86)=(-((1+params(26))*(1+params(24))*T868*T843*T864*T732*params(28)*params(13)*params(39)/(T1086*T868*params(3)*T1059)));
  g1(79,87)=(-((T251-1)*T868*T843*T938*T732*params(28)*params(13)*params(39)/T1100));
  g1(79,88)=params(28)*params(39)/(T1059*T1062);
  g1(79,89)=(-((1+params(26))*(1+params(24))*exp(y(39))*params(28)*params(39)/(T1059*T1086)));
  g1(79,92)=(-(T843*exp((-y(41)))));
  g1(80,31)=T1123*(T1122+y(85)*T1117*T1117*getPowerDeriv(T1117,(1+params(26))*params(24)/params(26),1))+(y(88)*T1117*(params(28)-1)*T1129-y(88)*T1117*(params(28)-1)*params(26)*T1117*getPowerDeriv(T1117,T1061,1))/(T1129*T1129)-((params(28)-1)*(1+params(26))*(1+params(24))*y(89)*T1117*T1137-(params(28)-1)*(1+params(26))*(1+params(24))*y(89)*T1117*params(26)*T1117*getPowerDeriv(T1117,1+T871,1))/(T1137*T1137);
  g1(80,85)=T1123*T1117*T1121;
  g1(80,88)=T1117*(params(28)-1)/T1129;
  g1(80,89)=(-((params(28)-1)*(1+params(26))*(1+params(24))*T1117/T1137));
  g1(81,33)=(-((-(y(81)*2*(1+y(33))))/(T1146*T1146)));
  g1(81,64)=(-params(3));
  g1(81,81)=(-(1/T1146));
  g1(82,64)=1;
  g1(82,65)=(-params(3));
  g1(83,65)=1;
  g1(84,20)=(-(y(71)*T732*exp(y(20))));
  g1(84,22)=T2481+T2489+T843*y(82)*T838*params(37)*exp((-y(23)))*getPowerDeriv(T838*params(37)*exp((-y(23))),T226,1)-y(86)*(T2524+T2529)-(y(28)*T868*T843*T732*params(13)*y(81)*T2395-T868*T843*T732*params(13)*y(81)*y(28)*T2395)/(y(28)*T868*y(28)*T868)+(T868*params(3)*y(28)*T843*T732*params(13)*y(81)*T2395-T868*T843*T732*params(13)*y(81)*params(3)*y(28)*T2395)/(T868*params(3)*y(28)*T868*params(3)*y(28))-(T868*T942*T843*T938*T732*params(13)*params(28)*y(87)*T2395-T942*T868*T843*T938*T732*params(13)*params(28)*y(87)*T2395)/(T868*T868);
  g1(84,23)=T843*y(82)*getPowerDeriv(T838*params(37)*exp((-y(23))),T226,1)*T838*params(37)*(-exp((-y(23))));
  g1(84,25)=(-(y(86)*T2727));
  g1(84,27)=T2825+T2832+T843*y(82)*(T838*params(37)*exp((-y(23))))^T226-y(86)*(T1163+T2863)-exp(y(20))*y(71)*(-T732)-T843*exp((-y(41)))*y(28)*y(92)-T868*(T843*T732*params(13)*y(81)+T843*params(13)*y(81)*(-T732))/(y(28)*T868)+T868*(T843*T732*params(13)*y(81)+T843*params(13)*y(81)*(-T732))/(T868*params(3)*y(28))-T942*T868*(T843*T938*T732*params(13)*params(28)*y(87)+T843*T938*params(13)*params(28)*y(87)*(-T732))/T868;
  g1(84,28)=T2977+T2982+(-(y(86)*T3031))-T843*y(92)*exp((-y(41)))-(-(T868*T868*T843*T732*params(13)*y(81)))/(y(28)*T868*y(28)*T868)+(-(params(3)*T868*T868*T843*T732*params(13)*y(81)))/(T868*params(3)*y(28)*T868*params(3)*y(28))-T868*T843*T938*T732*params(13)*params(28)*y(87)*T2959/T868;
  g1(84,29)=T1042-y(86)*T1168;
  g1(84,30)=T1031-T942*T868*T843*T938*T732*params(13)*params(28)*y(87)/T868;
  g1(84,41)=(-(T843*y(28)*y(92)*(-exp((-y(41))))));
  g1(84,52)=(-(y(86)*T3283));
  g1(84,66)=(-params(3));
  g1(84,71)=(-(T732*exp(y(20))));
  g1(84,81)=(-(T868*T843*params(13)*T732/(y(28)*T868)))+T868*T843*params(13)*T732/(T868*params(3)*y(28));
  g1(84,82)=T843*(T838*params(37)*exp((-y(23))))^T226;
  g1(84,86)=T868*T843*T864*params(13)*params(28)*T732/(T872*params(3)*T868)-(T1163+T1168);
  g1(84,87)=T942*T868*T843*T938*params(13)*params(28)*T732/(params(3)*T868)-T1292;
  g1(84,92)=(-(T843*y(28)*exp((-y(41)))));
  g1(85,27)=T843*exp((-y(41)))*y(28)*y(92);
  g1(85,28)=T843*y(92)*exp((-y(41)));
  g1(85,41)=T843*y(28)*y(92)*(-exp((-y(41))));
  g1(85,66)=1;
  g1(85,67)=(-params(3));
  g1(85,92)=T843*y(28)*exp((-y(41)));
  g1(86,67)=1;
  g1(87,22)=(-(y(86)*(T2524+(1+params(26))*T1205*T843*exp((-y(52)))*params(24)*params(36)*exp(2*y(25))*T2395/params(26))));
  g1(87,25)=y(90)*T846-y(86)*(T2727+(1+params(26))*(T1205*T868*T843*exp((-y(52)))*params(24)*params(36)*2*exp(2*y(25))+T868*T843*exp((-y(52)))*params(24)*params(36)*exp(2*y(25))*T846*exp((-y(52)))*getPowerDeriv(T846*exp((-y(52))),params(24)-1,1))/params(26))-T846*y(87)*(1+params(40)*exp(y(53)))/params(26)-T846*params(15)*y(91)*exp(y(51))+(T1228+T846*exp(y(32))*params(36)*y(95)*T846*getPowerDeriv(T846,params(24),1))/T994;
  g1(87,27)=(-T1210);
  g1(87,32)=T1228/T994;
  g1(87,51)=(-(T846*params(15)*y(91)*exp(y(51))));
  g1(87,52)=(-(y(86)*(T3283+(1+params(26))*(T1205*T868*T843*params(24)*params(36)*exp(2*y(25))*(-exp((-y(52))))+T868*T843*exp((-y(52)))*params(24)*params(36)*exp(2*y(25))*getPowerDeriv(T846*exp((-y(52))),params(24)-1,1)*T846*(-exp((-y(52)))))/params(26))))+(-(T1228*exp(y(52))*getPowerDeriv(exp(y(52)),params(24),1)))/(T994*T994);
  g1(87,53)=(-(T846*y(87)*params(40)*exp(y(53))/params(26)));
  g1(87,86)=(-T1209);
  g1(87,87)=(-(T846*(1+params(40)*exp(y(53)))/params(26)));
  g1(87,90)=T846;
  g1(87,91)=(-(T846*params(15)*exp(y(51))));
  g1(87,95)=T846^params(24)*T846*params(36)*exp(y(32))/T994;
  g1(88,54)=1;
  g1(89,55)=1;
  g1(90,94)=1;
  g1(91,95)=1;
  g1(92,68)=1-params(5)/params(3);
  g1(93,8)=(-(T1760+y(69)*(-((y(14)*T444*T417*params(5)*T436*T1587-T444*T417*params(5)*T436*y(14)*T1587)/(y(14)*T444*y(14)*T444)))+y(74)*((-T1722)-T1727)+y(75)*(-((T444*T529*T417*T525*params(5)*params(29)*T436*T1587-T529*T444*T417*T525*params(5)*params(29)*T436*T1587)/(T444*T444)))));
  g1(93,11)=T1961;
  g1(93,13)=(-(y(69)*(-(T444*(T417*params(5)*T436+T417*params(5)*(-T436))/(y(14)*T444)))+y(74)*((-T767)-T2066)+y(75)*(-(T529*T444*(T417*T525*params(5)*params(29)*T436+T417*T525*params(5)*params(29)*(-T436))/T444))));
  g1(93,14)=(-(y(69)*(-((-(T444*T444*T417*params(5)*T436))/(y(14)*T444*y(14)*T444)))+y(74)*(-T2235)+y(75)*(-(T444*T417*T525*params(5)*params(29)*T436*T2163/T444))));
  g1(93,15)=(-(y(74)*(T440-T772)));
  g1(93,16)=(-(y(75)*(T525-T1269)));
  g1(93,19)=(-(y(69)*(-1)/((1+y(19))*(1+y(19)))));
  g1(93,22)=(-(y(81)*(-((y(28)*T868*T843*params(13)*T732*T2395-T868*T843*params(13)*T732*y(28)*T2395)/(y(28)*T868*y(28)*T868)))+y(86)*((-T2524)-T2529)+y(87)*(-((T868*T942*T843*T938*params(13)*params(28)*T732*T2395-T942*T868*T843*T938*params(13)*params(28)*T732*T2395)/(T868*T868)))));
  g1(93,25)=T2758;
  g1(93,27)=(-(y(81)*(-(T868*(T843*params(13)*T732+T843*params(13)*(-T732))/(y(28)*T868)))+y(86)*((-T1163)-T2863)+y(87)*(-(T942*T868*(T843*T938*params(13)*params(28)*T732+T843*T938*params(13)*params(28)*(-T732))/T868))));
  g1(93,28)=(-(y(81)*(-((-(T868*T868*T843*params(13)*T732))/(y(28)*T868*y(28)*T868)))+y(86)*(-T3031)+y(87)*(-(T868*T843*T938*params(13)*params(28)*T732*T2959/T868))));
  g1(93,29)=(-(y(86)*(T864-T1168)));
  g1(93,30)=(-(y(87)*(T938-T1292)));
  g1(93,33)=(-(y(81)*(-1)/((1+y(33))*(1+y(33)))));
  g1(93,35)=(-(y(68)*(1-params(5))));
  g1(93,49)=(-(y(74)*(-T3212)));
  g1(93,50)=(-(y(75)*(-(T420*params(35)*exp(y(50))/params(27)))));
  g1(93,52)=(-(y(86)*(-T3283)));
  g1(93,53)=(-(y(87)*(-(T846*params(40)*exp(y(53))/params(26)))));
  g1(93,68)=(-(y(35)-params(5)*y(35)+T1247));
  g1(93,69)=(-T1255);
  g1(93,74)=(-(T440-T767-T772));
  g1(93,75)=(-(T1264-T1269));
  g1(93,81)=(-T1278);
  g1(93,86)=(-(T864-T1163-T1168));
  g1(93,87)=(-(T1287-T1292));
  g1(93,98)=1;
  g1(94,1)=1;
  g1(94,8)=(-(T1760+y(69)*(-(T417*params(5)*exp((-y(110)))*T1587/(y(111)*T1306)))+y(74)*((-T1722)-T417*exp(y(112))*params(5)*params(29)*exp((-y(110)))*T1587/T1317)+y(75)*(-(T164*T417*exp(y(113))*params(5)*params(29)*exp((-y(110)))*T1587/T1306))));
  g1(94,11)=T1961;
  g1(94,13)=(-(y(69)*(-(T444*T417*params(5)*exp((-y(110)))/(y(111)*T1306)))+y(74)*((-T767)-T1318)+y(75)*(-T1326)));
  g1(94,15)=(-(y(74)*T440));
  g1(94,16)=(-(y(75)*T525));
  g1(94,19)=(-(y(69)*(-1)/((1+y(19))*(1+y(19)))));
  g1(94,22)=(-(y(81)*(-(T843*params(13)*exp((-y(124)))*T2395/(y(125)*T1335)))+y(86)*((-T2524)-T843*exp(y(126))*params(13)*params(28)*exp((-y(124)))*T2395/T1346)+y(87)*(-(T296*T843*exp(y(127))*params(13)*params(28)*exp((-y(124)))*T2395/T1335))));
  g1(94,25)=T2758;
  g1(94,27)=(-(y(81)*(-(T868*T843*params(13)*exp((-y(124)))/(y(125)*T1335)))+y(86)*((-T1163)-T1347)+y(87)*(-T1355)));
  g1(94,29)=(-(y(86)*T864));
  g1(94,30)=(-(y(87)*T938));
  g1(94,33)=(-(y(81)*(-1)/((1+y(33))*(1+y(33)))));
  g1(94,35)=(-y(68));
  g1(94,49)=(-(y(74)*(-T3212)));
  g1(94,50)=(-(y(75)*(-(T420*params(35)*exp(y(50))/params(27)))));
  g1(94,52)=(-(y(86)*(-T3283)));
  g1(94,53)=(-(y(87)*(-(T846*params(40)*exp(y(53))/params(26)))));
  g1(94,68)=(-(T1247+y(35)-y(132)*params(5)));
  g1(94,69)=(-T1309);
  g1(94,74)=(-(T440-T767-T1318));
  g1(94,75)=(-(T1264-T1326));
  g1(94,81)=(-T1338);
  g1(94,86)=(-(T864-T1163-T1347));
  g1(94,87)=(-(T1287-T1355));
  g1(94,105)=(-(y(69)*(-((-(T444*T417*params(5)*exp((-y(110)))*y(111)*T3626))/(y(111)*T1306*y(111)*T1306)))+y(74)*(-((-(T444*T417*exp(y(112))*params(5)*params(29)*exp((-y(110)))*T146^T447*T3626))/(T1317*T1317)))+y(75)*(-((-(T164*T444*T417*exp(y(113))*params(5)*params(29)*exp((-y(110)))*T3626))/(T1306*T1306)))));
  g1(94,110)=(-(y(69)*(-(T444*T417*params(5)*(-exp((-y(110))))/(y(111)*T1306)))+y(74)*(-(T444*T417*exp(y(112))*params(5)*params(29)*(-exp((-y(110))))/T1317))+y(75)*(-(T164*T444*T417*exp(y(113))*params(5)*params(29)*(-exp((-y(110))))/T1306))));
  g1(94,111)=(-(y(69)*(-((-(T444*T417*params(5)*exp((-y(110)))*T1306))/(y(111)*T1306*y(111)*T1306)))+y(74)*(-((-(T444*T417*exp(y(112))*params(5)*params(29)*exp((-y(110)))*T1306*T3750*getPowerDeriv(T146,T447,1)))/(T1317*T1317)))+y(75)*(-(T444*T417*exp(y(113))*params(5)*params(29)*exp((-y(110)))*T3750*getPowerDeriv(T146,1-T119,1)/T1306))));
  g1(94,112)=(-(y(74)*(-T1318)));
  g1(94,113)=(-(y(75)*(-T1326)));
  g1(94,119)=(-(y(81)*(-((-(T868*T843*params(13)*exp((-y(124)))*y(125)*T3866))/(y(125)*T1335*y(125)*T1335)))+y(86)*(-((-(T868*T843*exp(y(126))*params(13)*params(28)*exp((-y(124)))*T278^T871*T3866))/(T1346*T1346)))+y(87)*(-((-(T296*T868*T843*exp(y(127))*params(13)*params(28)*exp((-y(124)))*T3866))/(T1335*T1335)))));
  g1(94,124)=(-(y(81)*(-(T868*T843*params(13)*(-exp((-y(124))))/(y(125)*T1335)))+y(86)*(-(T868*T843*exp(y(126))*params(13)*params(28)*(-exp((-y(124))))/T1346))+y(87)*(-(T296*T868*T843*exp(y(127))*params(13)*params(28)*(-exp((-y(124))))/T1335))));
  g1(94,125)=(-(y(81)*(-((-(T868*T843*params(13)*exp((-y(124)))*T1335))/(y(125)*T1335*y(125)*T1335)))+y(86)*(-((-(T868*T843*exp(y(126))*params(13)*params(28)*exp((-y(124)))*T1335*T3990*getPowerDeriv(T278,T871,1)))/(T1346*T1346)))+y(87)*(-(T868*T843*exp(y(127))*params(13)*params(28)*exp((-y(124)))*T3990*getPowerDeriv(T278,1-T251,1)/T1335))));
  g1(94,126)=(-(y(86)*(-T1347)));
  g1(94,127)=(-(y(87)*(-T1355)));
  g1(94,132)=(-(y(68)*(-params(5))));
  g1(95,2)=1;
  g1(95,6)=(-params(1));
  g1(95,7)=(-params(2));
  g1(96,2)=(-1);
  g1(96,3)=1-params(3);
  g1(97,6)=(-1);
  g1(97,96)=1-params(3);
  g1(98,7)=(-1);
  g1(98,97)=1-params(3);
  g1(99,4)=1;
  g1(99,14)=(-1);
  g1(100,5)=1;
  g1(100,28)=(-1);
  g1(101,18)=(-1);
  g1(101,36)=1;
  g1(102,36)=(-1);
  g1(102,42)=1;
  g1(103,19)=(-1);
  g1(103,37)=1;
  g1(104,37)=(-1);
  g1(104,43)=1;
  g1(105,13)=(-1);
  g1(105,38)=1;
  g1(106,38)=(-1);
  g1(106,44)=1;
  g1(107,32)=(-1);
  g1(107,39)=1;
  g1(108,39)=(-1);
  g1(108,45)=1;
  g1(109,33)=(-1);
  g1(109,40)=1;
  g1(110,40)=(-1);
  g1(110,46)=1;
  g1(111,27)=(-1);
  g1(111,41)=1;
  g1(112,41)=(-1);
  g1(112,47)=1;
  g1(113,8)=T1801;
  g1(113,35)=1-params(5);
  g1(114,8)=(-((T1407*params(5)*T1804-params(5)*T1407*T1804)/(T1407*T1407)/y(14)));
  g1(114,13)=(-((T1407*params(5)*T2114-params(5)*T1407*T2114)/(T1407*T1407)/y(14)));
  g1(114,14)=(-((-(params(5)*T1407/T1407))/(y(14)*y(14))));
  g1(114,19)=(-1)/((1+y(19))*(1+y(19)));
  g1(115,8)=T417*T1413*getPowerDeriv(T1413,T90,1);
  g1(115,9)=T417*getPowerDeriv(T1413,T90,1)*(-(exp(y(9))*params(31)*T411))/(exp(y(9))*exp(y(9)));
  g1(115,13)=T417*T1413^T90;
  g1(116,8)=(-(T1419*getPowerDeriv(T1419,T90,1)));
  g1(116,10)=(-(getPowerDeriv(T1419,T90,1)*(-(exp(y(10))*params(32)*T411))/(exp(y(10))*exp(y(10)))));
  g1(116,20)=exp(y(20))/T843;
  g1(116,27)=(-(exp(y(20))*T843))/(T843*T843);
  g1(117,8)=T411;
  g1(117,9)=(-(T105*exp(y(9))*getPowerDeriv(exp(y(9)),T106,1)*getPowerDeriv(T562,1+params(6),1)));
  g1(117,10)=(-(getPowerDeriv(T562,1+params(6),1)*T109*exp(y(10))*getPowerDeriv(exp(y(10)),T106,1)));
  g1(118,15)=(-(T440/T525));
  g1(118,16)=(-((-(T440*T525))/(T525*T525)));
  g1(118,17)=T706*getPowerDeriv(T706,1+T119*params(25),1);
  g1(119,8)=(-(T420*(-(T1429*T1804))/(T1407*T1407)+T440*T1434*(T1407*params(5)*params(29)*T1804-params(5)*params(29)*T1407*T1804)/(T1407*T1407)));
  g1(119,11)=(-(T420*T1429/T1407+T420*T119*params(30)*T420/exp(y(49))*T1962/T1407));
  g1(119,13)=(-(T420*(-(T1429*T2114))/(T1407*T1407)+T440*T1434*(T1407*params(5)*params(29)*T2114-params(5)*params(29)*T1407*T2114)/(T1407*T1407)));
  g1(119,14)=(-(T440*T1433*T2145*getPowerDeriv(T445,T150,1)));
  g1(119,15)=T440-T440*T1433*T1434;
  g1(119,49)=(-(T420*T119*params(30)*T1962*(-(T420*exp(y(49))))/(exp(y(49))*exp(y(49)))/T1407));
  g1(120,8)=(-(T525*T529*(T1407*params(5)*params(29)*T1804-params(5)*params(29)*T1407*T1804)/(T1407*T1407)));
  g1(120,11)=(-(T420*(1+params(35)*exp(y(50)))/params(27)));
  g1(120,13)=(-(T525*T529*(T1407*params(5)*params(29)*T2114-params(5)*params(29)*T1407*T2114)/(T1407*T1407)));
  g1(120,14)=(-(T525*T1433*T2163));
  g1(120,16)=T525-T525*T529*T1433;
  g1(120,50)=(-(T420*params(35)*exp(y(50))/params(27)));
  g1(121,14)=params(29)*T2145*getPowerDeriv(T445,T170,1);
  g1(121,17)=(1-params(29))*T706*getPowerDeriv(T706,T170,1);
  g1(122,14)=(-(exp(y(36))*params(29)*T2145*getPowerDeriv(T445,T150,1)));
  g1(122,17)=(-((1-params(29))*T706*getPowerDeriv(T706,T150,1)));
  g1(122,18)=exp(y(18));
  g1(122,36)=(-(exp(y(36))*params(29)*T1434));
  g1(123,9)=(-exp(y(9)));
  g1(123,11)=T420;
  g1(123,12)=(-exp(y(12)));
  g1(123,24)=(-(1/params(33)*exp(y(24))));
  g1(124,11)=(-(exp(y(48))*params(7)*T420));
  g1(124,12)=exp(y(12));
  g1(124,48)=(-(exp(y(48))*params(7)*T420));
  g1(125,13)=(-(y(14)*T417/exp(y(38))));
  g1(125,14)=(-(T417/exp(y(38))));
  g1(125,21)=1;
  g1(125,38)=(-(y(14)*(-(T417*exp(y(38))))/(exp(y(38))*exp(y(38)))));
  g1(126,22)=(-((T1470*params(13)*T2598-params(13)*T1470*T2598)/(T1470*T1470)/y(28)));
  g1(126,27)=(-((T1470*params(13)*T2914-params(13)*T1470*T2914)/(T1470*T1470)/y(28)));
  g1(126,28)=(-((-(params(13)*T1470/T1470))/(y(28)*y(28))));
  g1(126,33)=(-1)/((1+y(33))*(1+y(33)));
  g1(127,22)=T843*T1476*getPowerDeriv(T1476,T226,1);
  g1(127,23)=T843*getPowerDeriv(T1476,T226,1)*(-(exp(y(23))*params(37)*T838))/(exp(y(23))*exp(y(23)));
  g1(127,27)=T843*T1476^T226;
  g1(128,13)=(-(T417*1/exp(y(20))))/(T417*T417);
  g1(128,20)=(-exp(y(20)))/(exp(y(20))*exp(y(20)))/T417;
  g1(128,22)=(-(T1483*getPowerDeriv(T1483,T226,1)));
  g1(128,24)=(-(getPowerDeriv(T1483,T226,1)*(-(exp(y(24))*params(38)*T838))/(exp(y(24))*exp(y(24)))));
  g1(129,22)=T838;
  g1(129,23)=(-(T237*exp(y(23))*getPowerDeriv(exp(y(23)),T238,1)*getPowerDeriv(T974,1+params(14),1)));
  g1(129,24)=(-(getPowerDeriv(T974,1+params(14),1)*T241*exp(y(24))*getPowerDeriv(exp(y(24)),T238,1)));
  g1(130,29)=(-(T864/T938));
  g1(130,30)=(-((-(T864*T938))/(T938*T938)));
  g1(130,31)=T1117*getPowerDeriv(T1117,1+T251*params(24),1);
  g1(131,22)=(-(T846*(-(T1493*T2598))/(T1470*T1470)+T864*T1498*(T1470*params(13)*params(28)*T2598-params(13)*params(28)*T1470*T2598)/(T1470*T1470)));
  g1(131,25)=(-(T846*T1493/T1470+T846*T251*params(36)*T846/exp(y(52))*T2759/T1470));
  g1(131,27)=(-(T846*(-(T1493*T2914))/(T1470*T1470)+T864*T1498*(T1470*params(13)*params(28)*T2914-params(13)*params(28)*T1470*T2914)/(T1470*T1470)));
  g1(131,28)=(-(T864*T1497*T2941*getPowerDeriv(T869,T282,1)));
  g1(131,29)=T864-T864*T1497*T1498;
  g1(131,52)=(-(T846*T251*params(36)*T2759*(-(T846*exp(y(52))))/(exp(y(52))*exp(y(52)))/T1470));
  g1(132,22)=(-(T938*T942*(T1470*params(13)*params(28)*T2598-params(13)*params(28)*T1470*T2598)/(T1470*T1470)));
  g1(132,25)=(-(T846*(1+params(40)*exp(y(53)))/params(26)));
  g1(132,27)=(-(T938*T942*(T1470*params(13)*params(28)*T2914-params(13)*params(28)*T1470*T2914)/(T1470*T1470)));
  g1(132,28)=(-(T938*T1497*T2959));
  g1(132,30)=T938-T938*T942*T1497;
  g1(132,53)=(-(T846*params(40)*exp(y(53))/params(26)));
  g1(133,28)=params(28)*T2941*getPowerDeriv(T869,T302,1);
  g1(133,31)=(1-params(28))*T1117*getPowerDeriv(T1117,T302,1);
  g1(134,28)=(-(exp(y(39))*params(28)*T2941*getPowerDeriv(T869,T282,1)));
  g1(134,31)=(-((1-params(28))*T1117*getPowerDeriv(T1117,T282,1)));
  g1(134,32)=exp(y(32));
  g1(134,39)=(-(exp(y(39))*params(28)*T1498));
  g1(135,10)=(-(params(33)*exp(y(10))));
  g1(135,23)=(-exp(y(23)));
  g1(135,25)=T846;
  g1(135,26)=(-exp(y(26)));
  g1(136,25)=(-(exp(y(51))*params(15)*T846));
  g1(136,26)=exp(y(26));
  g1(136,51)=(-(exp(y(51))*params(15)*T846));
  g1(137,27)=(-(y(28)*T843/exp(y(41))));
  g1(137,28)=(-(T843/exp(y(41))));
  g1(137,34)=1;
  g1(137,41)=(-(y(28)*(-(T843*exp(y(41))))/(exp(y(41))*exp(y(41)))));
  g1(138,8)=(-(params(51)*(-(params(50)*params(49)/exp(y(20))*T411*getPowerDeriv(T411,(-params(4)),1)))/(T1406*T1406)));
  g1(138,20)=(-(params(51)*params(50)*(-(params(49)*exp(y(20))))/(exp(y(20))*exp(y(20)))/T1406));
  g1(138,22)=params(48)*(-(params(47)*T838*getPowerDeriv(T838,(-params(12)),1)))/(T1469*T1469);
  g1(139,6)=1;
  g1(139,8)=T1801;
  g1(139,11)=exp(y(18))*params(30)*exp(y(49))^(-params(25))*T420*getPowerDeriv(T420,1+params(25),1)/(1+params(25));
  g1(139,18)=T1544;
  g1(139,49)=exp(y(18))*T579*params(30)*exp(y(49))*getPowerDeriv(exp(y(49)),(-params(25)),1)/(1+params(25));
  g1(140,7)=1;
  g1(140,22)=(-(T838*getPowerDeriv(T838,1-params(12),1)/(1-params(12))));
  g1(140,25)=exp(y(32))*params(36)*exp(y(52))^(-params(24))*T846*getPowerDeriv(T846,1+params(24),1)/(1+params(24));
  g1(140,32)=T1553;
  g1(140,52)=exp(y(32))*T991*params(36)*exp(y(52))*getPowerDeriv(exp(y(52)),(-params(24)),1)/(1+params(24));
  g1(141,48)=1-params(8);
  g1(142,49)=1-params(10);
  g1(143,50)=1-params(22);
  g1(144,51)=1-params(16);
  g1(145,52)=1-params(18);
  g1(146,53)=1-params(20);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],146,21316);
end
end
