function [residual, g1, g2, g3] = BBCDLmodelcomp_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           columns: equations in order of declaration
%                                                           rows: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(43, 1);
T15 = ((1+y(4))/(1+params(38)))^params(40);
T18 = y(29)/params(31);
T20 = T18^params(41);
T23 = (T18*T20)^(1-params(40));
T38 = ((1+y(11))/(1+params(39)))^params(42);
T41 = y(46)/params(36);
T43 = T41^params(43);
T46 = (T41*T43)^(1-params(42));
T60 = exp(y(23))^(1-params(1))/(1-params(1));
T74 = exp(y(64))^(-params(1))/exp(y(65));
T76 = exp(y(23))^(-params(1));
T79 = T76/exp(y(28));
T88 = exp(y(23))*params(28)/exp(y(24));
T91 = params(3)/(1+params(3));
T93 = exp(y(28))*T88^T91;
T99 = exp(y(35))/exp(y(45));
T104 = exp(y(23))*params(29)/exp(y(25));
T108 = 1/(1+params(3));
T114 = params(28)^T91*exp(y(24))^T108+params(29)^T91*exp(y(25))^T108;
T124 = 1+(1+params(24))/params(24)*params(22);
T133 = (1+params(24))/params(24)*params(27);
T135 = exp(y(26));
T138 = T135/exp(y(59));
T140 = T133*T138^params(22);
T146 = T74*params(2)*params(26)/T79;
T147 = params(31)/y(66);
T151 = (-(1+params(24)))/params(24)*(1+params(22));
T152 = T147^T151;
T167 = T147^(1-(1+params(24))/params(24));
T175 = (-1)/params(24);
T178 = params(31)/y(29);
T220 = exp(y(37))/exp(y(6));
T242 = exp(y(69))^(-params(9))/exp(y(70));
T246 = exp(y(40))^(-params(9));
T247 = T246/exp(y(45));
T256 = exp(y(40))*params(34)/exp(y(41));
T259 = params(11)/(1+params(11));
T261 = exp(y(45))*T256^T259;
T267 = exp(y(40))*params(35)/exp(y(42));
T271 = 1/(1+params(11));
T277 = params(34)^T259*exp(y(41))^T271+params(35)^T259*exp(y(42))^T271;
T287 = 1+(1+params(23))/params(23)*params(21);
T296 = (1+params(23))/params(23)*params(33);
T298 = exp(y(43));
T301 = T298/exp(y(62));
T303 = T296*T301^params(21);
T309 = T242*params(10)*params(25)/T247;
T310 = params(36)/y(71);
T314 = (-(1+params(23)))/params(23)*(1+params(21));
T315 = T310^T314;
T330 = T310^(1-(1+params(23))/params(23));
T338 = (-1)/params(23);
T341 = params(36)/y(46);
T379 = exp(y(54))/exp(y(13));
T398 = params(46)/exp(y(35))*params(47);
T409 = exp(y(35))/exp(y(5));
T417 = exp(y(52))/exp(y(12));
T426 = params(27)*exp(y(59))^(-params(22));
T427 = T135^(1+params(22));
T430 = exp(y(33))*T426*T427/(1+params(22));
T439 = params(33)*exp(y(62))^(-params(21));
T440 = T298^(1+params(21));
T443 = exp(y(50))*T439*T440/(1+params(21));
T497 = (-(exp(y(23))*getPowerDeriv(exp(y(23)),1-params(1),1)/(1-params(1))));
T499 = exp(y(23))*getPowerDeriv(exp(y(23)),(-params(1)),1);
T500 = T499/exp(y(28));
T519 = (-(T74*params(2)*params(26)*T500))/(T79*T79);
T534 = exp(y(64))*getPowerDeriv(exp(y(64)),(-params(1)),1);
T535 = T534/exp(y(65));
T541 = params(2)*params(26)*T535/T79;
T551 = (-(exp(y(23))*params(28)*exp(y(24))))/(exp(y(24))*exp(y(24)));
T552 = getPowerDeriv(T88,T91,1)*T551;
T556 = params(28)^T91*exp(y(24))*getPowerDeriv(exp(y(24)),T108,1);
T557 = getPowerDeriv(T114,1+params(3),1);
T564 = (-(exp(y(23))*params(29)*exp(y(25))))/(exp(y(25))*exp(y(25)));
T565 = getPowerDeriv(T104,T91,1)*T564;
T569 = params(29)^T91*exp(y(25))*getPowerDeriv(exp(y(25)),T108,1);
T577 = (-((-(y(29)*T135*exp(y(1))))/(exp(y(1))*exp(y(1)))));
T580 = T133*T138*getPowerDeriv(T138,params(22),1);
T583 = T135*T140/T79+T135*T580/T79;
T589 = T135*getPowerDeriv(T135,1+params(22),1);
T592 = exp(y(33))*T426*T589/(1+params(22));
T598 = (-(exp(y(28))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T600 = (-(y(29)*T598));
T603 = exp(y(28))*exp(y(28));
T604 = (-(T76*exp(y(28))))/T603;
T616 = (-(T74*params(2)*params(26)*T604))/(T79*T79);
T626 = (-(exp(y(28))*1/exp(y(35))));
T629 = (-(exp(y(64))^(-params(1))*exp(y(65))));
T631 = T629/(exp(y(65))*exp(y(65)));
T637 = params(2)*params(26)*T631/T79;
T644 = 1/params(31);
T646 = T644*getPowerDeriv(T18,params(41),1);
T653 = (1+params(38))*T15*(T20*T644+T18*T646)*getPowerDeriv(T18*T20,1-params(40),1);
T658 = (-params(31))/(y(29)*y(29));
T674 = (-params(31))/(y(66)*y(66));
T676 = T674*getPowerDeriv(T147,T151,1);
T680 = getPowerDeriv(T147,1-(1+params(24))/params(24),1);
T681 = T674*T680;
T691 = (-((-(exp(y(30))*exp(y(31))))/(exp(y(31))*exp(y(31)))));
T694 = exp(y(32))*getPowerDeriv(exp(y(32)),T124,1);
T706 = 1/(1+params(38))*getPowerDeriv((1+y(4))/(1+params(38)),params(40),1);
T716 = (-(exp(y(35))*exp(y(5))))/(exp(y(5))*exp(y(5)));
T724 = params(47)*(-(exp(y(35))*params(46)))/(exp(y(35))*exp(y(35)));
T737 = (-(exp(y(37))*exp(y(6))))/(exp(y(6))*exp(y(6)));
T742 = (-((-(exp(y(38))*exp(y(7))))/(exp(y(7))*exp(y(7)))));
T746 = exp(y(40))*getPowerDeriv(exp(y(40)),(-params(9)),1);
T747 = T746/exp(y(45));
T766 = (-(T242*params(10)*params(25)*T747))/(T247*T247);
T784 = exp(y(69))*getPowerDeriv(exp(y(69)),(-params(9)),1);
T785 = T784/exp(y(70));
T791 = params(10)*params(25)*T785/T247;
T801 = (-(exp(y(40))*params(34)*exp(y(41))))/(exp(y(41))*exp(y(41)));
T802 = getPowerDeriv(T256,T259,1)*T801;
T806 = params(34)^T259*exp(y(41))*getPowerDeriv(exp(y(41)),T271,1);
T807 = getPowerDeriv(T277,1+params(11),1);
T815 = (-(exp(y(42))*exp(y(40))*params(35)))/(exp(y(42))*exp(y(42)));
T816 = getPowerDeriv(T267,T259,1)*T815;
T820 = params(35)^T259*exp(y(42))*getPowerDeriv(exp(y(42)),T271,1);
T827 = (-((-(y(46)*T298*exp(y(8))))/(exp(y(8))*exp(y(8)))));
T830 = T296*T301*getPowerDeriv(T301,params(21),1);
T833 = T298*T303/T247+T298*T830/T247;
T839 = T298*getPowerDeriv(T298,1+params(21),1);
T842 = exp(y(50))*T439*T839/(1+params(21));
T848 = (-(exp(y(45))*exp(y(9))))/(exp(y(9))*exp(y(9)));
T850 = (-(y(46)*T848));
T853 = exp(y(45))*exp(y(45));
T854 = (-(exp(y(35))*exp(y(45))))/T853;
T857 = (-(exp(y(45))*T246))/T853;
T869 = (-(T242*params(10)*params(25)*T857))/(T247*T247);
T879 = (-(exp(y(69))^(-params(9))*exp(y(70))));
T881 = T879/(exp(y(70))*exp(y(70)));
T887 = params(10)*params(25)*T881/T247;
T894 = 1/params(36);
T896 = T894*getPowerDeriv(T41,params(43),1);
T903 = (1+params(39))*T38*(T43*T894+T41*T896)*getPowerDeriv(T41*T43,1-params(42),1);
T908 = (-params(36))/(y(46)*y(46));
T924 = (-params(36))/(y(71)*y(71));
T926 = T924*getPowerDeriv(T310,T314,1);
T930 = getPowerDeriv(T310,1-(1+params(23))/params(23),1);
T931 = T924*T930;
T941 = (-((-(exp(y(47))*exp(y(48))))/(exp(y(48))*exp(y(48)))));
T944 = exp(y(49))*getPowerDeriv(exp(y(49)),T287,1);
T956 = 1/(1+params(39))*getPowerDeriv((1+y(11))/(1+params(39)),params(42),1);
T966 = (-(exp(y(52))*exp(y(12))))/(exp(y(12))*exp(y(12)));
T980 = (-(exp(y(54))*exp(y(13))))/(exp(y(13))*exp(y(13)));
T985 = (-((-(exp(y(55))*exp(y(14))))/(exp(y(14))*exp(y(14)))));
T994 = (-(T135*exp(y(59))))/(exp(y(59))*exp(y(59)));
T995 = getPowerDeriv(T138,params(22),1)*T994;
T996 = T133*T995;
T1005 = exp(y(33))*T427*params(27)*exp(y(59))*getPowerDeriv(exp(y(59)),(-params(22)),1)/(1+params(22));
T1010 = (-(T135*params(32)*exp(y(60))/params(24)));
T1016 = (-(T298*exp(y(62))))/(exp(y(62))*exp(y(62)));
T1017 = getPowerDeriv(T301,params(21),1)*T1016;
T1018 = T296*T1017;
T1027 = exp(y(50))*T440*params(33)*exp(y(62))*getPowerDeriv(exp(y(62)),(-params(21)),1)/(1+params(21));
T1032 = (-(T298*params(37)*exp(y(63))/params(23)));
T1104 = (-((exp(y(23))*getPowerDeriv(exp(y(23)),1-params(1),1)+exp(y(23))*exp(y(23))*getPowerDeriv(exp(y(23)),1-params(1),2))/(1-params(1))));
T1108 = T499+exp(y(23))*exp(y(23))*getPowerDeriv(exp(y(23)),(-params(1)),2);
T1109 = T1108/exp(y(28));
T1130 = (T534+exp(y(64))*exp(y(64))*getPowerDeriv(exp(y(64)),(-params(1)),2))/exp(y(65));
T1137 = (-(exp(y(28))*T499))/T603;
T1156 = ((-(T76*exp(y(28))))*T603-(-(T76*exp(y(28))))*(T603+T603))/(T603*T603);
T1189 = (T629*exp(y(65))*exp(y(65))-T629*(exp(y(65))*exp(y(65))+exp(y(65))*exp(y(65))))/(exp(y(65))*exp(y(65))*exp(y(65))*exp(y(65)));
T1306 = (T79*T79*(-(T74*params(2)*params(26)*T1109))-(-(T74*params(2)*params(26)*T500))*(T79*T500+T79*T500))/(T79*T79*T79*T79);
T1350 = (T79*T79*(-(T74*params(2)*params(26)*T1137))-(-(T74*params(2)*params(26)*T604))*(T79*T500+T79*T500))/(T79*T79*T79*T79);
T1379 = (T79*T79*(-(T74*params(2)*params(26)*T1156))-(-(T74*params(2)*params(26)*T604))*(T79*T604+T79*T604))/(T79*T79*T79*T79);
T1391 = params(2)*params(26)*(-(exp(y(65))*T534))/(exp(y(65))*exp(y(65)))/T79;
T1578 = T746+exp(y(40))*exp(y(40))*getPowerDeriv(exp(y(40)),(-params(9)),2);
T1579 = T1578/exp(y(45));
T1600 = (T784+exp(y(69))*exp(y(69))*getPowerDeriv(exp(y(69)),(-params(9)),2))/exp(y(70));
T1607 = (-(exp(y(45))*T746))/T853;
T1624 = (T853*(-(exp(y(45))*T246))-(-(exp(y(45))*T246))*(T853+T853))/(T853*T853);
T1657 = (T879*exp(y(70))*exp(y(70))-T879*(exp(y(70))*exp(y(70))+exp(y(70))*exp(y(70))))/(exp(y(70))*exp(y(70))*exp(y(70))*exp(y(70)));
T1782 = (T247*T247*(-(T242*params(10)*params(25)*T1579))-(-(T242*params(10)*params(25)*T747))*(T247*T747+T247*T747))/(T247*T247*T247*T247);
T1826 = (T247*T247*(-(T242*params(10)*params(25)*T1607))-(-(T242*params(10)*params(25)*T857))*(T247*T747+T247*T747))/(T247*T247*T247*T247);
T1855 = (T247*T247*(-(T242*params(10)*params(25)*T1624))-(-(T242*params(10)*params(25)*T857))*(T247*T857+T247*T857))/(T247*T247*T247*T247);
T1867 = params(10)*params(25)*(-(exp(y(70))*T784))/(exp(y(70))*exp(y(70)))/T247;
lhs =y(34);
rhs =(1+params(38))*T15*T23*(1+x(it_, 7))-1;
residual(1)= lhs-rhs;
lhs =y(51);
rhs =(1+params(39))*T38*T46*(1+x(it_, 8))-1;
residual(2)= lhs-rhs;
lhs =y(57);
rhs =T60+params(2)*y(74);
residual(3)= lhs-rhs;
lhs =1/(1+y(34));
rhs =params(2)*T74/T79/y(66);
residual(4)= lhs-rhs;
lhs =T93;
rhs =1;
residual(5)= lhs-rhs;
lhs =T99;
rhs =T104^T91;
residual(6)= lhs-rhs;
lhs =exp(y(23));
rhs =T114^(1+params(3));
residual(7)= lhs-rhs;
lhs =exp(y(32))^T124;
rhs =exp(y(30))/exp(y(31));
residual(8)= lhs-rhs;
lhs =exp(y(30));
rhs =T135*T140/T79+T146*T152*exp(y(67));
residual(9)= lhs-rhs;
lhs =exp(y(31));
rhs =T135*(1+params(32)*exp(y(60)))/params(24)+T146*T167*exp(y(68));
residual(10)= lhs-rhs;
lhs =(1-params(26))*exp(y(32))^T175+params(26)*T178^T175;
rhs =1;
residual(11)= lhs-rhs;
lhs =exp(y(33));
rhs =(1-params(26))*exp(y(32))^T151+params(26)*T178^T151*exp(y(3));
residual(12)= lhs-rhs;
lhs =T135;
rhs =exp(y(24))+exp(y(27))+1/params(30)*exp(y(42));
residual(13)= lhs-rhs;
lhs =exp(y(27));
rhs =T135*params(4)*exp(y(58));
residual(14)= lhs-rhs;
lhs =y(36);
rhs =y(29)*exp(y(28))/exp(y(2));
residual(15)= lhs-rhs;
lhs =T220;
rhs =y(29)*T135/exp(y(1));
residual(16)= lhs-rhs;
lhs =y(36);
rhs =exp(y(38))/exp(y(7));
residual(17)= lhs-rhs;
lhs =1/(1+y(51));
rhs =params(10)*T242/T247/y(71);
residual(18)= lhs-rhs;
lhs =T261;
rhs =1;
residual(19)= lhs-rhs;
lhs =1/exp(y(35))/exp(y(28));
rhs =T267^T259;
residual(20)= lhs-rhs;
lhs =exp(y(40));
rhs =T277^(1+params(11));
residual(21)= lhs-rhs;
lhs =exp(y(49))^T287;
rhs =exp(y(47))/exp(y(48));
residual(22)= lhs-rhs;
lhs =exp(y(47));
rhs =T298*T303/T247+T309*T315*exp(y(72));
residual(23)= lhs-rhs;
lhs =exp(y(48));
rhs =T298*(1+params(37)*exp(y(63)))/params(23)+T309*T330*exp(y(73));
residual(24)= lhs-rhs;
lhs =(1-params(25))*exp(y(49))^T338+params(25)*T341^T338;
rhs =1;
residual(25)= lhs-rhs;
lhs =exp(y(50));
rhs =(1-params(25))*exp(y(49))^T314+params(25)*T341^T314*exp(y(10));
residual(26)= lhs-rhs;
lhs =T298;
rhs =exp(y(41))+exp(y(44))+exp(y(25))*params(30);
residual(27)= lhs-rhs;
lhs =exp(y(44));
rhs =T298*params(12)*exp(y(61));
residual(28)= lhs-rhs;
lhs =y(53);
rhs =y(46)*exp(y(45))/exp(y(9));
residual(29)= lhs-rhs;
lhs =T379;
rhs =y(46)*T298/exp(y(8));
residual(30)= lhs-rhs;
lhs =y(53);
rhs =exp(y(55))/exp(y(14));
residual(31)= lhs-rhs;
lhs =params(44)/T246*params(45);
rhs =T398/T76*params(48);
residual(32)= lhs-rhs;
lhs =exp(y(35));
rhs =1/exp(y(52));
residual(33)= lhs-rhs;
lhs =T409;
rhs =y(53)*exp(y(39))/y(36);
residual(34)= lhs-rhs;
lhs =T417;
rhs =y(36)*exp(y(56))/y(53);
residual(35)= lhs-rhs;
lhs =y(21);
rhs =T60-T430;
residual(36)= lhs-rhs;
lhs =y(22);
rhs =exp(y(40))^(1-params(9))/(1-params(9))-T443;
residual(37)= lhs-rhs;
lhs =y(58);
rhs =params(5)*y(15)+params(6)*x(it_, 1);
residual(38)= lhs-rhs;
lhs =y(59);
rhs =params(7)*y(16)+params(8)*x(it_, 2);
residual(39)= lhs-rhs;
lhs =y(60);
rhs =params(19)*y(17)+params(20)*x(it_, 6);
residual(40)= lhs-rhs;
lhs =y(61);
rhs =params(13)*y(18)+params(14)*x(it_, 3);
residual(41)= lhs-rhs;
lhs =y(62);
rhs =params(15)*y(19)+params(16)*x(it_, 4);
residual(42)= lhs-rhs;
lhs =y(63);
rhs =params(17)*y(20)+params(18)*x(it_, 5);
residual(43)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(43, 82);

  %
  % Jacobian matrix
  %

  g1(1,29)=(-((1+x(it_, 7))*T653));
  g1(1,4)=(-((1+x(it_, 7))*(1+params(38))*T23*T706));
  g1(1,34)=1;
  g1(1,81)=(-((1+params(38))*T15*T23));
  g1(2,46)=(-((1+x(it_, 8))*T903));
  g1(2,11)=(-((1+x(it_, 8))*(1+params(39))*T46*T956));
  g1(2,51)=1;
  g1(2,82)=(-((1+params(39))*T38*T46));
  g1(3,23)=T497;
  g1(3,57)=1;
  g1(3,74)=(-params(2));
  g1(4,23)=(-((-(params(2)*T74*T500))/(T79*T79)/y(66)));
  g1(4,64)=(-(params(2)*T535/T79/y(66)));
  g1(4,28)=(-((-(params(2)*T74*T604))/(T79*T79)/y(66)));
  g1(4,65)=(-(params(2)*T631/T79/y(66)));
  g1(4,66)=(-((-(params(2)*T74/T79))/(y(66)*y(66))));
  g1(4,34)=(-1)/((1+y(34))*(1+y(34)));
  g1(5,23)=exp(y(28))*T88*getPowerDeriv(T88,T91,1);
  g1(5,24)=exp(y(28))*T552;
  g1(5,28)=T93;
  g1(6,23)=(-(T104*getPowerDeriv(T104,T91,1)));
  g1(6,25)=(-T565);
  g1(6,35)=T99;
  g1(6,45)=T854;
  g1(7,23)=exp(y(23));
  g1(7,24)=(-(T556*T557));
  g1(7,25)=(-(T557*T569));
  g1(8,30)=(-(exp(y(30))/exp(y(31))));
  g1(8,31)=T691;
  g1(8,32)=T694;
  g1(9,23)=(-(T135*(-(T140*T500))/(T79*T79)+exp(y(67))*T152*T519));
  g1(9,64)=(-(exp(y(67))*T152*T541));
  g1(9,26)=(-T583);
  g1(9,28)=(-(T135*(-(T140*T604))/(T79*T79)+exp(y(67))*T152*T616));
  g1(9,65)=(-(exp(y(67))*T152*T637));
  g1(9,66)=(-(exp(y(67))*T146*T676));
  g1(9,30)=exp(y(30));
  g1(9,67)=(-(T146*T152*exp(y(67))));
  g1(9,59)=(-(T135*T996/T79));
  g1(10,23)=(-(exp(y(68))*T167*T519));
  g1(10,64)=(-(exp(y(68))*T167*T541));
  g1(10,26)=(-(T135*(1+params(32)*exp(y(60)))/params(24)));
  g1(10,28)=(-(exp(y(68))*T167*T616));
  g1(10,65)=(-(exp(y(68))*T167*T637));
  g1(10,66)=(-(exp(y(68))*T146*T681));
  g1(10,31)=exp(y(31));
  g1(10,68)=(-(T146*T167*exp(y(68))));
  g1(10,60)=T1010;
  g1(11,29)=params(26)*T658*getPowerDeriv(T178,T175,1);
  g1(11,32)=(1-params(26))*exp(y(32))*getPowerDeriv(exp(y(32)),T175,1);
  g1(12,29)=(-(exp(y(3))*params(26)*T658*getPowerDeriv(T178,T151,1)));
  g1(12,32)=(-((1-params(26))*exp(y(32))*getPowerDeriv(exp(y(32)),T151,1)));
  g1(12,3)=(-(params(26)*T178^T151*exp(y(3))));
  g1(12,33)=exp(y(33));
  g1(13,24)=(-exp(y(24)));
  g1(13,26)=T135;
  g1(13,27)=(-exp(y(27)));
  g1(13,42)=(-(1/params(30)*exp(y(42))));
  g1(14,26)=(-(T135*params(4)*exp(y(58))));
  g1(14,27)=exp(y(27));
  g1(14,58)=(-(T135*params(4)*exp(y(58))));
  g1(15,2)=T600;
  g1(15,28)=(-(y(29)*exp(y(28))/exp(y(2))));
  g1(15,29)=(-(exp(y(28))/exp(y(2))));
  g1(15,36)=1;
  g1(16,1)=T577;
  g1(16,26)=(-(y(29)*T135/exp(y(1))));
  g1(16,29)=(-(T135/exp(y(1))));
  g1(16,6)=T737;
  g1(16,37)=T220;
  g1(17,36)=1;
  g1(17,7)=T742;
  g1(17,38)=(-(exp(y(38))/exp(y(7))));
  g1(18,40)=(-((-(params(10)*T242*T747))/(T247*T247)/y(71)));
  g1(18,69)=(-(params(10)*T785/T247/y(71)));
  g1(18,45)=(-((-(params(10)*T242*T857))/(T247*T247)/y(71)));
  g1(18,70)=(-(params(10)*T881/T247/y(71)));
  g1(18,71)=(-((-(params(10)*T242/T247))/(y(71)*y(71))));
  g1(18,51)=(-1)/((1+y(51))*(1+y(51)));
  g1(19,40)=exp(y(45))*T256*getPowerDeriv(T256,T259,1);
  g1(19,41)=exp(y(45))*T802;
  g1(19,45)=T261;
  g1(20,28)=T626/T603;
  g1(20,35)=(-exp(y(35)))/(exp(y(35))*exp(y(35)))/exp(y(28));
  g1(20,40)=(-(T267*getPowerDeriv(T267,T259,1)));
  g1(20,42)=(-T816);
  g1(21,40)=exp(y(40));
  g1(21,41)=(-(T806*T807));
  g1(21,42)=(-(T807*T820));
  g1(22,47)=(-(exp(y(47))/exp(y(48))));
  g1(22,48)=T941;
  g1(22,49)=T944;
  g1(23,40)=(-(T298*(-(T303*T747))/(T247*T247)+exp(y(72))*T315*T766));
  g1(23,69)=(-(exp(y(72))*T315*T791));
  g1(23,43)=(-T833);
  g1(23,45)=(-(T298*(-(T303*T857))/(T247*T247)+exp(y(72))*T315*T869));
  g1(23,70)=(-(exp(y(72))*T315*T887));
  g1(23,71)=(-(exp(y(72))*T309*T926));
  g1(23,47)=exp(y(47));
  g1(23,72)=(-(T309*T315*exp(y(72))));
  g1(23,62)=(-(T298*T1018/T247));
  g1(24,40)=(-(exp(y(73))*T330*T766));
  g1(24,69)=(-(exp(y(73))*T330*T791));
  g1(24,43)=(-(T298*(1+params(37)*exp(y(63)))/params(23)));
  g1(24,45)=(-(exp(y(73))*T330*T869));
  g1(24,70)=(-(exp(y(73))*T330*T887));
  g1(24,71)=(-(exp(y(73))*T309*T931));
  g1(24,48)=exp(y(48));
  g1(24,73)=(-(T309*T330*exp(y(73))));
  g1(24,63)=T1032;
  g1(25,46)=params(25)*T908*getPowerDeriv(T341,T338,1);
  g1(25,49)=(1-params(25))*exp(y(49))*getPowerDeriv(exp(y(49)),T338,1);
  g1(26,46)=(-(exp(y(10))*params(25)*T908*getPowerDeriv(T341,T314,1)));
  g1(26,49)=(-((1-params(25))*exp(y(49))*getPowerDeriv(exp(y(49)),T314,1)));
  g1(26,10)=(-(params(25)*T341^T314*exp(y(10))));
  g1(26,50)=exp(y(50));
  g1(27,25)=(-(exp(y(25))*params(30)));
  g1(27,41)=(-exp(y(41)));
  g1(27,43)=T298;
  g1(27,44)=(-exp(y(44)));
  g1(28,43)=(-(T298*params(12)*exp(y(61))));
  g1(28,44)=exp(y(44));
  g1(28,61)=(-(T298*params(12)*exp(y(61))));
  g1(29,9)=T850;
  g1(29,45)=(-(y(46)*exp(y(45))/exp(y(9))));
  g1(29,46)=(-(exp(y(45))/exp(y(9))));
  g1(29,53)=1;
  g1(30,8)=T827;
  g1(30,43)=(-(y(46)*T298/exp(y(8))));
  g1(30,46)=(-(T298/exp(y(8))));
  g1(30,13)=T980;
  g1(30,54)=T379;
  g1(31,53)=1;
  g1(31,14)=T985;
  g1(31,55)=(-(exp(y(55))/exp(y(14))));
  g1(32,23)=(-(params(48)*(-(T398*T499))/(T76*T76)));
  g1(32,35)=(-(params(48)*T724/T76));
  g1(32,40)=params(45)*(-(params(44)*T746))/(T246*T246);
  g1(33,35)=exp(y(35));
  g1(33,52)=(-((-exp(y(52)))/(exp(y(52))*exp(y(52)))));
  g1(34,5)=T716;
  g1(34,35)=T409;
  g1(34,36)=(-((-(y(53)*exp(y(39))))/(y(36)*y(36))));
  g1(34,39)=(-(y(53)*exp(y(39))/y(36)));
  g1(34,53)=(-(exp(y(39))/y(36)));
  g1(35,36)=(-(exp(y(56))/y(53)));
  g1(35,12)=T966;
  g1(35,52)=T417;
  g1(35,53)=(-((-(y(36)*exp(y(56))))/(y(53)*y(53))));
  g1(35,56)=(-(y(36)*exp(y(56))/y(53)));
  g1(36,21)=1;
  g1(36,23)=T497;
  g1(36,26)=T592;
  g1(36,33)=T430;
  g1(36,59)=T1005;
  g1(37,22)=1;
  g1(37,40)=(-(exp(y(40))*getPowerDeriv(exp(y(40)),1-params(9),1)/(1-params(9))));
  g1(37,43)=T842;
  g1(37,50)=T443;
  g1(37,62)=T1027;
  g1(38,15)=(-params(5));
  g1(38,58)=1;
  g1(38,75)=(-params(6));
  g1(39,16)=(-params(7));
  g1(39,59)=1;
  g1(39,76)=(-params(8));
  g1(40,17)=(-params(19));
  g1(40,60)=1;
  g1(40,80)=(-params(20));
  g1(41,18)=(-params(13));
  g1(41,61)=1;
  g1(41,77)=(-params(14));
  g1(42,19)=(-params(15));
  g1(42,62)=1;
  g1(42,78)=(-params(16));
  g1(43,20)=(-params(17));
  g1(43,63)=1;
  g1(43,79)=(-params(18));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(436,3);
  v2(1,1)=1;
  v2(1,2)=2325;
  v2(1,3)=(-((1+x(it_, 7))*(1+params(38))*T15*(getPowerDeriv(T18*T20,1-params(40),1)*(T644*T646+T644*T646+T18*T644*T644*getPowerDeriv(T18,params(41),2))+(T20*T644+T18*T646)*(T20*T644+T18*T646)*getPowerDeriv(T18*T20,1-params(40),2))));
  v2(2,1)=1;
  v2(2,2)=275;
  v2(2,3)=(-((1+x(it_, 7))*(1+params(38))*(T20*T644+T18*T646)*getPowerDeriv(T18*T20,1-params(40),1)*T706));
  v2(3,1)=1;
  v2(3,2)=2300;
  v2(3,3)=  v2(2,3);
  v2(4,1)=1;
  v2(4,2)=250;
  v2(4,3)=(-((1+x(it_, 7))*(1+params(38))*T23*1/(1+params(38))*1/(1+params(38))*getPowerDeriv((1+y(4))/(1+params(38)),params(40),2)));
  v2(5,1)=1;
  v2(5,2)=6589;
  v2(5,3)=(-T653);
  v2(6,1)=1;
  v2(6,2)=2377;
  v2(6,3)=  v2(5,3);
  v2(7,1)=1;
  v2(7,2)=6564;
  v2(7,3)=(-((1+params(38))*T23*T706));
  v2(8,1)=1;
  v2(8,2)=327;
  v2(8,3)=  v2(7,3);
  v2(9,1)=2;
  v2(9,2)=3736;
  v2(9,3)=(-((1+x(it_, 8))*(1+params(39))*T38*(getPowerDeriv(T41*T43,1-params(42),1)*(T894*T896+T894*T896+T41*T894*T894*getPowerDeriv(T41,params(43),2))+(T43*T894+T41*T896)*(T43*T894+T41*T896)*getPowerDeriv(T41*T43,1-params(42),2))));
  v2(10,1)=2;
  v2(10,2)=866;
  v2(10,3)=(-((1+x(it_, 8))*(1+params(39))*(T43*T894+T41*T896)*getPowerDeriv(T41*T43,1-params(42),1)*T956));
  v2(11,1)=2;
  v2(11,2)=3701;
  v2(11,3)=  v2(10,3);
  v2(12,1)=2;
  v2(12,2)=831;
  v2(12,3)=(-((1+x(it_, 8))*(1+params(39))*T46*1/(1+params(39))*1/(1+params(39))*getPowerDeriv((1+y(11))/(1+params(39)),params(42),2)));
  v2(13,1)=2;
  v2(13,2)=6688;
  v2(13,3)=(-T903);
  v2(14,1)=2;
  v2(14,2)=3772;
  v2(14,3)=  v2(13,3);
  v2(15,1)=2;
  v2(15,2)=6653;
  v2(15,3)=(-((1+params(39))*T46*T956));
  v2(16,1)=2;
  v2(16,2)=902;
  v2(16,3)=  v2(15,3);
  v2(17,1)=3;
  v2(17,2)=1827;
  v2(17,3)=T1104;
  v2(18,1)=4;
  v2(18,2)=1827;
  v2(18,3)=(-((T79*T79*(-(params(2)*T74*T1109))-(-(params(2)*T74*T500))*(T79*T500+T79*T500))/(T79*T79*T79*T79)/y(66)));
  v2(19,1)=4;
  v2(19,2)=5189;
  v2(19,3)=(-((-(T500*params(2)*T535))/(T79*T79)/y(66)));
  v2(20,1)=4;
  v2(20,2)=1868;
  v2(20,3)=  v2(19,3);
  v2(21,1)=4;
  v2(21,2)=5230;
  v2(21,3)=(-(params(2)*T1130/T79/y(66)));
  v2(22,1)=4;
  v2(22,2)=2237;
  v2(22,3)=(-((T79*T79*(-(params(2)*T74*T1137))-(-(params(2)*T74*T604))*(T79*T500+T79*T500))/(T79*T79*T79*T79)/y(66)));
  v2(23,1)=4;
  v2(23,2)=1832;
  v2(23,3)=  v2(22,3);
  v2(24,1)=4;
  v2(24,2)=2278;
  v2(24,3)=(-((-(params(2)*T535*T604))/(T79*T79)/y(66)));
  v2(25,1)=4;
  v2(25,2)=5194;
  v2(25,3)=  v2(24,3);
  v2(26,1)=4;
  v2(26,2)=2242;
  v2(26,3)=(-((T79*T79*(-(params(2)*T74*T1156))-(-(params(2)*T74*T604))*(T79*T604+T79*T604))/(T79*T79*T79*T79)/y(66)));
  v2(27,1)=4;
  v2(27,2)=5271;
  v2(27,3)=(-((-(T500*params(2)*T631))/(T79*T79)/y(66)));
  v2(28,1)=4;
  v2(28,2)=1869;
  v2(28,3)=  v2(27,3);
  v2(29,1)=4;
  v2(29,2)=5312;
  v2(29,3)=(-(params(2)*(-(exp(y(65))*T534))/(exp(y(65))*exp(y(65)))/T79/y(66)));
  v2(30,1)=4;
  v2(30,2)=5231;
  v2(30,3)=  v2(29,3);
  v2(31,1)=4;
  v2(31,2)=5276;
  v2(31,3)=(-((-(T604*params(2)*T631))/(T79*T79)/y(66)));
  v2(32,1)=4;
  v2(32,2)=2279;
  v2(32,3)=  v2(31,3);
  v2(33,1)=4;
  v2(33,2)=5313;
  v2(33,3)=(-(params(2)*T1189/T79/y(66)));
  v2(34,1)=4;
  v2(34,2)=5353;
  v2(34,3)=(-((-((-(params(2)*T74*T500))/(T79*T79)))/(y(66)*y(66))));
  v2(35,1)=4;
  v2(35,2)=1870;
  v2(35,3)=  v2(34,3);
  v2(36,1)=4;
  v2(36,2)=5394;
  v2(36,3)=(-((-(params(2)*T535/T79))/(y(66)*y(66))));
  v2(37,1)=4;
  v2(37,2)=5232;
  v2(37,3)=  v2(36,3);
  v2(38,1)=4;
  v2(38,2)=5358;
  v2(38,3)=(-((-((-(params(2)*T74*T604))/(T79*T79)))/(y(66)*y(66))));
  v2(39,1)=4;
  v2(39,2)=2280;
  v2(39,3)=  v2(38,3);
  v2(40,1)=4;
  v2(40,2)=5395;
  v2(40,3)=(-((-(params(2)*T631/T79))/(y(66)*y(66))));
  v2(41,1)=4;
  v2(41,2)=5314;
  v2(41,3)=  v2(40,3);
  v2(42,1)=4;
  v2(42,2)=5396;
  v2(42,3)=(-((-((-(params(2)*T74/T79))*(y(66)+y(66))))/(y(66)*y(66)*y(66)*y(66))));
  v2(43,1)=4;
  v2(43,2)=2740;
  v2(43,3)=(1+y(34)+1+y(34))/((1+y(34))*(1+y(34))*(1+y(34))*(1+y(34)));
  v2(44,1)=5;
  v2(44,2)=1827;
  v2(44,3)=exp(y(28))*(T88*getPowerDeriv(T88,T91,1)+T88*T88*getPowerDeriv(T88,T91,2));
  v2(45,1)=5;
  v2(45,2)=1909;
  v2(45,3)=exp(y(28))*(T552+T551*T88*getPowerDeriv(T88,T91,2));
  v2(46,1)=5;
  v2(46,2)=1828;
  v2(46,3)=  v2(45,3);
  v2(47,1)=5;
  v2(47,2)=1910;
  v2(47,3)=exp(y(28))*(T551*T551*getPowerDeriv(T88,T91,2)+getPowerDeriv(T88,T91,1)*((-(exp(y(23))*params(28)*exp(y(24))))*exp(y(24))*exp(y(24))-(-(exp(y(23))*params(28)*exp(y(24))))*(exp(y(24))*exp(y(24))+exp(y(24))*exp(y(24))))/(exp(y(24))*exp(y(24))*exp(y(24))*exp(y(24))));
  v2(48,1)=5;
  v2(48,2)=2237;
  v2(48,3)=exp(y(28))*T88*getPowerDeriv(T88,T91,1);
  v2(49,1)=5;
  v2(49,2)=1832;
  v2(49,3)=  v2(48,3);
  v2(50,1)=5;
  v2(50,2)=2238;
  v2(50,3)=exp(y(28))*T552;
  v2(51,1)=5;
  v2(51,2)=1914;
  v2(51,3)=  v2(50,3);
  v2(52,1)=5;
  v2(52,2)=2242;
  v2(52,3)=T93;
  v2(53,1)=6;
  v2(53,2)=1827;
  v2(53,3)=(-(T104*getPowerDeriv(T104,T91,1)+T104*T104*getPowerDeriv(T104,T91,2)));
  v2(54,1)=6;
  v2(54,2)=1991;
  v2(54,3)=(-(T565+T564*T104*getPowerDeriv(T104,T91,2)));
  v2(55,1)=6;
  v2(55,2)=1829;
  v2(55,3)=  v2(54,3);
  v2(56,1)=6;
  v2(56,2)=1993;
  v2(56,3)=(-(T564*T564*getPowerDeriv(T104,T91,2)+getPowerDeriv(T104,T91,1)*((-(exp(y(23))*params(29)*exp(y(25))))*exp(y(25))*exp(y(25))-(-(exp(y(23))*params(29)*exp(y(25))))*(exp(y(25))*exp(y(25))+exp(y(25))*exp(y(25))))/(exp(y(25))*exp(y(25))*exp(y(25))*exp(y(25)))));
  v2(57,1)=6;
  v2(57,2)=2823;
  v2(57,3)=T99;
  v2(58,1)=6;
  v2(58,2)=3643;
  v2(58,3)=T854;
  v2(59,1)=6;
  v2(59,2)=2833;
  v2(59,3)=  v2(58,3);
  v2(60,1)=6;
  v2(60,2)=3653;
  v2(60,3)=((-(exp(y(35))*exp(y(45))))*T853-(-(exp(y(35))*exp(y(45))))*(T853+T853))/(T853*T853);
  v2(61,1)=7;
  v2(61,2)=1827;
  v2(61,3)=exp(y(23));
  v2(62,1)=7;
  v2(62,2)=1910;
  v2(62,3)=(-(T557*params(28)^T91*(exp(y(24))*getPowerDeriv(exp(y(24)),T108,1)+exp(y(24))*exp(y(24))*getPowerDeriv(exp(y(24)),T108,2))+T556*T556*getPowerDeriv(T114,1+params(3),2)));
  v2(63,1)=7;
  v2(63,2)=1992;
  v2(63,3)=(-(T569*T556*getPowerDeriv(T114,1+params(3),2)));
  v2(64,1)=7;
  v2(64,2)=1911;
  v2(64,3)=  v2(63,3);
  v2(65,1)=7;
  v2(65,2)=1993;
  v2(65,3)=(-(T569*T569*getPowerDeriv(T114,1+params(3),2)+T557*params(29)^T91*(exp(y(25))*getPowerDeriv(exp(y(25)),T108,1)+exp(y(25))*exp(y(25))*getPowerDeriv(exp(y(25)),T108,2))));
  v2(66,1)=8;
  v2(66,2)=2408;
  v2(66,3)=(-(exp(y(30))/exp(y(31))));
  v2(67,1)=8;
  v2(67,2)=2490;
  v2(67,3)=T691;
  v2(68,1)=8;
  v2(68,2)=2409;
  v2(68,3)=  v2(67,3);
  v2(69,1)=8;
  v2(69,2)=2491;
  v2(69,3)=(-(((-(exp(y(30))*exp(y(31))))*exp(y(31))*exp(y(31))-(-(exp(y(30))*exp(y(31))))*(exp(y(31))*exp(y(31))+exp(y(31))*exp(y(31))))/(exp(y(31))*exp(y(31))*exp(y(31))*exp(y(31)))));
  v2(70,1)=8;
  v2(70,2)=2574;
  v2(70,3)=T694+exp(y(32))*exp(y(32))*getPowerDeriv(exp(y(32)),T124,2);
  v2(71,1)=9;
  v2(71,2)=1827;
  v2(71,3)=(-(T135*(T79*T79*(-(T140*T1109))-(-(T140*T500))*(T79*T500+T79*T500))/(T79*T79*T79*T79)+exp(y(67))*T152*T1306));
  v2(72,1)=9;
  v2(72,2)=5189;
  v2(72,3)=(-(exp(y(67))*T152*(-(T500*params(2)*params(26)*T535))/(T79*T79)));
  v2(73,1)=9;
  v2(73,2)=1868;
  v2(73,3)=  v2(72,3);
  v2(74,1)=9;
  v2(74,2)=5230;
  v2(74,3)=(-(exp(y(67))*T152*params(2)*params(26)*T1130/T79));
  v2(75,1)=9;
  v2(75,2)=2073;
  v2(75,3)=(-(T135*(-(T140*T500))/(T79*T79)+T135*(-(T500*T580))/(T79*T79)));
  v2(76,1)=9;
  v2(76,2)=1830;
  v2(76,3)=  v2(75,3);
  v2(77,1)=9;
  v2(77,2)=2076;
  v2(77,3)=(-(T583+T135*T580/T79+T135*T133*(T138*getPowerDeriv(T138,params(22),1)+T138*T138*getPowerDeriv(T138,params(22),2))/T79));
  v2(78,1)=9;
  v2(78,2)=2237;
  v2(78,3)=(-(T135*(T79*T79*(-(T140*T1137))-(-(T140*T604))*(T79*T500+T79*T500))/(T79*T79*T79*T79)+exp(y(67))*T152*T1350));
  v2(79,1)=9;
  v2(79,2)=1832;
  v2(79,3)=  v2(78,3);
  v2(80,1)=9;
  v2(80,2)=2278;
  v2(80,3)=(-(exp(y(67))*T152*(-(params(2)*params(26)*T535*T604))/(T79*T79)));
  v2(81,1)=9;
  v2(81,2)=5194;
  v2(81,3)=  v2(80,3);
  v2(82,1)=9;
  v2(82,2)=2240;
  v2(82,3)=(-(T135*(-(T140*T604))/(T79*T79)+T135*(-(T580*T604))/(T79*T79)));
  v2(83,1)=9;
  v2(83,2)=2078;
  v2(83,3)=  v2(82,3);
  v2(84,1)=9;
  v2(84,2)=2242;
  v2(84,3)=(-(T135*(T79*T79*(-(T140*T1156))-(-(T140*T604))*(T79*T604+T79*T604))/(T79*T79*T79*T79)+exp(y(67))*T152*T1379));
  v2(85,1)=9;
  v2(85,2)=5271;
  v2(85,3)=(-(exp(y(67))*T152*(-(T500*params(2)*params(26)*T631))/(T79*T79)));
  v2(86,1)=9;
  v2(86,2)=1869;
  v2(86,3)=  v2(85,3);
  v2(87,1)=9;
  v2(87,2)=5312;
  v2(87,3)=(-(exp(y(67))*T152*T1391));
  v2(88,1)=9;
  v2(88,2)=5231;
  v2(88,3)=  v2(87,3);
  v2(89,1)=9;
  v2(89,2)=5276;
  v2(89,3)=(-(exp(y(67))*T152*(-(T604*params(2)*params(26)*T631))/(T79*T79)));
  v2(90,1)=9;
  v2(90,2)=2279;
  v2(90,3)=  v2(89,3);
  v2(91,1)=9;
  v2(91,2)=5313;
  v2(91,3)=(-(exp(y(67))*T152*params(2)*params(26)*T1189/T79));
  v2(92,1)=9;
  v2(92,2)=5353;
  v2(92,3)=(-(exp(y(67))*T519*T676));
  v2(93,1)=9;
  v2(93,2)=1870;
  v2(93,3)=  v2(92,3);
  v2(94,1)=9;
  v2(94,2)=5394;
  v2(94,3)=(-(exp(y(67))*T541*T676));
  v2(95,1)=9;
  v2(95,2)=5232;
  v2(95,3)=  v2(94,3);
  v2(96,1)=9;
  v2(96,2)=5358;
  v2(96,3)=(-(exp(y(67))*T616*T676));
  v2(97,1)=9;
  v2(97,2)=2280;
  v2(97,3)=  v2(96,3);
  v2(98,1)=9;
  v2(98,2)=5395;
  v2(98,3)=(-(exp(y(67))*T637*T676));
  v2(99,1)=9;
  v2(99,2)=5314;
  v2(99,3)=  v2(98,3);
  v2(100,1)=9;
  v2(100,2)=5396;
  v2(100,3)=(-(exp(y(67))*T146*(getPowerDeriv(T147,T151,1)*(-((-params(31))*(y(66)+y(66))))/(y(66)*y(66)*y(66)*y(66))+T674*T674*getPowerDeriv(T147,T151,2))));
  v2(101,1)=9;
  v2(101,2)=2408;
  v2(101,3)=exp(y(30));
  v2(102,1)=9;
  v2(102,2)=5435;
  v2(102,3)=(-(exp(y(67))*T152*T519));
  v2(103,1)=9;
  v2(103,2)=1871;
  v2(103,3)=  v2(102,3);
  v2(104,1)=9;
  v2(104,2)=5476;
  v2(104,3)=(-(exp(y(67))*T152*T541));
  v2(105,1)=9;
  v2(105,2)=5233;
  v2(105,3)=  v2(104,3);
  v2(106,1)=9;
  v2(106,2)=5440;
  v2(106,3)=(-(exp(y(67))*T152*T616));
  v2(107,1)=9;
  v2(107,2)=2281;
  v2(107,3)=  v2(106,3);
  v2(108,1)=9;
  v2(108,2)=5477;
  v2(108,3)=(-(exp(y(67))*T152*T637));
  v2(109,1)=9;
  v2(109,2)=5315;
  v2(109,3)=  v2(108,3);
  v2(110,1)=9;
  v2(110,2)=5478;
  v2(110,3)=(-(exp(y(67))*T146*T676));
  v2(111,1)=9;
  v2(111,2)=5397;
  v2(111,3)=  v2(110,3);
  v2(112,1)=9;
  v2(112,2)=5479;
  v2(112,3)=(-(T146*T152*exp(y(67))));
  v2(113,1)=9;
  v2(113,2)=4779;
  v2(113,3)=(-(T135*(-(T500*T996))/(T79*T79)));
  v2(114,1)=9;
  v2(114,2)=1863;
  v2(114,3)=  v2(113,3);
  v2(115,1)=9;
  v2(115,2)=4782;
  v2(115,3)=(-(T135*T996/T79+T135*T133*(T995+T994*T138*getPowerDeriv(T138,params(22),2))/T79));
  v2(116,1)=9;
  v2(116,2)=2109;
  v2(116,3)=  v2(115,3);
  v2(117,1)=9;
  v2(117,2)=4784;
  v2(117,3)=(-(T135*(-(T604*T996))/(T79*T79)));
  v2(118,1)=9;
  v2(118,2)=2273;
  v2(118,3)=  v2(117,3);
  v2(119,1)=9;
  v2(119,2)=4815;
  v2(119,3)=(-(T135*T133*(T994*T994*getPowerDeriv(T138,params(22),2)+getPowerDeriv(T138,params(22),1)*((-(T135*exp(y(59))))*exp(y(59))*exp(y(59))-(-(T135*exp(y(59))))*(exp(y(59))*exp(y(59))+exp(y(59))*exp(y(59))))/(exp(y(59))*exp(y(59))*exp(y(59))*exp(y(59))))/T79));
  v2(120,1)=10;
  v2(120,2)=1827;
  v2(120,3)=(-(exp(y(68))*T167*T1306));
  v2(121,1)=10;
  v2(121,2)=5189;
  v2(121,3)=(-(exp(y(68))*T167*(-(T500*params(2)*params(26)*T535))/(T79*T79)));
  v2(122,1)=10;
  v2(122,2)=1868;
  v2(122,3)=  v2(121,3);
  v2(123,1)=10;
  v2(123,2)=5230;
  v2(123,3)=(-(exp(y(68))*T167*params(2)*params(26)*T1130/T79));
  v2(124,1)=10;
  v2(124,2)=2076;
  v2(124,3)=(-(T135*(1+params(32)*exp(y(60)))/params(24)));
  v2(125,1)=10;
  v2(125,2)=2237;
  v2(125,3)=(-(exp(y(68))*T167*T1350));
  v2(126,1)=10;
  v2(126,2)=1832;
  v2(126,3)=  v2(125,3);
  v2(127,1)=10;
  v2(127,2)=2278;
  v2(127,3)=(-(exp(y(68))*T167*(-(params(2)*params(26)*T535*T604))/(T79*T79)));
  v2(128,1)=10;
  v2(128,2)=5194;
  v2(128,3)=  v2(127,3);
  v2(129,1)=10;
  v2(129,2)=2242;
  v2(129,3)=(-(exp(y(68))*T167*T1379));
  v2(130,1)=10;
  v2(130,2)=5271;
  v2(130,3)=(-(exp(y(68))*T167*(-(T500*params(2)*params(26)*T631))/(T79*T79)));
  v2(131,1)=10;
  v2(131,2)=1869;
  v2(131,3)=  v2(130,3);
  v2(132,1)=10;
  v2(132,2)=5312;
  v2(132,3)=(-(exp(y(68))*T167*T1391));
  v2(133,1)=10;
  v2(133,2)=5231;
  v2(133,3)=  v2(132,3);
  v2(134,1)=10;
  v2(134,2)=5276;
  v2(134,3)=(-(exp(y(68))*T167*(-(T604*params(2)*params(26)*T631))/(T79*T79)));
  v2(135,1)=10;
  v2(135,2)=2279;
  v2(135,3)=  v2(134,3);
  v2(136,1)=10;
  v2(136,2)=5313;
  v2(136,3)=(-(exp(y(68))*T167*params(2)*params(26)*T1189/T79));
  v2(137,1)=10;
  v2(137,2)=5353;
  v2(137,3)=(-(exp(y(68))*T519*T681));
  v2(138,1)=10;
  v2(138,2)=1870;
  v2(138,3)=  v2(137,3);
  v2(139,1)=10;
  v2(139,2)=5394;
  v2(139,3)=(-(exp(y(68))*T541*T681));
  v2(140,1)=10;
  v2(140,2)=5232;
  v2(140,3)=  v2(139,3);
  v2(141,1)=10;
  v2(141,2)=5358;
  v2(141,3)=(-(exp(y(68))*T616*T681));
  v2(142,1)=10;
  v2(142,2)=2280;
  v2(142,3)=  v2(141,3);
  v2(143,1)=10;
  v2(143,2)=5395;
  v2(143,3)=(-(exp(y(68))*T637*T681));
  v2(144,1)=10;
  v2(144,2)=5314;
  v2(144,3)=  v2(143,3);
  v2(145,1)=10;
  v2(145,2)=5396;
  v2(145,3)=(-(exp(y(68))*T146*(T680*(-((-params(31))*(y(66)+y(66))))/(y(66)*y(66)*y(66)*y(66))+T674*T674*getPowerDeriv(T147,1-(1+params(24))/params(24),2))));
  v2(146,1)=10;
  v2(146,2)=2491;
  v2(146,3)=exp(y(31));
  v2(147,1)=10;
  v2(147,2)=5517;
  v2(147,3)=(-(exp(y(68))*T167*T519));
  v2(148,1)=10;
  v2(148,2)=1872;
  v2(148,3)=  v2(147,3);
  v2(149,1)=10;
  v2(149,2)=5558;
  v2(149,3)=(-(exp(y(68))*T167*T541));
  v2(150,1)=10;
  v2(150,2)=5234;
  v2(150,3)=  v2(149,3);
  v2(151,1)=10;
  v2(151,2)=5522;
  v2(151,3)=(-(exp(y(68))*T167*T616));
  v2(152,1)=10;
  v2(152,2)=2282;
  v2(152,3)=  v2(151,3);
  v2(153,1)=10;
  v2(153,2)=5559;
  v2(153,3)=(-(exp(y(68))*T167*T637));
  v2(154,1)=10;
  v2(154,2)=5316;
  v2(154,3)=  v2(153,3);
  v2(155,1)=10;
  v2(155,2)=5560;
  v2(155,3)=(-(exp(y(68))*T146*T681));
  v2(156,1)=10;
  v2(156,2)=5398;
  v2(156,3)=  v2(155,3);
  v2(157,1)=10;
  v2(157,2)=5562;
  v2(157,3)=(-(T146*T167*exp(y(68))));
  v2(158,1)=10;
  v2(158,2)=4864;
  v2(158,3)=T1010;
  v2(159,1)=10;
  v2(159,2)=2110;
  v2(159,3)=  v2(158,3);
  v2(160,1)=10;
  v2(160,2)=4898;
  v2(160,3)=T1010;
  v2(161,1)=11;
  v2(161,2)=2325;
  v2(161,3)=params(26)*(getPowerDeriv(T178,T175,1)*(-((-params(31))*(y(29)+y(29))))/(y(29)*y(29)*y(29)*y(29))+T658*T658*getPowerDeriv(T178,T175,2));
  v2(162,1)=11;
  v2(162,2)=2574;
  v2(162,3)=(1-params(26))*(exp(y(32))*getPowerDeriv(exp(y(32)),T175,1)+exp(y(32))*exp(y(32))*getPowerDeriv(exp(y(32)),T175,2));
  v2(163,1)=12;
  v2(163,2)=2325;
  v2(163,3)=(-(exp(y(3))*params(26)*(getPowerDeriv(T178,T151,1)*(-((-params(31))*(y(29)+y(29))))/(y(29)*y(29)*y(29)*y(29))+T658*T658*getPowerDeriv(T178,T151,2))));
  v2(164,1)=12;
  v2(164,2)=2574;
  v2(164,3)=(-((1-params(26))*(exp(y(32))*getPowerDeriv(exp(y(32)),T151,1)+exp(y(32))*exp(y(32))*getPowerDeriv(exp(y(32)),T151,2))));
  v2(165,1)=12;
  v2(165,2)=193;
  v2(165,3)=(-(exp(y(3))*params(26)*T658*getPowerDeriv(T178,T151,1)));
  v2(166,1)=12;
  v2(166,2)=2299;
  v2(166,3)=  v2(165,3);
  v2(167,1)=12;
  v2(167,2)=167;
  v2(167,3)=(-(params(26)*T178^T151*exp(y(3))));
  v2(168,1)=12;
  v2(168,2)=2657;
  v2(168,3)=exp(y(33));
  v2(169,1)=13;
  v2(169,2)=1910;
  v2(169,3)=(-exp(y(24)));
  v2(170,1)=13;
  v2(170,2)=2076;
  v2(170,3)=T135;
  v2(171,1)=13;
  v2(171,2)=2159;
  v2(171,3)=(-exp(y(27)));
  v2(172,1)=13;
  v2(172,2)=3404;
  v2(172,3)=(-(1/params(30)*exp(y(42))));
  v2(173,1)=14;
  v2(173,2)=2076;
  v2(173,3)=(-(T135*params(4)*exp(y(58))));
  v2(174,1)=14;
  v2(174,2)=2159;
  v2(174,3)=exp(y(27));
  v2(175,1)=14;
  v2(175,2)=4700;
  v2(175,3)=(-(T135*params(4)*exp(y(58))));
  v2(176,1)=14;
  v2(176,2)=2108;
  v2(176,3)=  v2(175,3);
  v2(177,1)=14;
  v2(177,2)=4732;
  v2(177,3)=(-(T135*params(4)*exp(y(58))));
  v2(178,1)=15;
  v2(178,2)=84;
  v2(178,3)=(-(y(29)*((-(exp(y(28))*exp(y(2))))*exp(y(2))*exp(y(2))-(-(exp(y(28))*exp(y(2))))*(exp(y(2))*exp(y(2))+exp(y(2))*exp(y(2))))/(exp(y(2))*exp(y(2))*exp(y(2))*exp(y(2)))));
  v2(179,1)=15;
  v2(179,2)=2216;
  v2(179,3)=T600;
  v2(180,1)=15;
  v2(180,2)=110;
  v2(180,3)=  v2(179,3);
  v2(181,1)=15;
  v2(181,2)=2242;
  v2(181,3)=(-(y(29)*exp(y(28))/exp(y(2))));
  v2(182,1)=15;
  v2(182,2)=2298;
  v2(182,3)=(-T598);
  v2(183,1)=15;
  v2(183,2)=111;
  v2(183,3)=  v2(182,3);
  v2(184,1)=15;
  v2(184,2)=2324;
  v2(184,3)=(-(exp(y(28))/exp(y(2))));
  v2(185,1)=15;
  v2(185,2)=2243;
  v2(185,3)=  v2(184,3);
  v2(186,1)=16;
  v2(186,2)=1;
  v2(186,3)=(-(((-(y(29)*T135*exp(y(1))))*exp(y(1))*exp(y(1))-(-(y(29)*T135*exp(y(1))))*(exp(y(1))*exp(y(1))+exp(y(1))*exp(y(1))))/(exp(y(1))*exp(y(1))*exp(y(1))*exp(y(1)))));
  v2(187,1)=16;
  v2(187,2)=2051;
  v2(187,3)=T577;
  v2(188,1)=16;
  v2(188,2)=26;
  v2(188,3)=  v2(187,3);
  v2(189,1)=16;
  v2(189,2)=2076;
  v2(189,3)=(-(y(29)*T135/exp(y(1))));
  v2(190,1)=16;
  v2(190,2)=2297;
  v2(190,3)=(-((-(T135*exp(y(1))))/(exp(y(1))*exp(y(1)))));
  v2(191,1)=16;
  v2(191,2)=29;
  v2(191,3)=  v2(190,3);
  v2(192,1)=16;
  v2(192,2)=2322;
  v2(192,3)=(-(T135/exp(y(1))));
  v2(193,1)=16;
  v2(193,2)=2079;
  v2(193,3)=  v2(192,3);
  v2(194,1)=16;
  v2(194,2)=416;
  v2(194,3)=((-(exp(y(37))*exp(y(6))))*exp(y(6))*exp(y(6))-(-(exp(y(37))*exp(y(6))))*(exp(y(6))*exp(y(6))+exp(y(6))*exp(y(6))))/(exp(y(6))*exp(y(6))*exp(y(6))*exp(y(6)));
  v2(195,1)=16;
  v2(195,2)=2958;
  v2(195,3)=T737;
  v2(196,1)=16;
  v2(196,2)=447;
  v2(196,3)=  v2(195,3);
  v2(197,1)=16;
  v2(197,2)=2989;
  v2(197,3)=T220;
  v2(198,1)=17;
  v2(198,2)=499;
  v2(198,3)=(-(((-(exp(y(38))*exp(y(7))))*exp(y(7))*exp(y(7))-(-(exp(y(38))*exp(y(7))))*(exp(y(7))*exp(y(7))+exp(y(7))*exp(y(7))))/(exp(y(7))*exp(y(7))*exp(y(7))*exp(y(7)))));
  v2(199,1)=17;
  v2(199,2)=3041;
  v2(199,3)=T742;
  v2(200,1)=17;
  v2(200,2)=530;
  v2(200,3)=  v2(199,3);
  v2(201,1)=17;
  v2(201,2)=3072;
  v2(201,3)=(-(exp(y(38))/exp(y(7))));
  v2(202,1)=18;
  v2(202,2)=3238;
  v2(202,3)=(-((T247*T247*(-(params(10)*T242*T1579))-(-(params(10)*T242*T747))*(T247*T747+T247*T747))/(T247*T247*T247*T247)/y(71)));
  v2(203,1)=18;
  v2(203,2)=5616;
  v2(203,3)=(-((-(T747*params(10)*T785))/(T247*T247)/y(71)));
  v2(204,1)=18;
  v2(204,2)=3267;
  v2(204,3)=  v2(203,3);
  v2(205,1)=18;
  v2(205,2)=5645;
  v2(205,3)=(-(params(10)*T1600/T247/y(71)));
  v2(206,1)=18;
  v2(206,2)=3648;
  v2(206,3)=(-((T247*T247*(-(params(10)*T242*T1607))-(-(params(10)*T242*T857))*(T247*T747+T247*T747))/(T247*T247*T247*T247)/y(71)));
  v2(207,1)=18;
  v2(207,2)=3243;
  v2(207,3)=  v2(206,3);
  v2(208,1)=18;
  v2(208,2)=3677;
  v2(208,3)=(-((-(params(10)*T785*T857))/(T247*T247)/y(71)));
  v2(209,1)=18;
  v2(209,2)=5621;
  v2(209,3)=  v2(208,3);
  v2(210,1)=18;
  v2(210,2)=3653;
  v2(210,3)=(-((T247*T247*(-(params(10)*T242*T1624))-(-(params(10)*T242*T857))*(T247*T857+T247*T857))/(T247*T247*T247*T247)/y(71)));
  v2(211,1)=18;
  v2(211,2)=5698;
  v2(211,3)=(-((-(T747*params(10)*T881))/(T247*T247)/y(71)));
  v2(212,1)=18;
  v2(212,2)=3268;
  v2(212,3)=  v2(211,3);
  v2(213,1)=18;
  v2(213,2)=5727;
  v2(213,3)=(-(params(10)*(-(exp(y(70))*T784))/(exp(y(70))*exp(y(70)))/T247/y(71)));
  v2(214,1)=18;
  v2(214,2)=5646;
  v2(214,3)=  v2(213,3);
  v2(215,1)=18;
  v2(215,2)=5703;
  v2(215,3)=(-((-(T857*params(10)*T881))/(T247*T247)/y(71)));
  v2(216,1)=18;
  v2(216,2)=3678;
  v2(216,3)=  v2(215,3);
  v2(217,1)=18;
  v2(217,2)=5728;
  v2(217,3)=(-(params(10)*T1657/T247/y(71)));
  v2(218,1)=18;
  v2(218,2)=5780;
  v2(218,3)=(-((-((-(params(10)*T242*T747))/(T247*T247)))/(y(71)*y(71))));
  v2(219,1)=18;
  v2(219,2)=3269;
  v2(219,3)=  v2(218,3);
  v2(220,1)=18;
  v2(220,2)=5809;
  v2(220,3)=(-((-(params(10)*T785/T247))/(y(71)*y(71))));
  v2(221,1)=18;
  v2(221,2)=5647;
  v2(221,3)=  v2(220,3);
  v2(222,1)=18;
  v2(222,2)=5785;
  v2(222,3)=(-((-((-(params(10)*T242*T857))/(T247*T247)))/(y(71)*y(71))));
  v2(223,1)=18;
  v2(223,2)=3679;
  v2(223,3)=  v2(222,3);
  v2(224,1)=18;
  v2(224,2)=5810;
  v2(224,3)=(-((-(params(10)*T881/T247))/(y(71)*y(71))));
  v2(225,1)=18;
  v2(225,2)=5729;
  v2(225,3)=  v2(224,3);
  v2(226,1)=18;
  v2(226,2)=5811;
  v2(226,3)=(-((-((-(params(10)*T242/T247))*(y(71)+y(71))))/(y(71)*y(71)*y(71)*y(71))));
  v2(227,1)=18;
  v2(227,2)=4151;
  v2(227,3)=(1+y(51)+1+y(51))/((1+y(51))*(1+y(51))*(1+y(51))*(1+y(51)));
  v2(228,1)=19;
  v2(228,2)=3238;
  v2(228,3)=exp(y(45))*(T256*getPowerDeriv(T256,T259,1)+T256*T256*getPowerDeriv(T256,T259,2));
  v2(229,1)=19;
  v2(229,2)=3320;
  v2(229,3)=exp(y(45))*(T802+T801*T256*getPowerDeriv(T256,T259,2));
  v2(230,1)=19;
  v2(230,2)=3239;
  v2(230,3)=  v2(229,3);
  v2(231,1)=19;
  v2(231,2)=3321;
  v2(231,3)=exp(y(45))*(T801*T801*getPowerDeriv(T256,T259,2)+getPowerDeriv(T256,T259,1)*((-(exp(y(40))*params(34)*exp(y(41))))*exp(y(41))*exp(y(41))-(-(exp(y(40))*params(34)*exp(y(41))))*(exp(y(41))*exp(y(41))+exp(y(41))*exp(y(41))))/(exp(y(41))*exp(y(41))*exp(y(41))*exp(y(41))));
  v2(232,1)=19;
  v2(232,2)=3648;
  v2(232,3)=exp(y(45))*T256*getPowerDeriv(T256,T259,1);
  v2(233,1)=19;
  v2(233,2)=3243;
  v2(233,3)=  v2(232,3);
  v2(234,1)=19;
  v2(234,2)=3649;
  v2(234,3)=exp(y(45))*T802;
  v2(235,1)=19;
  v2(235,2)=3325;
  v2(235,3)=  v2(234,3);
  v2(236,1)=19;
  v2(236,2)=3653;
  v2(236,3)=T261;
  v2(237,1)=20;
  v2(237,2)=2242;
  v2(237,3)=(T603*T626-T626*(T603+T603))/(T603*T603);
  v2(238,1)=20;
  v2(238,2)=2816;
  v2(238,3)=(-(exp(y(28))*(-exp(y(35)))/(exp(y(35))*exp(y(35)))))/T603;
  v2(239,1)=20;
  v2(239,2)=2249;
  v2(239,3)=  v2(238,3);
  v2(240,1)=20;
  v2(240,2)=2823;
  v2(240,3)=((-exp(y(35)))*exp(y(35))*exp(y(35))-(-exp(y(35)))*(exp(y(35))*exp(y(35))+exp(y(35))*exp(y(35))))/(exp(y(35))*exp(y(35))*exp(y(35))*exp(y(35)))/exp(y(28));
  v2(241,1)=20;
  v2(241,2)=3238;
  v2(241,3)=(-(T267*getPowerDeriv(T267,T259,1)+T267*T267*getPowerDeriv(T267,T259,2)));
  v2(242,1)=20;
  v2(242,2)=3402;
  v2(242,3)=(-(T816+T815*T267*getPowerDeriv(T267,T259,2)));
  v2(243,1)=20;
  v2(243,2)=3240;
  v2(243,3)=  v2(242,3);
  v2(244,1)=20;
  v2(244,2)=3404;
  v2(244,3)=(-(T815*T815*getPowerDeriv(T267,T259,2)+getPowerDeriv(T267,T259,1)*((-(exp(y(42))*exp(y(40))*params(35)))*exp(y(42))*exp(y(42))-(-(exp(y(42))*exp(y(40))*params(35)))*(exp(y(42))*exp(y(42))+exp(y(42))*exp(y(42))))/(exp(y(42))*exp(y(42))*exp(y(42))*exp(y(42)))));
  v2(245,1)=21;
  v2(245,2)=3238;
  v2(245,3)=exp(y(40));
  v2(246,1)=21;
  v2(246,2)=3321;
  v2(246,3)=(-(T807*params(34)^T259*(exp(y(41))*getPowerDeriv(exp(y(41)),T271,1)+exp(y(41))*exp(y(41))*getPowerDeriv(exp(y(41)),T271,2))+T806*T806*getPowerDeriv(T277,1+params(11),2)));
  v2(247,1)=21;
  v2(247,2)=3403;
  v2(247,3)=(-(T820*T806*getPowerDeriv(T277,1+params(11),2)));
  v2(248,1)=21;
  v2(248,2)=3322;
  v2(248,3)=  v2(247,3);
  v2(249,1)=21;
  v2(249,2)=3404;
  v2(249,3)=(-(T820*T820*getPowerDeriv(T277,1+params(11),2)+T807*params(35)^T259*(exp(y(42))*getPowerDeriv(exp(y(42)),T271,1)+exp(y(42))*exp(y(42))*getPowerDeriv(exp(y(42)),T271,2))));
  v2(250,1)=22;
  v2(250,2)=3819;
  v2(250,3)=(-(exp(y(47))/exp(y(48))));
  v2(251,1)=22;
  v2(251,2)=3901;
  v2(251,3)=T941;
  v2(252,1)=22;
  v2(252,2)=3820;
  v2(252,3)=  v2(251,3);
  v2(253,1)=22;
  v2(253,2)=3902;
  v2(253,3)=(-(((-(exp(y(47))*exp(y(48))))*exp(y(48))*exp(y(48))-(-(exp(y(47))*exp(y(48))))*(exp(y(48))*exp(y(48))+exp(y(48))*exp(y(48))))/(exp(y(48))*exp(y(48))*exp(y(48))*exp(y(48)))));
  v2(254,1)=22;
  v2(254,2)=3985;
  v2(254,3)=T944+exp(y(49))*exp(y(49))*getPowerDeriv(exp(y(49)),T287,2);
  v2(255,1)=23;
  v2(255,2)=3238;
  v2(255,3)=(-(T298*(T247*T247*(-(T303*T1579))-(-(T303*T747))*(T247*T747+T247*T747))/(T247*T247*T247*T247)+exp(y(72))*T315*T1782));
  v2(256,1)=23;
  v2(256,2)=5616;
  v2(256,3)=(-(exp(y(72))*T315*(-(T747*params(10)*params(25)*T785))/(T247*T247)));
  v2(257,1)=23;
  v2(257,2)=3267;
  v2(257,3)=  v2(256,3);
  v2(258,1)=23;
  v2(258,2)=5645;
  v2(258,3)=(-(exp(y(72))*T315*params(10)*params(25)*T1600/T247));
  v2(259,1)=23;
  v2(259,2)=3484;
  v2(259,3)=(-(T298*(-(T303*T747))/(T247*T247)+T298*(-(T747*T830))/(T247*T247)));
  v2(260,1)=23;
  v2(260,2)=3241;
  v2(260,3)=  v2(259,3);
  v2(261,1)=23;
  v2(261,2)=3487;
  v2(261,3)=(-(T833+T298*T830/T247+T298*T296*(T301*getPowerDeriv(T301,params(21),1)+T301*T301*getPowerDeriv(T301,params(21),2))/T247));
  v2(262,1)=23;
  v2(262,2)=3648;
  v2(262,3)=(-(T298*(T247*T247*(-(T303*T1607))-(-(T303*T857))*(T247*T747+T247*T747))/(T247*T247*T247*T247)+exp(y(72))*T315*T1826));
  v2(263,1)=23;
  v2(263,2)=3243;
  v2(263,3)=  v2(262,3);
  v2(264,1)=23;
  v2(264,2)=3677;
  v2(264,3)=(-(exp(y(72))*T315*(-(params(10)*params(25)*T785*T857))/(T247*T247)));
  v2(265,1)=23;
  v2(265,2)=5621;
  v2(265,3)=  v2(264,3);
  v2(266,1)=23;
  v2(266,2)=3651;
  v2(266,3)=(-(T298*(-(T303*T857))/(T247*T247)+T298*(-(T830*T857))/(T247*T247)));
  v2(267,1)=23;
  v2(267,2)=3489;
  v2(267,3)=  v2(266,3);
  v2(268,1)=23;
  v2(268,2)=3653;
  v2(268,3)=(-(T298*(T247*T247*(-(T303*T1624))-(-(T303*T857))*(T247*T857+T247*T857))/(T247*T247*T247*T247)+exp(y(72))*T315*T1855));
  v2(269,1)=23;
  v2(269,2)=5698;
  v2(269,3)=(-(exp(y(72))*T315*(-(T747*params(10)*params(25)*T881))/(T247*T247)));
  v2(270,1)=23;
  v2(270,2)=3268;
  v2(270,3)=  v2(269,3);
  v2(271,1)=23;
  v2(271,2)=5727;
  v2(271,3)=(-(exp(y(72))*T315*T1867));
  v2(272,1)=23;
  v2(272,2)=5646;
  v2(272,3)=  v2(271,3);
  v2(273,1)=23;
  v2(273,2)=5703;
  v2(273,3)=(-(exp(y(72))*T315*(-(T857*params(10)*params(25)*T881))/(T247*T247)));
  v2(274,1)=23;
  v2(274,2)=3678;
  v2(274,3)=  v2(273,3);
  v2(275,1)=23;
  v2(275,2)=5728;
  v2(275,3)=(-(exp(y(72))*T315*params(10)*params(25)*T1657/T247));
  v2(276,1)=23;
  v2(276,2)=5780;
  v2(276,3)=(-(exp(y(72))*T766*T926));
  v2(277,1)=23;
  v2(277,2)=3269;
  v2(277,3)=  v2(276,3);
  v2(278,1)=23;
  v2(278,2)=5809;
  v2(278,3)=(-(exp(y(72))*T791*T926));
  v2(279,1)=23;
  v2(279,2)=5647;
  v2(279,3)=  v2(278,3);
  v2(280,1)=23;
  v2(280,2)=5785;
  v2(280,3)=(-(exp(y(72))*T869*T926));
  v2(281,1)=23;
  v2(281,2)=3679;
  v2(281,3)=  v2(280,3);
  v2(282,1)=23;
  v2(282,2)=5810;
  v2(282,3)=(-(exp(y(72))*T887*T926));
  v2(283,1)=23;
  v2(283,2)=5729;
  v2(283,3)=  v2(282,3);
  v2(284,1)=23;
  v2(284,2)=5811;
  v2(284,3)=(-(exp(y(72))*T309*(getPowerDeriv(T310,T314,1)*(-((-params(36))*(y(71)+y(71))))/(y(71)*y(71)*y(71)*y(71))+T924*T924*getPowerDeriv(T310,T314,2))));
  v2(285,1)=23;
  v2(285,2)=3819;
  v2(285,3)=exp(y(47));
  v2(286,1)=23;
  v2(286,2)=5862;
  v2(286,3)=(-(exp(y(72))*T315*T766));
  v2(287,1)=23;
  v2(287,2)=3270;
  v2(287,3)=  v2(286,3);
  v2(288,1)=23;
  v2(288,2)=5891;
  v2(288,3)=(-(exp(y(72))*T315*T791));
  v2(289,1)=23;
  v2(289,2)=5648;
  v2(289,3)=  v2(288,3);
  v2(290,1)=23;
  v2(290,2)=5867;
  v2(290,3)=(-(exp(y(72))*T315*T869));
  v2(291,1)=23;
  v2(291,2)=3680;
  v2(291,3)=  v2(290,3);
  v2(292,1)=23;
  v2(292,2)=5892;
  v2(292,3)=(-(exp(y(72))*T315*T887));
  v2(293,1)=23;
  v2(293,2)=5730;
  v2(293,3)=  v2(292,3);
  v2(294,1)=23;
  v2(294,2)=5893;
  v2(294,3)=(-(exp(y(72))*T309*T926));
  v2(295,1)=23;
  v2(295,2)=5812;
  v2(295,3)=  v2(294,3);
  v2(296,1)=23;
  v2(296,2)=5894;
  v2(296,3)=(-(T309*T315*exp(y(72))));
  v2(297,1)=23;
  v2(297,2)=5042;
  v2(297,3)=(-(T298*(-(T747*T1018))/(T247*T247)));
  v2(298,1)=23;
  v2(298,2)=3260;
  v2(298,3)=  v2(297,3);
  v2(299,1)=23;
  v2(299,2)=5045;
  v2(299,3)=(-(T298*T1018/T247+T298*T296*(T1017+T1016*T301*getPowerDeriv(T301,params(21),2))/T247));
  v2(300,1)=23;
  v2(300,2)=3506;
  v2(300,3)=  v2(299,3);
  v2(301,1)=23;
  v2(301,2)=5047;
  v2(301,3)=(-(T298*(-(T857*T1018))/(T247*T247)));
  v2(302,1)=23;
  v2(302,2)=3670;
  v2(302,3)=  v2(301,3);
  v2(303,1)=23;
  v2(303,2)=5064;
  v2(303,3)=(-(T298*T296*(T1016*T1016*getPowerDeriv(T301,params(21),2)+getPowerDeriv(T301,params(21),1)*((-(T298*exp(y(62))))*exp(y(62))*exp(y(62))-(-(T298*exp(y(62))))*(exp(y(62))*exp(y(62))+exp(y(62))*exp(y(62))))/(exp(y(62))*exp(y(62))*exp(y(62))*exp(y(62))))/T247));
  v2(304,1)=24;
  v2(304,2)=3238;
  v2(304,3)=(-(exp(y(73))*T330*T1782));
  v2(305,1)=24;
  v2(305,2)=5616;
  v2(305,3)=(-(exp(y(73))*T330*(-(T747*params(10)*params(25)*T785))/(T247*T247)));
  v2(306,1)=24;
  v2(306,2)=3267;
  v2(306,3)=  v2(305,3);
  v2(307,1)=24;
  v2(307,2)=5645;
  v2(307,3)=(-(exp(y(73))*T330*params(10)*params(25)*T1600/T247));
  v2(308,1)=24;
  v2(308,2)=3487;
  v2(308,3)=(-(T298*(1+params(37)*exp(y(63)))/params(23)));
  v2(309,1)=24;
  v2(309,2)=3648;
  v2(309,3)=(-(exp(y(73))*T330*T1826));
  v2(310,1)=24;
  v2(310,2)=3243;
  v2(310,3)=  v2(309,3);
  v2(311,1)=24;
  v2(311,2)=3677;
  v2(311,3)=(-(exp(y(73))*T330*(-(params(10)*params(25)*T785*T857))/(T247*T247)));
  v2(312,1)=24;
  v2(312,2)=5621;
  v2(312,3)=  v2(311,3);
  v2(313,1)=24;
  v2(313,2)=3653;
  v2(313,3)=(-(exp(y(73))*T330*T1855));
  v2(314,1)=24;
  v2(314,2)=5698;
  v2(314,3)=(-(exp(y(73))*T330*(-(T747*params(10)*params(25)*T881))/(T247*T247)));
  v2(315,1)=24;
  v2(315,2)=3268;
  v2(315,3)=  v2(314,3);
  v2(316,1)=24;
  v2(316,2)=5727;
  v2(316,3)=(-(exp(y(73))*T330*T1867));
  v2(317,1)=24;
  v2(317,2)=5646;
  v2(317,3)=  v2(316,3);
  v2(318,1)=24;
  v2(318,2)=5703;
  v2(318,3)=(-(exp(y(73))*T330*(-(T857*params(10)*params(25)*T881))/(T247*T247)));
  v2(319,1)=24;
  v2(319,2)=3678;
  v2(319,3)=  v2(318,3);
  v2(320,1)=24;
  v2(320,2)=5728;
  v2(320,3)=(-(exp(y(73))*T330*params(10)*params(25)*T1657/T247));
  v2(321,1)=24;
  v2(321,2)=5780;
  v2(321,3)=(-(exp(y(73))*T766*T931));
  v2(322,1)=24;
  v2(322,2)=3269;
  v2(322,3)=  v2(321,3);
  v2(323,1)=24;
  v2(323,2)=5809;
  v2(323,3)=(-(exp(y(73))*T791*T931));
  v2(324,1)=24;
  v2(324,2)=5647;
  v2(324,3)=  v2(323,3);
  v2(325,1)=24;
  v2(325,2)=5785;
  v2(325,3)=(-(exp(y(73))*T869*T931));
  v2(326,1)=24;
  v2(326,2)=3679;
  v2(326,3)=  v2(325,3);
  v2(327,1)=24;
  v2(327,2)=5810;
  v2(327,3)=(-(exp(y(73))*T887*T931));
  v2(328,1)=24;
  v2(328,2)=5729;
  v2(328,3)=  v2(327,3);
  v2(329,1)=24;
  v2(329,2)=5811;
  v2(329,3)=(-(exp(y(73))*T309*(T930*(-((-params(36))*(y(71)+y(71))))/(y(71)*y(71)*y(71)*y(71))+T924*T924*getPowerDeriv(T310,1-(1+params(23))/params(23),2))));
  v2(330,1)=24;
  v2(330,2)=3902;
  v2(330,3)=exp(y(48));
  v2(331,1)=24;
  v2(331,2)=5944;
  v2(331,3)=(-(exp(y(73))*T330*T766));
  v2(332,1)=24;
  v2(332,2)=3271;
  v2(332,3)=  v2(331,3);
  v2(333,1)=24;
  v2(333,2)=5973;
  v2(333,3)=(-(exp(y(73))*T330*T791));
  v2(334,1)=24;
  v2(334,2)=5649;
  v2(334,3)=  v2(333,3);
  v2(335,1)=24;
  v2(335,2)=5949;
  v2(335,3)=(-(exp(y(73))*T330*T869));
  v2(336,1)=24;
  v2(336,2)=3681;
  v2(336,3)=  v2(335,3);
  v2(337,1)=24;
  v2(337,2)=5974;
  v2(337,3)=(-(exp(y(73))*T330*T887));
  v2(338,1)=24;
  v2(338,2)=5731;
  v2(338,3)=  v2(337,3);
  v2(339,1)=24;
  v2(339,2)=5975;
  v2(339,3)=(-(exp(y(73))*T309*T931));
  v2(340,1)=24;
  v2(340,2)=5813;
  v2(340,3)=  v2(339,3);
  v2(341,1)=24;
  v2(341,2)=5977;
  v2(341,3)=(-(T309*T330*exp(y(73))));
  v2(342,1)=24;
  v2(342,2)=5127;
  v2(342,3)=T1032;
  v2(343,1)=24;
  v2(343,2)=3507;
  v2(343,3)=  v2(342,3);
  v2(344,1)=24;
  v2(344,2)=5147;
  v2(344,3)=T1032;
  v2(345,1)=25;
  v2(345,2)=3736;
  v2(345,3)=params(25)*(getPowerDeriv(T341,T338,1)*(-((-params(36))*(y(46)+y(46))))/(y(46)*y(46)*y(46)*y(46))+T908*T908*getPowerDeriv(T341,T338,2));
  v2(346,1)=25;
  v2(346,2)=3985;
  v2(346,3)=(1-params(25))*(exp(y(49))*getPowerDeriv(exp(y(49)),T338,1)+exp(y(49))*exp(y(49))*getPowerDeriv(exp(y(49)),T338,2));
  v2(347,1)=26;
  v2(347,2)=3736;
  v2(347,3)=(-(exp(y(10))*params(25)*(getPowerDeriv(T341,T314,1)*(-((-params(36))*(y(46)+y(46))))/(y(46)*y(46)*y(46)*y(46))+T908*T908*getPowerDeriv(T341,T314,2))));
  v2(348,1)=26;
  v2(348,2)=3985;
  v2(348,3)=(-((1-params(25))*(exp(y(49))*getPowerDeriv(exp(y(49)),T314,1)+exp(y(49))*exp(y(49))*getPowerDeriv(exp(y(49)),T314,2))));
  v2(349,1)=26;
  v2(349,2)=784;
  v2(349,3)=(-(exp(y(10))*params(25)*T908*getPowerDeriv(T341,T314,1)));
  v2(350,1)=26;
  v2(350,2)=3700;
  v2(350,3)=  v2(349,3);
  v2(351,1)=26;
  v2(351,2)=748;
  v2(351,3)=(-(params(25)*T341^T314*exp(y(10))));
  v2(352,1)=26;
  v2(352,2)=4068;
  v2(352,3)=exp(y(50));
  v2(353,1)=27;
  v2(353,2)=1993;
  v2(353,3)=(-(exp(y(25))*params(30)));
  v2(354,1)=27;
  v2(354,2)=3321;
  v2(354,3)=(-exp(y(41)));
  v2(355,1)=27;
  v2(355,2)=3487;
  v2(355,3)=T298;
  v2(356,1)=27;
  v2(356,2)=3570;
  v2(356,3)=(-exp(y(44)));
  v2(357,1)=28;
  v2(357,2)=3487;
  v2(357,3)=(-(T298*params(12)*exp(y(61))));
  v2(358,1)=28;
  v2(358,2)=3570;
  v2(358,3)=exp(y(44));
  v2(359,1)=28;
  v2(359,2)=4963;
  v2(359,3)=(-(T298*params(12)*exp(y(61))));
  v2(360,1)=28;
  v2(360,2)=3505;
  v2(360,3)=  v2(359,3);
  v2(361,1)=28;
  v2(361,2)=4981;
  v2(361,3)=(-(T298*params(12)*exp(y(61))));
  v2(362,1)=29;
  v2(362,2)=665;
  v2(362,3)=(-(y(46)*((-(exp(y(45))*exp(y(9))))*exp(y(9))*exp(y(9))-(-(exp(y(45))*exp(y(9))))*(exp(y(9))*exp(y(9))+exp(y(9))*exp(y(9))))/(exp(y(9))*exp(y(9))*exp(y(9))*exp(y(9)))));
  v2(363,1)=29;
  v2(363,2)=3617;
  v2(363,3)=T850;
  v2(364,1)=29;
  v2(364,2)=701;
  v2(364,3)=  v2(363,3);
  v2(365,1)=29;
  v2(365,2)=3653;
  v2(365,3)=(-(y(46)*exp(y(45))/exp(y(9))));
  v2(366,1)=29;
  v2(366,2)=3699;
  v2(366,3)=(-T848);
  v2(367,1)=29;
  v2(367,2)=702;
  v2(367,3)=  v2(366,3);
  v2(368,1)=29;
  v2(368,2)=3735;
  v2(368,3)=(-(exp(y(45))/exp(y(9))));
  v2(369,1)=29;
  v2(369,2)=3654;
  v2(369,3)=  v2(368,3);
  v2(370,1)=30;
  v2(370,2)=582;
  v2(370,3)=(-(((-(y(46)*T298*exp(y(8))))*exp(y(8))*exp(y(8))-(-(y(46)*T298*exp(y(8))))*(exp(y(8))*exp(y(8))+exp(y(8))*exp(y(8))))/(exp(y(8))*exp(y(8))*exp(y(8))*exp(y(8)))));
  v2(371,1)=30;
  v2(371,2)=3452;
  v2(371,3)=T827;
  v2(372,1)=30;
  v2(372,2)=617;
  v2(372,3)=  v2(371,3);
  v2(373,1)=30;
  v2(373,2)=3487;
  v2(373,3)=(-(y(46)*T298/exp(y(8))));
  v2(374,1)=30;
  v2(374,2)=3698;
  v2(374,3)=(-((-(T298*exp(y(8))))/(exp(y(8))*exp(y(8)))));
  v2(375,1)=30;
  v2(375,2)=620;
  v2(375,3)=  v2(374,3);
  v2(376,1)=30;
  v2(376,2)=3733;
  v2(376,3)=(-(T298/exp(y(8))));
  v2(377,1)=30;
  v2(377,2)=3490;
  v2(377,3)=  v2(376,3);
  v2(378,1)=30;
  v2(378,2)=997;
  v2(378,3)=((-(exp(y(54))*exp(y(13))))*exp(y(13))*exp(y(13))-(-(exp(y(54))*exp(y(13))))*(exp(y(13))*exp(y(13))+exp(y(13))*exp(y(13))))/(exp(y(13))*exp(y(13))*exp(y(13))*exp(y(13)));
  v2(379,1)=30;
  v2(379,2)=4359;
  v2(379,3)=T980;
  v2(380,1)=30;
  v2(380,2)=1038;
  v2(380,3)=  v2(379,3);
  v2(381,1)=30;
  v2(381,2)=4400;
  v2(381,3)=T379;
  v2(382,1)=31;
  v2(382,2)=1080;
  v2(382,3)=(-(((-(exp(y(55))*exp(y(14))))*exp(y(14))*exp(y(14))-(-(exp(y(55))*exp(y(14))))*(exp(y(14))*exp(y(14))+exp(y(14))*exp(y(14))))/(exp(y(14))*exp(y(14))*exp(y(14))*exp(y(14)))));
  v2(383,1)=31;
  v2(383,2)=4442;
  v2(383,3)=T985;
  v2(384,1)=31;
  v2(384,2)=1121;
  v2(384,3)=  v2(383,3);
  v2(385,1)=31;
  v2(385,2)=4483;
  v2(385,3)=(-(exp(y(55))/exp(y(14))));
  v2(386,1)=32;
  v2(386,2)=1827;
  v2(386,3)=(-(params(48)*(T76*T76*(-(T398*T1108))-(-(T398*T499))*(T76*T499+T76*T499))/(T76*T76*T76*T76)));
  v2(387,1)=32;
  v2(387,2)=2811;
  v2(387,3)=(-(params(48)*(-(T499*T724))/(T76*T76)));
  v2(388,1)=32;
  v2(388,2)=1839;
  v2(388,3)=  v2(387,3);
  v2(389,1)=32;
  v2(389,2)=2823;
  v2(389,3)=(-(params(48)*params(47)*(exp(y(35))*exp(y(35))*(-(exp(y(35))*params(46)))-(-(exp(y(35))*params(46)))*(exp(y(35))*exp(y(35))+exp(y(35))*exp(y(35))))/(exp(y(35))*exp(y(35))*exp(y(35))*exp(y(35)))/T76));
  v2(390,1)=32;
  v2(390,2)=3238;
  v2(390,3)=params(45)*(T246*T246*(-(params(44)*T1578))-(-(params(44)*T746))*(T246*T746+T246*T746))/(T246*T246*T246*T246);
  v2(391,1)=33;
  v2(391,2)=2823;
  v2(391,3)=exp(y(35));
  v2(392,1)=33;
  v2(392,2)=4234;
  v2(392,3)=(-(((-exp(y(52)))*exp(y(52))*exp(y(52))-(-exp(y(52)))*(exp(y(52))*exp(y(52))+exp(y(52))*exp(y(52))))/(exp(y(52))*exp(y(52))*exp(y(52))*exp(y(52)))));
  v2(393,1)=34;
  v2(393,2)=333;
  v2(393,3)=((-(exp(y(35))*exp(y(5))))*exp(y(5))*exp(y(5))-(-(exp(y(35))*exp(y(5))))*(exp(y(5))*exp(y(5))+exp(y(5))*exp(y(5))))/(exp(y(5))*exp(y(5))*exp(y(5))*exp(y(5)));
  v2(394,1)=34;
  v2(394,2)=2793;
  v2(394,3)=T716;
  v2(395,1)=34;
  v2(395,2)=363;
  v2(395,3)=  v2(394,3);
  v2(396,1)=34;
  v2(396,2)=2823;
  v2(396,3)=T409;
  v2(397,1)=34;
  v2(397,2)=2906;
  v2(397,3)=(-((-((-(y(53)*exp(y(39))))*(y(36)+y(36))))/(y(36)*y(36)*y(36)*y(36))));
  v2(398,1)=34;
  v2(398,2)=3152;
  v2(398,3)=(-((-(y(53)*exp(y(39))))/(y(36)*y(36))));
  v2(399,1)=34;
  v2(399,2)=2909;
  v2(399,3)=  v2(398,3);
  v2(400,1)=34;
  v2(400,2)=3155;
  v2(400,3)=(-(y(53)*exp(y(39))/y(36)));
  v2(401,1)=34;
  v2(401,2)=4300;
  v2(401,3)=(-((-exp(y(39)))/(y(36)*y(36))));
  v2(402,1)=34;
  v2(402,2)=2923;
  v2(402,3)=  v2(401,3);
  v2(403,1)=34;
  v2(403,2)=4303;
  v2(403,3)=(-(exp(y(39))/y(36)));
  v2(404,1)=34;
  v2(404,2)=3169;
  v2(404,3)=  v2(403,3);
  v2(405,1)=35;
  v2(405,2)=914;
  v2(405,3)=((-(exp(y(52))*exp(y(12))))*exp(y(12))*exp(y(12))-(-(exp(y(52))*exp(y(12))))*(exp(y(12))*exp(y(12))+exp(y(12))*exp(y(12))))/(exp(y(12))*exp(y(12))*exp(y(12))*exp(y(12)));
  v2(406,1)=35;
  v2(406,2)=4194;
  v2(406,3)=T966;
  v2(407,1)=35;
  v2(407,2)=954;
  v2(407,3)=  v2(406,3);
  v2(408,1)=35;
  v2(408,2)=4234;
  v2(408,3)=T417;
  v2(409,1)=35;
  v2(409,2)=4300;
  v2(409,3)=(-((-exp(y(56)))/(y(53)*y(53))));
  v2(410,1)=35;
  v2(410,2)=2923;
  v2(410,3)=  v2(409,3);
  v2(411,1)=35;
  v2(411,2)=4317;
  v2(411,3)=(-((-((-(y(36)*exp(y(56))))*(y(53)+y(53))))/(y(53)*y(53)*y(53)*y(53))));
  v2(412,1)=35;
  v2(412,2)=4546;
  v2(412,3)=(-(exp(y(56))/y(53)));
  v2(413,1)=35;
  v2(413,2)=2926;
  v2(413,3)=  v2(412,3);
  v2(414,1)=35;
  v2(414,2)=4563;
  v2(414,3)=(-((-(y(36)*exp(y(56))))/(y(53)*y(53))));
  v2(415,1)=35;
  v2(415,2)=4320;
  v2(415,3)=  v2(414,3);
  v2(416,1)=35;
  v2(416,2)=4566;
  v2(416,3)=(-(y(36)*exp(y(56))/y(53)));
  v2(417,1)=36;
  v2(417,2)=1827;
  v2(417,3)=T1104;
  v2(418,1)=36;
  v2(418,2)=2076;
  v2(418,3)=exp(y(33))*T426*(T589+T135*T135*getPowerDeriv(T135,1+params(22),2))/(1+params(22));
  v2(419,1)=36;
  v2(419,2)=2650;
  v2(419,3)=T592;
  v2(420,1)=36;
  v2(420,2)=2083;
  v2(420,3)=  v2(419,3);
  v2(421,1)=36;
  v2(421,2)=2657;
  v2(421,3)=T430;
  v2(422,1)=36;
  v2(422,2)=4782;
  v2(422,3)=exp(y(33))*T589*params(27)*exp(y(59))*getPowerDeriv(exp(y(59)),(-params(22)),1)/(1+params(22));
  v2(423,1)=36;
  v2(423,2)=2109;
  v2(423,3)=  v2(422,3);
  v2(424,1)=36;
  v2(424,2)=4789;
  v2(424,3)=T1005;
  v2(425,1)=36;
  v2(425,2)=2683;
  v2(425,3)=  v2(424,3);
  v2(426,1)=36;
  v2(426,2)=4815;
  v2(426,3)=exp(y(33))*T427*params(27)*(exp(y(59))*getPowerDeriv(exp(y(59)),(-params(22)),1)+exp(y(59))*exp(y(59))*getPowerDeriv(exp(y(59)),(-params(22)),2))/(1+params(22));
  v2(427,1)=37;
  v2(427,2)=3238;
  v2(427,3)=(-((exp(y(40))*getPowerDeriv(exp(y(40)),1-params(9),1)+exp(y(40))*exp(y(40))*getPowerDeriv(exp(y(40)),1-params(9),2))/(1-params(9))));
  v2(428,1)=37;
  v2(428,2)=3487;
  v2(428,3)=exp(y(50))*T439*(T839+T298*T298*getPowerDeriv(T298,1+params(21),2))/(1+params(21));
  v2(429,1)=37;
  v2(429,2)=4061;
  v2(429,3)=T842;
  v2(430,1)=37;
  v2(430,2)=3494;
  v2(430,3)=  v2(429,3);
  v2(431,1)=37;
  v2(431,2)=4068;
  v2(431,3)=T443;
  v2(432,1)=37;
  v2(432,2)=5045;
  v2(432,3)=exp(y(50))*T839*params(33)*exp(y(62))*getPowerDeriv(exp(y(62)),(-params(21)),1)/(1+params(21));
  v2(433,1)=37;
  v2(433,2)=3506;
  v2(433,3)=  v2(432,3);
  v2(434,1)=37;
  v2(434,2)=5052;
  v2(434,3)=T1027;
  v2(435,1)=37;
  v2(435,2)=4080;
  v2(435,3)=  v2(434,3);
  v2(436,1)=37;
  v2(436,2)=5064;
  v2(436,3)=exp(y(50))*T440*params(33)*(exp(y(62))*getPowerDeriv(exp(y(62)),(-params(21)),1)+exp(y(62))*exp(y(62))*getPowerDeriv(exp(y(62)),(-params(21)),2))/(1+params(21));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),43,6724);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],43,551368);
end
end
