function [residual, g1, g2] = rbcb_monprud_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 33, 1);

%
% Model equations
%

T96 = y(5)*params(5)*(1-params(10))/y(5);
T100 = y(5)*params(5)*params(10)/y(5);
T108 = (1-y(28))*T100*(y(7)+1+y(11)*(y(4)-y(7))/(params(9)-y(10)));
T124 = exp(y(29))*y(1)^params(1)*y(6)^(1-params(1));
T152 = (-(1+params(16)+y(33)))/params(15)+y(24)*(1+params(15))/params(15);
T173 = y(20)/(y(20)*params(17)+params(48)*(1-params(17)))-1;
T228 = log(y(15)-y(15)*params(2)+y(32))-params(3)*y(6)^(1+params(4))/(1+params(4));
T336 = params(3)*getPowerDeriv(y(6),1+params(4),1)/(1+params(4));
T441 = (y(20)*params(17)+params(48)*(1-params(17))-y(20)*params(17))/((y(20)*params(17)+params(48)*(1-params(17)))*(y(20)*params(17)+params(48)*(1-params(17))));
lhs =y(19);
rhs =params(39)+params(22)*(y(19)-((-1)+params(48)/params(5)))+(1-params(22))*params(23)*(y(20)-params(48))+x(2);
residual(1)= lhs-rhs;
lhs =y(28);
rhs =y(28)*params(25)+x(4);
residual(2)= lhs-rhs;
lhs =y(5);
rhs =1/(y(15)-y(15)*params(2)+y(32))-params(2)*y(31)/(y(15)-y(15)*params(2)+y(32));
residual(3)= lhs-rhs;
lhs =params(3)*y(6)^params(4);
rhs =y(5)*y(3);
residual(4)= lhs-rhs;
lhs =1;
rhs =1/(y(31)*(1+y(7)));
residual(5)= lhs-rhs;
lhs =y(8)*y(14);
rhs =y(11)/(y(30)-y(10))*y(9)*(1-y(28));
residual(6)= lhs-rhs;
lhs =y(9);
rhs =(1-y(28))*y(9)*params(10)*(y(7)+1+y(11)*(y(4)-y(7))/(y(30)-y(10)))+y(8)*y(14)*params(11);
residual(7)= lhs-rhs;
lhs =y(10);
rhs =(y(4)-y(7))*T96+y(10)*T108;
residual(8)= lhs-rhs;
lhs =y(11);
rhs =1-params(10)+y(11)*T108;
residual(9)= lhs-rhs;
lhs =y(1);
rhs =y(8);
residual(10)= lhs-rhs;
lhs =y(2);
rhs =T124;
residual(11)= lhs-rhs;
lhs =y(6);
rhs =y(2)*(1-params(1))*y(24)/y(3);
residual(12)= lhs-rhs;
lhs =1+y(4);
rhs =y(2)*params(1)*y(24)/(y(14)*y(1))+y(14)*(1-params(6))/y(14);
residual(13)= lhs-rhs;
lhs =0;
rhs =y(2)*T152-y(2)*y(22)-y(2)*1/(1+y(19))*y(23);
residual(14)= lhs-rhs;
lhs =y(21);
rhs =params(13)/2*T173^2;
residual(15)= lhs-rhs;
lhs =y(22);
rhs =y(20)*params(13)*T173/(y(20)*params(17)+params(48)*(1-params(17)));
residual(16)= lhs-rhs;
lhs =y(23);
rhs =T173*(-params(13))*y(20)^2/(y(20)*params(17)+params(48)*(1-params(17)));
residual(17)= lhs-rhs;
lhs =y(1);
rhs =y(12)+y(1)*(1-params(6));
residual(18)= lhs-rhs;
lhs =y(12);
rhs =y(13);
residual(19)= lhs-rhs;
lhs =y(14);
rhs =1;
residual(20)= lhs-rhs;
lhs =y(2);
rhs =y(15)+y(13)+y(16)+y(2)*y(21);
residual(21)= lhs-rhs;
lhs =y(16);
rhs =y(2)*params(8);
residual(22)= lhs-rhs;
lhs =y(17);
rhs =y(4)-y(7);
residual(23)= lhs-rhs;
lhs =y(18);
rhs =y(11)/(params(9)-y(10));
residual(24)= lhs-rhs;
lhs =1/y(20);
rhs =1/(y(31)*(1+y(19)));
residual(25)= lhs-rhs;
lhs =y(25);
rhs =y(9)/y(2);
residual(26)= lhs-rhs;
lhs =y(26);
rhs =T228-params(19)*(y(20)-params(48))^2-params(51)*params(18)*(y(17)-params(14))^2;
residual(27)= lhs-rhs;
lhs =y(27);
rhs =T228-params(18)*(y(17)-params(14))^2-(y(20)-params(48))^2*params(19)*params(52);
residual(28)= lhs-rhs;
lhs =y(30)-params(9);
rhs =(y(30)-params(9))*params(29)+params(30)*x(3);
residual(29)= lhs-rhs;
lhs =y(31)-params(5);
rhs =(y(31)-params(5))*params(33)+params(34)*x(5);
residual(30)= lhs-rhs;
lhs =y(32);
rhs =y(32)*params(35)+params(36)*x(6);
residual(31)= lhs-rhs;
lhs =y(29);
rhs =y(29)*params(27)+params(28)*x(1);
residual(32)= lhs-rhs;
lhs =y(33);
rhs =y(33)*params(50)+params(49)*x(7);
residual(33)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(33, 33);

  %
  % Jacobian matrix
  %

  g1(1,19)=1-params(22);
  g1(1,20)=(-((1-params(22))*params(23)));
  g1(2,28)=1-params(25);
  g1(3,5)=1;
  g1(3,15)=(-((-(1-params(2)))/((y(15)-y(15)*params(2)+y(32))*(y(15)-y(15)*params(2)+y(32)))-(-(params(2)*y(31)*(1-params(2))))/((y(15)-y(15)*params(2)+y(32))*(y(15)-y(15)*params(2)+y(32)))));
  g1(3,31)=params(2)/(y(15)-y(15)*params(2)+y(32));
  g1(3,32)=(-((-1)/((y(15)-y(15)*params(2)+y(32))*(y(15)-y(15)*params(2)+y(32)))-(-(params(2)*y(31)))/((y(15)-y(15)*params(2)+y(32))*(y(15)-y(15)*params(2)+y(32)))));
  g1(4,3)=(-y(5));
  g1(4,5)=(-y(3));
  g1(4,6)=params(3)*getPowerDeriv(y(6),params(4),1);
  g1(5,7)=(-((-y(31))/(y(31)*(1+y(7))*y(31)*(1+y(7)))));
  g1(5,31)=(-((-(1+y(7)))/(y(31)*(1+y(7))*y(31)*(1+y(7)))));
  g1(6,8)=y(14);
  g1(6,9)=(-(y(11)/(y(30)-y(10))*(1-y(28))));
  g1(6,10)=(-((1-y(28))*y(9)*y(11)/((y(30)-y(10))*(y(30)-y(10)))));
  g1(6,11)=(-((1-y(28))*y(9)*1/(y(30)-y(10))));
  g1(6,14)=y(8);
  g1(6,28)=y(11)/(y(30)-y(10))*y(9);
  g1(6,30)=(-((1-y(28))*y(9)*(-y(11))/((y(30)-y(10))*(y(30)-y(10)))));
  g1(7,4)=(-((1-y(28))*y(9)*y(11)/(y(30)-y(10))*params(10)));
  g1(7,7)=(-((1-y(28))*y(9)*params(10)*(1+(-y(11))/(y(30)-y(10)))));
  g1(7,8)=(-(y(14)*params(11)));
  g1(7,9)=1-(1-y(28))*params(10)*(y(7)+1+y(11)*(y(4)-y(7))/(y(30)-y(10)));
  g1(7,10)=(-((1-y(28))*y(9)*params(10)*y(11)*(y(4)-y(7))/((y(30)-y(10))*(y(30)-y(10)))));
  g1(7,11)=(-((1-y(28))*y(9)*params(10)*(y(4)-y(7))/(y(30)-y(10))));
  g1(7,14)=(-(y(8)*params(11)));
  g1(7,28)=y(9)*params(10)*(y(7)+1+y(11)*(y(4)-y(7))/(y(30)-y(10)));
  g1(7,30)=(-((1-y(28))*y(9)*params(10)*(-(y(11)*(y(4)-y(7))))/((y(30)-y(10))*(y(30)-y(10)))));
  g1(8,4)=(-(T96+y(10)*(1-y(28))*T100*y(11)/(params(9)-y(10))));
  g1(8,7)=(-((-T96)+y(10)*(1-y(28))*T100*(1+(-y(11))/(params(9)-y(10)))));
  g1(8,10)=1-(T108+y(10)*(1-y(28))*T100*y(11)*(y(4)-y(7))/((params(9)-y(10))*(params(9)-y(10))));
  g1(8,11)=(-(y(10)*(1-y(28))*T100*(y(4)-y(7))/(params(9)-y(10))));
  g1(8,28)=(-(y(10)*(-(T100*(y(7)+1+y(11)*(y(4)-y(7))/(params(9)-y(10)))))));
  g1(9,4)=(-(y(11)*(1-y(28))*T100*y(11)/(params(9)-y(10))));
  g1(9,7)=(-(y(11)*(1-y(28))*T100*(1+(-y(11))/(params(9)-y(10)))));
  g1(9,10)=(-(y(11)*(1-y(28))*T100*y(11)*(y(4)-y(7))/((params(9)-y(10))*(params(9)-y(10)))));
  g1(9,11)=1-(T108+y(11)*(1-y(28))*T100*(y(4)-y(7))/(params(9)-y(10)));
  g1(9,28)=(-(y(11)*(-(T100*(y(7)+1+y(11)*(y(4)-y(7))/(params(9)-y(10)))))));
  g1(10,1)=1;
  g1(10,8)=(-1);
  g1(11,1)=(-(y(6)^(1-params(1))*exp(y(29))*getPowerDeriv(y(1),params(1),1)));
  g1(11,2)=1;
  g1(11,6)=(-(exp(y(29))*y(1)^params(1)*getPowerDeriv(y(6),1-params(1),1)));
  g1(11,29)=(-T124);
  g1(12,2)=(-((1-params(1))*y(24)/y(3)));
  g1(12,3)=(-((-(y(2)*(1-params(1))*y(24)))/(y(3)*y(3))));
  g1(12,6)=1;
  g1(12,24)=(-(y(2)*(1-params(1))/y(3)));
  g1(13,1)=(-((-(y(14)*y(2)*params(1)*y(24)))/(y(14)*y(1)*y(14)*y(1))));
  g1(13,2)=(-(params(1)*y(24)/(y(14)*y(1))));
  g1(13,4)=1;
  g1(13,14)=(-((-(y(1)*y(2)*params(1)*y(24)))/(y(14)*y(1)*y(14)*y(1))));
  g1(13,24)=(-(y(2)*params(1)/(y(14)*y(1))));
  g1(14,2)=(-(T152-y(22)-1/(1+y(19))*y(23)));
  g1(14,19)=y(23)*y(2)*(-1)/((1+y(19))*(1+y(19)));
  g1(14,22)=y(2);
  g1(14,23)=y(2)*1/(1+y(19));
  g1(14,24)=(-(y(2)*(1+params(15))/params(15)));
  g1(14,33)=(-(y(2)*(-1)/params(15)));
  g1(15,20)=(-(params(13)/2*T441*2*T173));
  g1(15,21)=1;
  g1(16,20)=(-(((y(20)*params(17)+params(48)*(1-params(17)))*(params(13)*T173+y(20)*params(13)*T441)-params(17)*y(20)*params(13)*T173)/((y(20)*params(17)+params(48)*(1-params(17)))*(y(20)*params(17)+params(48)*(1-params(17))))));
  g1(16,22)=1;
  g1(17,20)=(-(((y(20)*params(17)+params(48)*(1-params(17)))*(y(20)^2*(-params(13))*T441+T173*(-params(13))*2*y(20))-params(17)*T173*(-params(13))*y(20)^2)/((y(20)*params(17)+params(48)*(1-params(17)))*(y(20)*params(17)+params(48)*(1-params(17))))));
  g1(17,23)=1;
  g1(18,1)=1-(1-params(6));
  g1(18,12)=(-1);
  g1(19,12)=1;
  g1(19,13)=(-1);
  g1(20,14)=1;
  g1(21,2)=1-y(21);
  g1(21,13)=(-1);
  g1(21,15)=(-1);
  g1(21,16)=(-1);
  g1(21,21)=(-y(2));
  g1(22,2)=(-params(8));
  g1(22,16)=1;
  g1(23,4)=(-1);
  g1(23,7)=1;
  g1(23,17)=1;
  g1(24,10)=(-(y(11)/((params(9)-y(10))*(params(9)-y(10)))));
  g1(24,11)=(-(1/(params(9)-y(10))));
  g1(24,18)=1;
  g1(25,19)=(-((-y(31))/(y(31)*(1+y(19))*y(31)*(1+y(19)))));
  g1(25,20)=(-1)/(y(20)*y(20));
  g1(25,31)=(-((-(1+y(19)))/(y(31)*(1+y(19))*y(31)*(1+y(19)))));
  g1(26,2)=(-((-y(9))/(y(2)*y(2))));
  g1(26,9)=(-(1/y(2)));
  g1(26,25)=1;
  g1(27,6)=T336;
  g1(27,15)=(-((1-params(2))/(y(15)-y(15)*params(2)+y(32))));
  g1(27,17)=params(51)*params(18)*2*(y(17)-params(14));
  g1(27,20)=params(19)*2*(y(20)-params(48));
  g1(27,26)=1;
  g1(27,32)=(-(1/(y(15)-y(15)*params(2)+y(32))));
  g1(28,6)=T336;
  g1(28,15)=(-((1-params(2))/(y(15)-y(15)*params(2)+y(32))));
  g1(28,17)=params(18)*2*(y(17)-params(14));
  g1(28,20)=params(19)*params(52)*2*(y(20)-params(48));
  g1(28,27)=1;
  g1(28,32)=(-(1/(y(15)-y(15)*params(2)+y(32))));
  g1(29,30)=1-params(29);
  g1(30,31)=1-params(33);
  g1(31,32)=1-params(35);
  g1(32,29)=1-params(27);
  g1(33,33)=1-params(50);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],33,1089);
end
end
